@@ -447,6 +447,14 @@ dku__convert_iso8601date <- function(x) {
     return (as.POSIXlt(x, format="%Y-%m-%dT%H:%M:%OSZ", tz="UTC"))
 }
 
+dku__convert_dateOnly <- function(x) {
+    return (as.Date(x))
+}
+
+dku__convert_datetimeNoTz <- function(x) {
+    return (as.POSIXlt(x, format="%Y-%m-%d %H:%M:%OS")) # Will get the system timezone added to it by default
+}
+
 dku__convert_type <- function(x) {
     conv <- function(t) {
         switch(t, tinyint="integer",smallint="integer",int="integer",bigint="integer",float="numeric",double="numeric",boolean="logical",date="character","character")
@@ -463,11 +471,22 @@ dku__fixup_dates_for_schema <- function(df, schema) {
     for (c in schema$columns) {
         if (c$type == "date") {
             df[[c$name]] <- dku__convert_iso8601date(df[,c$name])
+        } else if (c$type == "dateonly") {
+            df[[c$name]] <- dku__convert_dateOnly(df[,c$name])
+        } else if (c$type == "datetimenotz") {
+            df[[c$name]] <- dku__convert_datetimeNoTz(df[,c$name])
         }
     }
     return (df)
 }
 
+dku__is_timezone_set <- function(tzone) {
+    # This might be more no timezone "specified", rather than no timezone "set", but not sure what else to do?
+    # POSIXct: tzone looks like "" when no timezone is specified
+    # POSIXlt: tzone is a vector of length 3 (looks like c("" "system tz" "system DST")) when no timezone is specified
+    return (length(tzone) == 1 && tzone != "")
+}
+
 dkuSourceLibR <- function(f, local = FALSE, verbose = getOption("verbose"), chdir = FALSE, encoding = getOption("encoding")) {
 	paths <- NA
 	print("SEARCHING FOR ")
