@@ -5,7 +5,6 @@ This will retrieve the definition of the stuff to be executed and execute it,
 forking the process (in the image's code environment if necessary).
 """
 
-import dataiku
 from dataiku.base import remoterun
 from dataiku.container.file_exchange import FileExchanger
 from dataiku.core import debugging, intercom
@@ -16,6 +15,8 @@ from dataiku.base.remoterun import safe_os_environ_update
 import requests
 import shutil
 import tempfile
+import socket
+import textwrap
 from dataiku.container.code_studio_server_thread import CommandServerThread
 
 from dataiku.container.compute_resource_usage import ProcessResourceUsageMonitor
@@ -230,10 +231,10 @@ def run_subprocess(execution_id, command, path = 'error.json',
 
     return handle_subprocess_return_value(execution_id, error_code, path, send_error_json, fail_if_subprocess_failed)
 
-def run_popen(command, **extra_env):
+def _run_popen(command, stdout, stderr, **extra_env):
     env = dict(os.environ, LC_ALL='en_US.utf8', DKU_CONTAINER_EXEC='1')
     env.update(extra_env)
-    p = subprocess.Popen(command, shell=True, env=env)
+    p = subprocess.Popen(command, shell=True, env=env, stdout=stdout, stderr=stderr)
     logging.info("Running subprocess in PID %s" % p.pid)
     # spawn a thread to monitor the usage of the subprocess
     # but unlike run_subprocess we can't wait on its proper termination
@@ -242,6 +243,49 @@ def run_popen(command, **extra_env):
     monitor.start()
     return p
 
+def run_popen(command, **extra_env):
+    return _run_popen(command, None, None, **extra_env)
+
+def run_popen_with_log_prefix(command, prefix, **extra_env):
+    p = _run_popen(command, subprocess.PIPE, subprocess.PIPE, **extra_env)
+    def log_stdout():
+        errors_countdown = 5
+        line = ''
+        while p.poll() is None or len(line) > 0:
+            try:
+                line = p.stdout.readline()
+                if line is None:
+                    break
+                logging.info("[%s out] %s" % (prefix, line.decode('utf8')))
+                errors_countdown = 5
+            except Exception as e:
+                if errors_countdown > 0: # don't log forever, but still try to consume the stdout, otherwise it'll hang
+                    logging.warning("[%s] Unable to log stdout : %s" % (prefix, str(e)))
+                errors_countdown -= 1
+        logging.info("[%s out] ** process finished **" % (prefix))
+    def log_stderr():
+        errors_countdown = 5
+        line = ''
+        while p.poll() is None or len(line) > 0:
+            try:
+                line = p.stderr.readline()
+                if line is None:
+                    break
+                logging.info("[%s err] %s" % (prefix, line.decode('utf8')))
+                errors_countdown = 5
+            except Exception as e:
+                if errors_countdown > 0: # don't log forever, but still try to consume the stderr, otherwise it'll hang
+                    logging.warning("[%s] Unable to log stderr : %s" % (prefix, str(e)))
+                errors_countdown -= 1
+        logging.info("[%s err] ** process finished **" % (prefix))
+    log_stdout_thread = threading.Thread(target=log_stdout)
+    log_stdout_thread.daemon = True
+    log_stdout_thread.start()
+    log_stderr_thread = threading.Thread(target=log_stderr)
+    log_stderr_thread.daemon = True
+    log_stderr_thread.start()
+    return p
+
 def handle_subprocess_return_value(execution_id, error_code, path = 'error.json',
                    send_error_json = True, fail_if_subprocess_failed = False):
     if os.WIFEXITED(error_code):
@@ -896,6 +940,12 @@ def main():
         logging.info("Running llm evaluation recipe main")
         run_subprocess(execution_id, '%s -m dataiku.container.exec_llm_eval_recipe' % python_bin)
 
+    elif execution['type'] == 'RECIPE_AGENT_EVALUATION_PYTHON':
+        logging.info("Evaluating agent")
+
+        logging.info("Running agent evaluation recipe main")
+        run_subprocess(execution_id, '%s -m dataiku.container.exec_agent_eval_recipe' % python_bin)
+
     elif execution['type'] == 'RECIPE_CLUSTERING_CLUSTER_PYTHON':
         logging.info("Clustering dataset")
 
@@ -1174,6 +1224,60 @@ main()
             # no 'failure' per se can happen
             os._exit(0)
 
+    elif execution['type'] == 'WEBAPP_STREAMLIT':
+
+        plugin_id = dku_vars.get("DKU_PLUGIN_ID", None)
+        if plugin_id is not None:
+            logging.info("Getting plugin %s" % plugin_id)
+            fetch_plugin(execution_id, plugin_id)
+
+        definition = json.loads(execution['definition'])
+        project_key = definition['projectKey']
+        webapp_id = definition['webAppId']
+        logging.info("Executing streamlit webapp backend {project_key}/{webapp_id}".format(project_key=project_key, webapp_id=webapp_id))
+
+        if not os.path.exists('backend'):
+            os.mkdir('backend')
+        with open(os.path.join('backend', 'main.py'), 'wb') as fd:
+            fd.write(definition['code'].encode('utf8'))
+        if definition.get('config', None) is not None:
+            if not os.path.exists('.streamlit'):
+                os.mkdir('.streamlit')
+            with open(os.path.join('.streamlit', 'config.toml'), 'wb') as fd:
+                fd.write(definition['config'].encode('utf8'))
+
+        security_info = definition.get('securityInfo', {})
+        web_app_host, web_app_port = setup_webapp_exposition(
+            security_info,
+            project_key,
+            webapp_id,
+            'STREAMLIT',
+            '/__ping'
+        )
+
+        # construct the external url for use in redirects if a redirect is required to capture authentication info
+        nb_workers = definition.get("nbProcesses", 1)
+        start_code = """from dataiku.webapps.run_streamlit import main
+import sys
+sys.argv = [sys.argv[0], './backend/main.py', '-w', '{nb_workers}', '-H', '{web_app_host}', '-p', '{web_app_port}']
+main()
+""".format(nb_workers=nb_workers, web_app_host=web_app_host, web_app_port=web_app_port)
+        with open('start_webapp.py', 'wb') as fd:
+            fd.write(start_code.encode('utf8'))
+
+        with open('/tmp/liveliness.marker', 'w') as f:  # 'w' OK, we write a string
+            f.write('alive')
+
+        setup_python_env(execution_id, dku_vars, False)
+
+        run_metrics_server()
+        logging.info("Executing streamlit webapp {project_key}/{webapp_id} subprocess".format(project_key=project_key, webapp_id=webapp_id))
+        try:
+            run_subprocess(execution_id, '%s -m dataiku.container.exec_py_webapp' % python_bin)
+        finally:
+            # no 'failure' per se can happen
+            os._exit(0)
+
     elif execution['type'] == 'RECIPE_CPYTHON':
         logging.info("Executing Continuous Python recipe")
 
@@ -1329,7 +1433,10 @@ main()
         try:
             for i, entrypoint in enumerate(definition['entrypoints']):
                 logging.info("Running Code Studio entrypoint %s: %s" % (i, entrypoint))
-                sub_processes.append(run_popen(entrypoint, **extra_env))
+                # guess what entrypoint it is from the entrypoint name
+                m = re.match('^(.*/)?([^/]+)-entrypoint[^/]*$', entrypoint)
+                name = 'block' if m is None else m.group(2)
+                sub_processes.append(run_popen_with_log_prefix(entrypoint, "%s_%s" % (name, i), **extra_env))
             exit_codes = [p.wait() for p in sub_processes]
         finally:
             # no 'failure' per se can happen
