@@ -1,7 +1,6 @@
 import enum
 import json
 import logging
-import random
 import time
 from collections.abc import Callable
 from typing import Dict, Optional, Any, List, Union
@@ -46,7 +45,7 @@ class AzureAISearchVectorStore(DkuRemoteVectorStore):
         self.azure_credential: Optional[Union[credentials.TokenCredential, credentials.AzureKeyCredential]] = None # to connect to Azure SearchIndexClient on our side
         self.auth_kwargs: Dict = {}  # for langchain (also connecting to the SearchIndexClient but internally)
         super().__init__(kb, exec_folder, connection_info_retriever)
-        self.document_filter = AzureAISearchVectorStoreDocumentFilter(self.metadata_column_type)
+        self.document_filter = AzureAISearchVectorStoreDocumentFilter(self.metadata_column_type_and_meaning)
 
     def init_connection(self) -> None:
 
@@ -132,11 +131,11 @@ class AzureAISearchVectorStore(DkuRemoteVectorStore):
         fields_from_metadata = [
             SimpleField(
                 name=column_name,
-                type=get_azure_data_type(column_type, column_name),
+                type=get_azure_data_type(column_type, column_name, column_meaning),
                 filterable=True,
                 searchable=False,  # don't want these fields used in hybrid search
             )
-            for column_name, column_type in self.metadata_column_type.items()
+            for column_name, (column_type, column_meaning) in self.metadata_column_type_and_meaning.items()
         ]
 
         # field used to enforce document-level security tokens
@@ -215,22 +214,35 @@ class AzureAISearchVectorStoreDocumentFilter(VectorStoreDocumentFilter):
             value = [self.escape_string(v) if type(v) is str else v for v in value]
         return value
 
-    def choose_separator(self, list_of_strings: List[str], num_tries: int=100) -> str:
-        """ Generate a string separator that is not part of the values we search for
+    @staticmethod
+    def choose_separator(list_of_strings: List[str]) -> str:
+        """ Find separator outside of list of string characters
+            https://learn.microsoft.com/en-us/azure/search/search-query-odata-search-in-function
+            Delimiters are not a single separator but a list of possible separators. Therefore, we
+            try to find one "complex" character that is not in the list of strings
         """
-        if num_tries == 0:
-            raise RuntimeError("failed to generate a separator that is not part of the search query")
-        separator = ''.join(random.choice('-_~+=#') for _ in range(3))
-        if separator in ''.join(list_of_strings):
-            return self.choose_separator(list_of_strings, num_tries-1)
-        else:
-            return separator
+        allowed_separators = '|;~^ ,'
+        # Check all combined strings once
+        full_string = ''.join(list_of_strings)
+        for separator in allowed_separators:
+            if separator not in full_string:
+                return separator
+
+        raise RuntimeError("failed to generate a separator that is not part of the search query")
 
     def convert(self, clause: Dict) -> str:
         if clause["operator"] == "EQUALS":
-            return f'({clause["column"]} eq {self._coerce_value(clause)})'
+            column_type = self._get_column_type(clause)
+            if column_type == ColumnType.BagOfWords: # 'ARRAY_CONTAINS' clause
+                return f'{clause["column"]}/any(v: v eq \'{self.escape_string(clause["value"])}\')'
+            else:
+                return f'({clause["column"]} eq {self._coerce_value(clause)})'
         elif clause["operator"] == "NOT_EQUALS":
-            return f'({clause["column"]} ne {self._coerce_value(clause)})'
+            column_type = self._get_column_type(clause)
+            if column_type == ColumnType.BagOfWords: # Not 'ARRAY_CONTAINS' clause
+                return f'not {clause["column"]}/any(v: v eq \'{self.escape_string(clause["value"])}\')'
+            else:
+                return f'({clause["column"]} ne {self._coerce_value(clause)})'
         elif clause["operator"] == "GREATER_THAN":
             return f'({clause["column"]} gt {self._coerce_value(clause)})'
         elif clause["operator"] == "LESS_THAN":
@@ -251,6 +263,11 @@ class AzureAISearchVectorStoreDocumentFilter(VectorStoreDocumentFilter):
                 list_of_numbers = super()._coerce_value(clause)
                 values = [f'({clause["column"]} eq {v})' for v in list_of_numbers]
                 return '(' + ' or '.join(values) + ')'
+            elif column_type == ColumnType.BagOfWords:
+                list_of_strings = self._coerce_value(clause)
+                separator = self.choose_separator(list_of_strings)
+                values = separator.join(list_of_strings)
+                return f"{clause['column']}/any(t: search.in(t, '{values}', '{separator}'))"
             else:
                 raise self._unsupported_type_for_operator(column_type, clause['operator'])
         elif clause["operator"] == "IN_NONE_OF":
@@ -264,6 +281,11 @@ class AzureAISearchVectorStoreDocumentFilter(VectorStoreDocumentFilter):
                 list_of_numbers = super()._coerce_value(clause)
                 values = [f'({clause["column"]} ne {v})' for v in list_of_numbers]
                 return '(' + ' and '.join(values) + ')'
+            elif column_type == ColumnType.BagOfWords:
+                list_of_strings = self._coerce_value(clause)
+                separator = self.choose_separator(list_of_strings)
+                values = separator.join(list_of_strings)
+                return f"{clause['column']}/all(t: not search.in(t, '{values}', '{separator}'))"
             else:
                 raise self._unsupported_type_for_operator(column_type, clause['operator'])
         elif clause["operator"] == "CONTAINS":
@@ -301,17 +323,19 @@ class AzureAISearchVectorStoreDocumentFilter(VectorStoreDocumentFilter):
         }
 
 
-def get_azure_data_type(dss_storage_type: str, column_name: str) -> SearchFieldDataType:
+def get_azure_data_type(dss_storage_type: str, column_name: str, column_meaning: str) -> SearchFieldDataType:
     # Maps a dss storage type to an Azure SearchFieldDataType
     # The list of DSS storage types is in the Java class: com.dataiku.dip.datasets.Type
     # The list of Azure data types: https://learn.microsoft.com/en-us/dotnet/api/azure.search.documents.indexes.models.searchfielddatatype?view=azure-dotnet#properties
+    if column_meaning == "BagOfWordsMeaning":
+        return SearchFieldDataType.Collection(SearchFieldDataType.String)
     if dss_storage_type == "string":
         return SearchFieldDataType.String
     elif dss_storage_type in ["date", "dateandtime", "dateonly"]:
         return SearchFieldDataType.DateTimeOffset
     elif dss_storage_type in ["geopoint", "geometry"]:
         return SearchFieldDataType.String # Not using Azure's geometry type because this would require converting the data into Azure's format
-    elif dss_storage_type in ["array", "map", "object"]:
+    elif dss_storage_type in ["map", "object", "array"]:
         # TODO @azureai-filtering Possibly add schema for complex fields (NB: Needs Azure API version >= 2019-05-06)
         #  https://learn.microsoft.com/en-gb/azure/search/search-howto-complex-data-types?tabs=portal
         #  https://github.com/Azure/azure-sdk-for-python/tree/main/sdk/search/azure-search-documents#creating-an-index
