@@ -52,7 +52,7 @@ class DkuVectorStore:
         self.kb = kb
         self.exec_folder = exec_folder
 
-        self.metadata_column_type = {col["name"]: col["type"] for col in kb.get("metadataColumnsSchema", [])}
+        self.metadata_column_type_and_meaning = {col["name"]: (col["type"], col.get("meaning")) for col in kb.get("metadataColumnsSchema", [])}
         self.source_id_column = kb.get("sourceIdColumn")  # Can be None, if not in a smart update mode
         self.document_filter = None
         self.total_added_documents = None # number of chunks added in overwrite mode (embed dataset only)
@@ -144,26 +144,29 @@ class DkuVectorStore:
     def _prepare_and_clean_metadata(self, document):
         new_meta = {}
         for key, val in document.metadata.items():
-            if pd.isna(val):
+            if isinstance(val, list):
+                if len(val) == 0:
+                    continue
+            elif pd.isna(val):
                 # Removing the empty metadata field all-together to stay aligned and safe with all vector stores.
                 continue
-            column_type = self.metadata_column_type.get(key)
-            if column_type is None:
-                new_meta[key] = val
-            elif column_type in ["bigint", "int", "smallint", "tinyint"]:
-                # Casting to int since if a single value is missing on an int column, panda will make the whole column float.
-                new_meta[key] = int(val)
-            elif column_type == "string":
-                # Casting to string for vector stores like azure ai that when given an int on a str column will throw an error.
-                new_meta[key] = str(val)
-            elif column_type in ["date", "datetimetz", "datetimenotz", "dateonly"] and isinstance(val, pd.Timestamp):
-                # Converting to string to avoid issues with vector stores that don't support pandas.Timestamp and for later serialisation
-                new_meta[key] = self.process_timestamp(val)
-            else:
-                new_meta[key] = val
+            storage_type, meaning = self.metadata_column_type_and_meaning.get(key, (None, None))
+            self._process_metadata_entry(new_meta, key, val, storage_type, meaning)
         document.metadata = new_meta
         return document
 
+    def _process_metadata_entry(self, new_meta, key, val, storage_type, meaning):
+        if storage_type in ["bigint", "int", "smallint", "tinyint"]:
+            # Casting to int since if a single value is missing on an int column, panda will make the whole column float.
+            val = int(val)
+        elif storage_type == "string" and meaning != "BagOfWordsMeaning":
+            # Casting to string for vector stores like azure ai that when given an int on a str column will throw an error.
+            val = str(val)
+        elif storage_type in ["date", "datetimetz", "datetimenotz", "dateonly"] and isinstance(val, pd.Timestamp):
+            # Converting to string to avoid issues with vector stores that don't support pandas.Timestamp and for later serialisation
+            val = self.process_timestamp(val)
+        new_meta[key] = val
+
     def process_timestamp(self, value: pd.Timestamp) -> str:
         return value.isoformat()
 
@@ -539,6 +542,9 @@ class DkuVectorStore:
         logger.info("Retrieved vector size for LLM id {}: {}".format(self.kb["embeddingLLMId"], model_embedding_size))
         return model_embedding_size
 
+    def get_document_metadata(self, document: "Document", column: str) -> Optional[Any]:
+        return document.metadata.get(column, None)
+
 
 class DkuLocalVectorStore(DkuVectorStore):
 
@@ -728,6 +734,10 @@ class VectorStoreFactory:
             from dataiku.core.vector_stores.qdrant_local_vector_store import QDrantLocalVectorStore
             return QDrantLocalVectorStore(kb, exec_folder)
 
+        elif vector_store_type == "MILVUS_LOCAL":
+            from dataiku.core.vector_stores.milvus_local_vector_store import MilvusLocalVectorStore
+            return MilvusLocalVectorStore(kb, exec_folder)
+
         else:
             raise NotImplementedError("Requested vector store type invalid: {}".format(vector_store_type))
 
