@@ -456,6 +456,10 @@ app.controller("_AdminCodeEnvsAutomationEditController", function($scope, $contr
         }).error(setErrorInScope.bind($scope));
     }
 
+    $scope.showResourcesTab = function() {
+        return ($scope.appConfig.admin && $scope.isInternalCodeEnv()) || !['EXTERNAL_CONDA_NAMED', 'DSS_INTERNAL'].includes($scope.codeEnv?.deploymentMode);
+    };
+
     $scope.updateEnvVersion = function(upgradeAllPackages, forceRebuildEnv, updateResources, versionToUpdate) {
         var updateSettings = {
             upgradeAllPackages: upgradeAllPackages,
@@ -556,7 +560,7 @@ app.controller("AdminCodeEnvsAutomationREditController", function($scope, $contr
     $controller("_AdminCodeEnvsAutomationEditController", {$scope:$scope});
 });
 
-app.directive('pythonVersion', function(DataikuAPI, $state, $stateParams, $rootScope, Deprecation) {
+app.directive('pythonVersion', function(DataikuAPI, $state, $stateParams, $rootScope, Deprecation, PandasSupport) {
     return {
         restrict : 'A',
         templateUrl : '/templates/admin/code-envs/automation/python-version.html',
@@ -626,6 +630,7 @@ app.directive('pythonVersion', function(DataikuAPI, $state, $stateParams, $rootS
             }
             
             $scope.isPythonDeprecated = Deprecation.isPythonDeprecated;
+            $scope.corePackagesVersions = PandasSupport.listSupportedVersions($scope.version.desc.pythonInterpreter, $scope.version.desc.corePackagesSet);
         }
     };
 });
