@@ -19,6 +19,21 @@ app.controller('AgentToolController', function ($scope, $state, $stateParams, $q
         return $scope.agentTool.type === 'InlinePython';
     }
 
+    // keep in sync with LLMClient.AgentToolOutputImageHandlingMode
+    $scope.imageHandlingModes = [{
+        id: "ONLY_ADD_AS_ARTIFACT",
+        label: "Only add as artifact",
+    }, {
+        id: "ONLY_SEND_TO_LLM",
+        label: "Only send to LLM/Agent",
+    }, {
+        id: "ADD_AS_ARTIFACT_AND_SEND_TO_LLM",
+        label: "Add as artifact and send to LLM/Agent",
+    }, {
+        id: "IGNORE",
+        label: "Ignore images",
+    }]
+
     $scope.editorOptions = CodeBasedEditorUtils.editorOptions('text/x-python', $scope, true);
     CodeBasedEditorUtils.registerBroadcastSelectionHandler($scope.editorOptions);
     CodeBasedEditorUtils.setRecipeScript($scope.script);
@@ -1375,11 +1390,11 @@ app.directive('agentToolRightColumnSummary', function($controller, $state, $stat
 
 
             /** Custom fields from plugins **/
-            scope.editCustomFields = function() {
+            scope.editCustomFields = function(editingTabIndex = 0) {
                 if (!scope.agentTool) {
                     return;
                 }
-                let modalScope = angular.extend(scope, {objectType: 'AGENT_TOOL', objectName: scope.agentTool.name, objectCustomFields: scope.agentTool.customFields});
+                let modalScope = angular.extend(scope, {objectType: 'AGENT_TOOL', objectName: scope.agentTool.name, objectCustomFields: scope.agentTool.customFields, editingTabIndex});
                 CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(newCustomFields) {
                     WT1.event('custom-fields-save', {objectType: 'AGENT_TOOL'});
                     const oldCustomFields = angular.copy(scope.agentTool.customFields);
