@@ -242,10 +242,10 @@ app.controller("AnalysisCoreController", function($scope, $stateParams, $rootSco
             });
     };
 
-    $scope.editCustomFields = function() {
+    $scope.editCustomFields = function(editingTabIndex = 0) {
         DataikuAPI.analysis.getSummary($stateParams.projectKey, $stateParams.analysisId).success(function(data) {
             let analysisCoreParams = data.object;
-            let modalScope = angular.extend($scope, {objectType: 'ANALYSIS', objectName: analysisCoreParams.name, objectCustomFields: analysisCoreParams.customFields});
+            let modalScope = angular.extend($scope, {objectType: 'ANALYSIS', objectName: analysisCoreParams.name, objectCustomFields: analysisCoreParams.customFields, editingTabIndex});
             CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(customFields) {
                 $scope.saveCustomFields(analysisCoreParams, customFields);
             });
