@@ -53,11 +53,15 @@
 
             if (Object.values($scope.modelData.preprocessing.per_feature).some(f => f.role === "INPUT")) {
                 $scope.hasExternalFeatures = true;
-                DataikuAPI.ml.prediction.getForecasts($scope.modelData.fullModelId)
-                    .then(function(res) {
-                        $scope.initFilter(Object.keys(res['data']['perTimeseries']))
-                    })
-                    .catch(setErrorInScope.bind($scope));
+                // Assuming that models supporting external features also support known in advance features
+                $scope.algoIncompatibleWithExternalFeatures = TimeseriesForecastingUtils.ALGOS_WITHOUT_EXTERNAL_FEATURES.names.includes($scope.modelData.modeling.algorithm);
+                if (!$scope.algoIncompatibleWithExternalFeatures) {
+                    DataikuAPI.ml.prediction.getForecasts($scope.modelData.fullModelId)
+                        .then(function(res) {
+                            $scope.initFilter(Object.keys(res['data']['perTimeseries']))
+                        })
+                        .catch(setErrorInScope.bind($scope));
+                }
             }
             deregister();
         });
