@@ -15,8 +15,10 @@
             columnNumber: '<', // number
             showGrid: '<', // boolean
             isInGroupTile: '<', // boolean
+            groupTileId: '<', // string | undefined
             tiles: '<', // DashboardTile[]
             page: '<', // DashboardPage
+            pageIdx: '<',
             preselectedTile: '<', // DashboardTile
             autoStackUp: '<', // boolean
             canExportDatasets: '<', // boolean
@@ -31,6 +33,7 @@
             filtersChange: '&', // ({ $filters }) => void
             filtersParamsChange: '&', // ({ $filtersParams }) => void,
             raiseError: '&', // ({ $errorData }) => void,
+            titleChange: '&',
             isDeactivatedChange: '&', // ({ $isDeactivated }) => void
             preselectedTileChange: '&', // ({ $preselectedTile }) => void
             gridInit: '&', // ({$api: { reload: () => void }}),
@@ -39,7 +42,7 @@
             onAddElementClick: '&' // () => void
         },
         templateUrl: '/static/dataiku/js/dashboards/components/dashboard-grid/dashboard-grid.component.html',
-        controller: function(DashboardFilters, $timeout, $rootScope, DashboardUtils, DashboardPageUtils, TileLoadingState, TileLoadingBehavior, $element, $scope, $q, ContextualMenu, TileUtils, LinkedList, DetectUtils, Debounce, WT1, Logger, translate) {
+        controller: function(DashboardFilters, $timeout, $rootScope, DashboardUtils, DashboardPageUtils, TileLoadingState, TileLoadingBehavior, $element, $scope, $q, ContextualMenu, TileUtils, LinkedList, DetectUtils, WT1, Logger, translate, DashboardGridElementService, GridIdService) {
             const ctrl = this;
 
             /*
@@ -75,7 +78,8 @@
             const selectedTileIds = new Set();
             const initializedTileIds = new Set();
             let scrollingContainer = null;
-            let resizeObserver = null;
+            let unobservePageInnerGridElementResize = null;
+            let gridScrollingContainerResizeSubscription = null;
             let grid = null;
             // Flags used to track the selection mode of the tiles for WT1 events
             let hasUsedRectangleSelection = false;
@@ -93,14 +97,14 @@
 
             ctrl.$onInit = function() {
                 ctrl.hook = {
-                    loadPromises : {},
-                    reloadPromises : {},
+                    loadPromises: {},
+                    reloadPromises: {},
                     loadStates: {},
                     visibleStates: {},
                     adjacentStates: {},
-                    isErrorMap : ctrl.isErrorMap,
-                    setErrorInDashboardPageScope : function(data, status, headers, config, statusText) {
-                        ctrl.raiseError({ $errorData : { data, status, headers, config, statusText } });
+                    isErrorMap: ctrl.isErrorMap,
+                    setErrorInDashboardPageScope: function(data, status, headers, config, statusText) {
+                        ctrl.raiseError({ $errorData: { data, status, headers, config, statusText } });
                     },
                     editable: ctrl.editable
                 };
@@ -114,6 +118,11 @@
             };
 
             ctrl.$onChanges = function(changes) {
+                if (!ctrl.isInGroupTile && changes.tiles) {
+                    ctrl.showEmptyState = (
+                        !ctrl.page.grid.tiles.filter(tile => !TileUtils.isTitleTile(tile)).length
+                    );
+                }
                 if (changes.tiles && ctrl.tiles != null) {
                     for (const tile of ctrl.tiles) {
                         tile.$tileId = tile.$tileId != null ? tile.$tileId : TileUtils.getUniqueTileId();
@@ -160,7 +169,7 @@
                     }
                 }
                 if (ctrl.gridListRendered &&
-                        ((changes.minHeight && !changes.minHeight.isFirstChange()) ||
+                    ((changes.minHeight && !changes.minHeight.isFirstChange()) ||
                         (changes.tileSpacing && !changes.tileSpacing.isFirstChange()) ||
                         (changes.padding && !changes.padding.isFirstChange()) ||
                         (changes.minNumberOfRows && !changes.minNumberOfRows.isFirstChange()))) {
@@ -270,6 +279,14 @@
                 }
             });
 
+            $scope.$on('dashboardRemoveTile', (_, tile) => {
+                ctrl.deleteTile(tile);
+            });
+
+            $scope.$on('dashboardMoveAndResizeTile', (_, { tile, newBox }) => {
+                moveAndResizeTile(tile, newBox);
+            });
+
             $scope.$on('dashboardSaved', () => {
                 if (ctrl.gridListRendered) {
                     grid.captureItemSizeAndPositionSnapshot();
@@ -398,7 +415,7 @@
             };
 
             ctrl.handleTileMouseDown = function(tile, event) {
-                if (!tile.locked || DashboardPageUtils.isPerformingDradAngDropWithinTile(event.target)) {
+                if (!tile.locked || DashboardPageUtils.isPerformingDradAngDropWithinTile(event.target) || TileUtils.isTitleTile(tile)) {
                     return;
                 }
                 event.preventDefault();
@@ -528,7 +545,7 @@
             };
 
             ctrl.scrollToTile = function(tile) {
-                return ctrl.editable && tile.$added && ctrl.isTileSelected(tile) && ctrl.currentGroupTileIdInEditMode == null ;
+                return ctrl.editable && tile.$added && ctrl.isTileSelected(tile) && ctrl.currentGroupTileIdInEditMode == null;
             };
 
             function stackGroupTileChildrenUp(groupTile) {
@@ -864,7 +881,7 @@
                 $scope.$emit('dashboardOpenMoveCopyTileModal', { tile });
             }
 
-            function hasMultipleTilesSelected(){
+            function hasMultipleTilesSelected() {
                 return selectedTileIds.size > 1;
             }
 
@@ -872,6 +889,17 @@
                 return ctrl.tiles.filter(tile => selectedTileIds.has(tile.$tileId));
             }
 
+            function moveAndResizeTile(tile, newBox) {
+                const el = $('[data-id=' + tile.$tileId + ']');
+                grid.moveAndResizeItem($(el), {
+                    x: newBox.left,
+                    y: newBox.top,
+                    w: newBox.width,
+                    h: newBox.height
+                });
+                syncTilesFromGridDeletionsAndMoves();
+            };
+
             function deleteTiles(tiles) {
                 tiles.forEach(tile => {
                     const el = $('[data-id=' + tile.$tileId + ']');
@@ -900,8 +928,11 @@
                 if (tileVisibilityObserver != null) {
                     tileVisibilityObserver.disconnect();
                 }
-                if (resizeObserver != null) {
-                    resizeObserver.disconnect();
+                if (unobservePageInnerGridElementResize !== null) {
+                    unobservePageInnerGridElementResize();
+                }
+                if (gridScrollingContainerResizeSubscription != null) {
+                    gridScrollingContainerResizeSubscription.unsubscribe();
                 }
                 if (unregisterDashboardUnselectTilesEvent != null) {
                     unregisterDashboardUnselectTilesEvent();
@@ -991,7 +1022,14 @@
                 if (tiles == null || tiles.length === 0 || tileElements == null || tileElements.length !== tiles.length) {
                     return Promise.resolve();
                 }
-                tiles.forEach((tile, i) => {
+
+                const selectableTiles = tiles.filter(tile => !TileUtils.isTitleTile(tile));
+
+                if (selectableTiles.length === 0) {
+                    return;
+                }
+
+                selectableTiles.forEach((tile, i) => {
                     const tileElement = tileElements[i];
                     const tileWrapper = DashboardPageUtils.getTileWrapperFromElement(tileElement);
                     if (ctrl.isTileSelected(tile)) {
@@ -1005,19 +1043,19 @@
                 });
                 hasUsedMultiSelectKey = isMultiSelectKeyPressed;
                 const tilesById = getTilesById();
-                if (tiles.length === 1) {
+                if (selectableTiles.length === 1) {
                     if (isMultiSelectKeyPressed) {
                         // it might unselect tile if already selected
-                        if (selectedTileIds.has(tiles[0].$tileId)) {
-                            selectedTileIds.delete(tiles[0].$tileId);
+                        if (selectedTileIds.has(selectableTiles[0].$tileId)) {
+                            selectedTileIds.delete(selectableTiles[0].$tileId);
                         } else {
-                            selectedTileIds.add(tiles[0].$tileId);
+                            selectedTileIds.add(selectableTiles[0].$tileId);
                         }
                     } else {
                         // Here one single tile is selected by a single click
                         hasUsedRectangleSelection = false;
                         selectedTileIds.clear();
-                        selectedTileIds.add(tiles[0].$tileId);
+                        selectedTileIds.add(selectableTiles[0].$tileId);
                     }
                     if (selectedTileIds.size === 0) {
                         return $timeout(() => {
@@ -1031,9 +1069,9 @@
                     }
                 } else {
                     selectedTileIds.clear();
-                    tiles.forEach(tile => selectedTileIds.add(tile.$tileId));
+                    selectableTiles.forEach(tile => selectedTileIds.add(tile.$tileId));
                     return $timeout(() => {
-                        $rootScope.$emit('dashboardSelectTiles', { tiles, grid });
+                        $rootScope.$emit('dashboardSelectTiles', { tiles: selectableTiles, grid });
                     });
                 }
             };
@@ -1045,7 +1083,7 @@
                 $rootScope.$emit('dashboardUnselectTiles');
             };
 
-            function ignoreTileSelectionClick(event){
+            function ignoreTileSelectionClick(event) {
                 return (!ctrl.editable && ctrl.isInGroupTile) ||
                     event.target.hasAttribute('dashboard-no-select') ||
                     event.target.closest('[dashboard-no-select]') !== null;
@@ -1055,7 +1093,7 @@
                 return DetectUtils.getOS() === 'macos' ? !!event.metaKey : !!event.ctrlKey;
             }
 
-            function ignoreMainGridClick(event){
+            function ignoreMainGridClick(event) {
                 return ctrl.isInGroupTile || isMultiSelectKeyPressed(event) ||
                     (!event.target.classList.contains('grid-display') && !event.target.classList.contains('dashboard-grid'));
             }
@@ -1066,7 +1104,7 @@
                         if (!tile.locked) {
                             return;
                         }
-                        if (TileUtils.isGroupTile(tile) && ignoreGroupTiles) {
+                        if (TileUtils.isTitleTile(tile) || TileUtils.isGroupTile(tile) && ignoreGroupTiles) {
                             return;
                         }
                         if (showLockedOverlay) {
@@ -1078,7 +1116,7 @@
             }
 
             function toggleLockedOverlayOnTile(tile, showLockedOverlay) {
-                if (showLockedOverlay === tile.$showLockedOverlay) {
+                if (TileUtils.isTitleTile(tile) || showLockedOverlay === tile.$showLockedOverlay) {
                     return;
                 }
                 $timeout(() => {
@@ -1117,13 +1155,21 @@
                 }
             }
 
-            const dispatchDebouncedResize = Debounce().withDelay(50, 50).wrap(() => {
-                $timeout(() => {
-                    window.dispatchEvent(new Event('resize'));
-                });
-            });
+            ctrl.$postLink = function() {
+                scrollingContainer = getScrollingContainer();
+                if (unobservePageInnerGridElementResize === null) {
+                    unobservePageInnerGridElementResize = DashboardGridElementService.observePageInnerGridElementResize({
+                        gridId: GridIdService.create({
+                            dashboardPageCid: ctrl.page.cid,
+                            tileId: ctrl.groupTileId
+                        }),
+                        innerGridElement: DashboardGridElementService.get($element[0])
+                    });
+                }
+            };
 
             function initGrid() {
+                $rootScope.$broadcast('gridListRenderingStarted');
                 ctrl.gridContainer = $($element.find('.dashboard-grid').addBack('.dashboard-grid')); //addBack to add self
                 /*
                  * Instantiating gridList
@@ -1140,15 +1186,15 @@
                     }
                 };
                 $timeout(() => {
+
                     if ($scope.$$destroyed) {
                         return;
                     }
 
-                    scrollingContainer = getScrollingContainer();
                     grid = ctrl.gridContainer.gridList(
                         {
                             lanes: ctrl.columnNumber,
-                            cellSizeMatchCustomHeight: ctrl.minHeight != null ? ctrl.minHeight + ctrl.tileSpacing - ctrl.padding * 2: false,
+                            cellSizeMatchCustomHeight: ctrl.minHeight != null ? ctrl.minHeight + ctrl.tileSpacing - ctrl.padding * 2 : false,
                             numberOfCellsMatchingCustomHeight: ctrl.minNumberOfRows != null ? ctrl.minNumberOfRows : false,
                             addExtraGridSpaceBelow: ctrl.addExtraGridSpaceBelow,
                             autoStackUp: ctrl.autoStackUp,
@@ -1261,7 +1307,7 @@
                                 selectTiles([draggedTile], [event.target], false);
 
                                 // Avoid group tile to enter in edit mode after performing the D&D
-                                event.target.setAttribute('dashboard-no-select','');
+                                event.target.setAttribute('dashboard-no-select', '');
 
                                 // Avoid deselecting child group tile when cursor is moving out of the group tile
                                 blockTileDeselection = true;
@@ -1359,8 +1405,9 @@
 
                     if (!ctrl.isInGroupTile && !$scope.$$destroyed) {
                         scrollingContainer.addEventListener('wheel', handleShiftWheelScroll, { passive: false });
-                        resizeObserver = new ResizeObserver(() => dispatchDebouncedResize(), { box: 'border-box' });
-                        resizeObserver.observe(scrollingContainer);
+                        gridScrollingContainerResizeSubscription = DashboardGridElementService.getPageInnerGridResizedWithThrottle$(50).subscribe(() => {
+                            window.dispatchEvent(new Event('resize'));
+                        });
                     }
                     return syncTilesFromGridDeletionsAndMoves();
                 });
@@ -1466,7 +1513,7 @@
              * Returns tile by id index
              * @return {Record<string, Tile>} tile by id index
              */
-            function getTilesById(){
+            function getTilesById() {
                 return Object.fromEntries(ctrl.tiles.map(tile => [tile.$tileId, tile]));
             }
 
