@@ -8,6 +8,23 @@
         return insight.params && insight.params.def && insight.params.def.facetDimension && insight.params.def.facetDimension.length > 0;
     };
 
+    const getDefaultTileParams = function(insight) {
+        return {
+            showXAxis: true,
+            showXAxisTitle: true,
+            showYAxis: true,
+            showYAxisTitle: true,
+            showLegend: false,
+            showBrush: false,
+            showBreadcrumb: true,
+            inheritLegendPlacement: true,
+            showTooltips: true,
+            autoPlayAnimation: true,
+            legendPlacement: insight.params && insight.params.def.legendPlacement,
+            useInsightTheme: false
+        };
+    };
+
     app.constant('ChartInsightHandler', {
         name: 'Chart',
         desc: 'Visualize data from your source',
@@ -25,20 +42,7 @@
         },
         hasEditTab: true,
         goToEditAfterCreation: true,
-        getDefaultTileParams: function(insight) {
-            return {
-                showXAxis: true,
-                showYAxis: true,
-                showLegend: false,
-                showBrush: false,
-                showBreadcrumb: true,
-                inheritLegendPlacement: true,
-                showTooltips: true,
-                autoPlayAnimation: true,
-                legendPlacement: insight.params && insight.params.def.legendPlacement,
-                useInsightTheme: false
-            };
-        },
+        getDefaultTileParams,
         getDefaultTileDimensions(insight) {
             if (insight && hasFacetDimension(insight)) {
                 return [15, 12];
@@ -72,6 +76,8 @@
                     edit: true
                 };
 
+                $scope.tile.tileParams = { ...getDefaultTileParams($scope.insight), ...$scope.tile.tileParams };
+
                 $controller('ChartInsightViewCommon', { $scope });
 
                 $scope.initChartCommonScopeConfig($scope);
@@ -559,11 +565,16 @@
                     }
                     const isFirstChange = nv === ov;
 
-                    $scope.noXAxis = !nv.showXAxis;
-                    $scope.noYAxis = !nv.showYAxis;
-                    $scope.noTooltips = !nv.showTooltips;
-                    $scope.noBreadcrumb = !nv.showBreadcrumb;
-                    $scope.autoPlayAnimation = nv.autoPlayAnimation;
+                    $scope.chartTileProperties = {
+                        showXAxis: _.isNil(nv.showXAxis) || nv.showXAxis,
+                        showYAxis: _.isNil(nv.showYAxis) || nv.showYAxis,
+                        showXAxisTitle: _.isNil(nv.showXAxisTitle) || nv.showXAxisTitle,
+                        showYAxisTitle: _.isNil(nv.showYAxisTitle) || nv.showYAxisTitle,
+                        showTooltips: _.isNil(nv.showTooltips) || nv.showTooltips,
+                        showBreadcrumb: _.isNil(nv.showBreadcrumb) || nv.showBreadcrumb,
+                        showBrush: !!nv.showBrush,
+                        autoPlayAnimation: nv.autoPlayAnimation
+                    };
 
                     if ($scope.chart && (isFirstChange || nv.useInsightTheme !== ov.useInsightTheme)) {
 
@@ -625,8 +636,6 @@
                             $scope.chart.def.legendPlacement = $scope.tile.tileParams.legendPlacement ? $scope.tile.tileParams.legendPlacement : $scope.chart.def.originLegendPlacement;
                         }
                     }
-                    $scope.chart.def.showXAxis = $scope.tile.tileParams.showXAxis;
-                    $scope.chart.def.linesZoomOptions.displayBrush = $scope.tile.tileParams.showBrush;
                 }
 
                 function resetChartDef() {
@@ -686,6 +695,8 @@
 
                 $scope.$watch('insight.params.def', (def) => {
                     $scope.canDisplayBrush = ChartFeatures.canDisplayBrush(def);
+                    $scope.canDisplayXAxisTitle = ChartFeatures.canShowXAxisTitle(def);
+                    $scope.canDisplayYAxisTitle = ChartFeatures.canShowYAxisTitle(def.type);
 
                     const hierarchiesInChart = ChartHierarchyDimension.getHierarchyDimensionsForChartType(def);
                     $scope.canDisplayBreadcrumb = ChartFeatures.canDisplayBreadcrumb(def.type) && !!hierarchiesInChart.length;
@@ -755,11 +766,6 @@
 
         $scope.validity = {}; // Needed by chart redraw
 
-        if ($scope.tile) {
-            $scope.chart.def.showLegend = $scope.tile.tileParams.showLegend;
-            $scope.chart.def.showXAxis = $scope.tile.tileParams.showXAxis;
-        }
-
         $scope.saveChart = function() {
             DataikuAPI.dashboards.insights.save($scope.insight)
                 .error(setErrorInScope.bind($scope))
@@ -777,6 +783,19 @@
             };
         };
 
+        $scope.getLLMChartContext = function() {
+            return {
+                context: 'shaker',
+                datasetProjectKey: $scope.resolvedDataset.projectKey,
+                spec: $scope.getDataSpec(),
+                datasetName: $scope.resolvedDataset.datasetName,
+                getSuggestionsCacheKey(chartDefCacheKey) {
+                    return chartDefCacheKey ? $scope.resolvedDataset.projectKey + $scope.resolvedDataset.datasetName + chartDefCacheKey : $scope.resolvedDataset.projectKey + $scope.resolvedDataset.datasetName;
+                }
+
+            };
+        };
+
         $scope.getExecutePromise = function(request, saveShaker=false, noSpinner=true, requiredSampleId=undefined, dataSpec=$scope.getDataSpec()) {
             if (request) {
                 if (requiredSampleId === undefined) {
@@ -854,7 +873,6 @@
                 $scope.readOnly = true;
                 $scope.bigChart = true;
                 $scope.bigChartDisabled = true;
-                $scope.showLegends = true;
                 $scope.saveChart = function() {};
 
                 $scope.fetchColumnsSummary().then(function(){
