@@ -89,11 +89,11 @@
                 });
         };
 
-        $scope.editCustomFields = function() {
+        $scope.editCustomFields = function(editingTabIndex = 0) {
             if (!$scope.insight) {
                 return;
             }
-            const modalScope = angular.extend($scope, { objectType: 'INSIGHT', objectName: $scope.insight.name, objectCustomFields: $scope.insight.customFields });
+            const modalScope = angular.extend($scope, { objectType: 'INSIGHT', objectName: $scope.insight.name, objectCustomFields: $scope.insight.customFields, editingTabIndex });
             CreateModalFromTemplate('/templates/taggable-objects/custom-fields-edit-modal.html', modalScope).then(function(customFields) {
                 $scope.saveCustomFields(customFields);
             });
