@@ -6,6 +6,8 @@
     app.constant('ModelEvaluationReportInsightHandler', {
         name: 'Model evaluation report',
         desc: 'Full report of a model evaluation',
+        i18nNameKey: 'INSIGHTS.MODEL_EVALUATION_REPORT.NAME',
+        i18nDescKey: 'INSIGHTS.MODEL_EVALUATION_REPORT.DESC',
         icon: 'icon-model-evaluation-store',
         color: 'model-evaluation-store',
         getSourceId: function(insight) {
@@ -53,8 +55,10 @@
                             $scope.evaluationId = data.evaluation.ref.evaluationId;
                             $scope.modelData = data.details;
                             const isLLMEvaluation = $scope.$modelEvaluation.evaluation && $scope.$modelEvaluation.evaluation.type === 'llm';
-                            if (isLLMEvaluation) {
-                                $controller('_LLMPredictionModelReportController', { $scope });
+                            const isAgentEvaluation = $scope.$modelEvaluation.evaluation && $scope.$modelEvaluation.evaluation.type === 'agent';
+                            const isGenAiEvaluation = isLLMEvaluation || isAgentEvaluation;
+                            if (isGenAiEvaluation){
+                                $controller('_GenAiPredictionModelReportController', { $scope , isLLMEvaluation, isAgentEvaluation});
                             } else {
                                 $controller('_PredictionModelReportController', { $scope });
                             }
@@ -111,6 +115,8 @@
                     }
                     $scope.insight.$evaluationDetails = nv;
                     $scope.insight.$isLLMEvaluation = nv.evaluation && nv.evaluation.type === 'llm';
+                    $scope.insight.$isAgentEvaluation = nv.evaluation && nv.evaluation.type === 'agent';
+                    $scope.insight.$isGenAiEvaluation = $scope.insight.$isLLMEvaluation || $scope.insight.$isAgentEvaluation;
                 });
 
                 if ($scope.tile.autoLoad) {
@@ -129,8 +135,16 @@
             return $scope.modelEvaluation && $scope.modelEvaluation.type === 'llm';
         };
 
+        $scope.isAgentEvaluation = function() {
+            return $scope.modelEvaluation && $scope.modelEvaluation.type === 'agent';
+        };
+
+        $scope.isGenAiEvaluation = function() {
+            return $scope.isLLMEvaluation() || $scope.isAgentEvaluation();
+        };
+
         const getSummarySuffix = () => {
-            return MLModelsUIRouterStates.getPredictionReportSummaryTab(false, $scope.isLLMEvaluation());
+            return MLModelsUIRouterStates.getPredictionReportSummaryTab(false, $scope.isGenAiEvaluation());
         };
 
         const updateUIRouterStateWithTarget = ({ stateName, stateParams }) => {
@@ -173,7 +187,7 @@
                 fromState,
                 fromParams,
                 '.insight.view',
-                `modelevaluations.prediction.${MLModelsUIRouterStates.getPredictionReportSummaryTab(false, $scope.isLLMEvaluation())}`,
+                `modelevaluations.prediction.${MLModelsUIRouterStates.getPredictionReportSummaryTab(false, $scope.isGenAiEvaluation())}`,
                 event
             );
 
@@ -215,9 +229,9 @@
         };
     });
 
-    app.directive('llmModelEvaluationReportInsightTileParams', function($controller, $timeout, DataikuAPI, FullModelLikeIdUtils, $q, ModelDataUtils, $stateParams) {
+    app.directive('genaiModelEvaluationReportInsightTileParams', function($controller, $timeout, DataikuAPI, FullModelLikeIdUtils, $q, ModelDataUtils, $stateParams) {
         return {
-            templateUrl: '/templates/dashboards/insights/model-evaluation_report/llm-model-evaluation_report_tile_params.html',
+            templateUrl: '/templates/dashboards/insights/model-evaluation_report/genai-model-evaluation_report_tile_params.html',
             scope: {
                 tileParams: '=',
                 insight: '='
@@ -233,7 +247,7 @@
 
                     $controller('ModelEvaluationReportViewCommon', { $scope: $scope });
 
-                    $controller('_LLMPredictionModelReportController', { $scope: $scope });
+                    $controller('_GenAiPredictionModelReportController', { $scope: $scope, isLLMEvaluation: $scope.insight.$isLLMEvaluation, isAgentEvaluation: $scope.insight.$isAgentEvaluation});
 
                     $timeout(function() {
                         $element.find('.view-select').selectpicker('refresh');
@@ -251,7 +265,8 @@
                         if (!nv) {
                             return;
                         }
-                        $scope.tileParams.$displayModeExtended = $scope.tileParams.displayMode || 'llm-summary';
+                        const defaultName = $scope.insight.$isLLMEvaluation ? 'llm-summary' : 'agent-summary';
+                        $scope.tileParams.$displayModeExtended = $scope.tileParams.displayMode || defaultName;
                         deregister();
                     });
                 });
@@ -259,7 +274,6 @@
         };
     });
 
-
     app.directive('modelEvaluationReportInsightTileParams', function($controller, $timeout, DataikuAPI, FullModelLikeIdUtils, $q, ModelDataUtils, $stateParams) {
         return {
             templateUrl: '/templates/dashboards/insights/model-evaluation_report/model-evaluation_report_tile_params.html',
@@ -404,17 +418,21 @@
         };
     });
 
-    app.directive('modelEvaluationReportInsightCreateForm', function(DataikuAPI) {
+    app.directive('modelEvaluationReportInsightCreateForm', function(translate) {
         return {
             templateUrl: '/templates/dashboards/insights/model-evaluation_report/model-evaluation_report_create_form.html',
             scope: true,
             link: function($scope, element, attrs) {
-                $scope.hook.defaultName = 'Model Evaluation table';
+                $scope.hook.defaultName = translate('DASHBOARD.NEW_TILE_MODAL.MODEL_EVALUATION_TABLE', 'Model Evaluation table');
                 $scope.$watch('hook.sourceObject', function(nv) {
                     if (!nv || !nv.label) {
                         return;
                     }
-                    $scope.hook.defaultName = nv.label + ' table';
+                    $scope.hook.defaultName = translate(
+                        'DASHBOARD.NEW_TILE_MODAL.MODEL_EVALUATION_TABLE',
+                        nv.label + ' table',
+                        { label: nv.label }
+                    );
                 });
             }
         };
