@@ -574,7 +574,8 @@ const app = angular.module('dataiku.datasets.directives', ['dataiku.filters', 'c
                 title: '@',
                 path: '=',
                 browseFn: '=',
-                validateFn: '=',
+                canSelectFn: '<?',
+                validateFn: '<?',
                 connection: '@',
                 changeNeedsConfirm: '='
             },
@@ -585,7 +586,16 @@ const app = angular.module('dataiku.datasets.directives', ['dataiku.filters', 'c
 
                 scope.navObj = {selectedItems: []};
                 scope.canBrowse = () => true;
-                scope.canSelect = () => true;
+                if (scope.canSelectFn) {
+                    scope.canSelect = scope.canSelectFn;
+                } else {
+                    scope.canSelect = () => true;
+                }
+
+                if (!scope.validateFn) {
+                    // default validate function
+                    scope.validateFn = () => {};
+                }
 
                 // -- browsing
 
@@ -625,7 +635,7 @@ const app = angular.module('dataiku.datasets.directives', ['dataiku.filters', 'c
         };
     });
 
-    app.directive('folderPathInput', (openDkuPopin, PathUtils) => {
+    app.directive('folderPathInput', (openDkuPopin, PathUtils, $timeout) => {
         return {
             restrict: 'E',
             replace: true,
@@ -649,8 +659,15 @@ const app = angular.module('dataiku.datasets.directives', ['dataiku.filters', 'c
             link: (scope, element, attrs) => {
                 scope.searchable = attrs.searchable ? scope.$eval(scope.searchable) : false;
                 scope.changeConfirmed = false;
-                const targetElement = element[0].querySelector('.browse-path-dropdown');
-                const template = $(targetElement).detach();
+
+                //Timeout used to make the folder exploration window appear in Angular (also compatible with AngularJS)
+                let popinTemplate;
+                $timeout(() => {
+                    const targetElement = element[0].querySelector('.browse-path-dropdown');
+                    if (targetElement) {
+                        popinTemplate = $(targetElement).detach();
+                    }
+                }, 0);
 
                 // -- file selection
 
@@ -661,7 +678,12 @@ const app = angular.module('dataiku.datasets.directives', ['dataiku.filters', 'c
 
                 scope.displayItem = item => scope.displayItemFn ? scope.displayItemFn(item) : item;
 
-                scope.inputEnabled = scope.inputEnabled ? scope.inputEnabled : () => true;
+                //inputEnabled is undefined when using this directive in Angular, hence the need for the isInputEnabled function below
+                const originalInputEnabledFn = scope.inputEnabled ? scope.inputEnabled : () => true;
+                scope.isInputEnabled = () => {
+                    const result = originalInputEnabledFn();
+                    return result === undefined ? true : result;
+                };
 
                 scope.currentFolder = scope.folder;
 
@@ -673,7 +695,12 @@ const app = angular.module('dataiku.datasets.directives', ['dataiku.filters', 'c
                     const isElsewhere = (tooltipElement, event) => $(event.target).parents('.browse-path-dropdown').length === 0 && $(event.target).parents('.browse-path-input').length === 0;
                     const onDismiss = () => scope.browseActive = false;
 
-                    scope.dismissPopin = openDkuPopin(scope, event, { popinPosition: 'SMART', arrow: false, doNotCompile: true, onDismiss, isElsewhere, template });
+                    if (!popinTemplate) {
+                        scope.browseActive = false;
+                        return;
+                    }
+
+                    scope.dismissPopin = openDkuPopin(scope, event, { popinPosition: 'SMART', arrow: false, doNotCompile: true, onDismiss, isElsewhere, template: popinTemplate });
                     if (scope.browseActive) {
                         if (scope.folder) {
                             scope.navObj.browsePath = scope.folder.id;
@@ -701,7 +728,7 @@ const app = angular.module('dataiku.datasets.directives', ['dataiku.filters', 'c
 
                 scope.browseDoneFn = folder => {
                     // show / if folder is root
-                    if (scope.showRootFolderPath && !folder.pathElts) {
+                    if (scope.showRootFolderPath && (!folder.pathElts || folder.pathElts === '')) {
                         folder.pathElts = '/';
                     }
 
@@ -1345,7 +1372,7 @@ app.directive('ellipsedList', [ '$window', '$timeout', function($window, $timeou
 }]);
 
 
-app.directive('datasetRightColumnSummary', function($controller, $stateParams, $state,
+app.directive('datasetRightColumnSummary', function($controller, $stateParams, $state, StateUtils, TopNav,
         DataikuAPI, CreateModalFromTemplate, GlobalProjectActions, QuickView, FlowGraphSelection, FlowBuildService,
         ActiveProjectKey, AnyLoc, ActivityIndicator, DatasetCustomFieldsService, $rootScope, SelectablePluginsService,
         DatasetRenameService, WT1, FlowGraph, translate, DataQualityComputationTrackingService, PluginCategoryService){
@@ -1406,6 +1433,13 @@ app.directive('datasetRightColumnSummary', function($controller, $stateParams, $
                 DatasetCustomFieldsService.saveCustomFields($scope.dataset, customFields);
             });
 
+            const customFieldsSavedEventSubscription = $rootScope.$on('customFieldsSaved', function(event, item, newCustomFields) {
+                if (TopNav.sameItem(TopNav.getItem(), item)) {
+                    $scope.datasetFullInfo.dataset.customFields = newCustomFields;
+                }
+            });
+            $scope.$on('$destroy', customFieldsSavedEventSubscription);
+
 
             $controller('_TaggableObjectsMassActions', { $scope });
             $controller('_TaggableObjectsCapabilities', { $scope });
@@ -1487,15 +1521,20 @@ app.directive('datasetRightColumnSummary', function($controller, $stateParams, $
                 }
                 if (!nv) return;
                 $scope.datasetType = nv.datasetType || nv.type;
-                if (nv.nodeType === 'FOREIGN_DATASET') {
+                if (nv.projectKey !== ActiveProjectKey.get()) {
+                    $scope.isLocalDataset = false;
                     $scope.datasetSmartName = nv.projectKey + '.' + nv.name;
                     $scope.datasetHref = $state.href('projects.project.foreigndatasets.dataset.explore',
                         {datasetFullName: $scope.datasetSmartName, projectKey: nv.projectKey});
                 } else {
+                    $scope.isLocalDataset = true;
                     $scope.datasetSmartName = nv.name;
                     $scope.datasetHref = $state.href('projects.project.datasets.dataset.explore',
                         {datasetName: nv.name, projectKey: nv.projectKey});
                 }
+
+                $scope.isInSelectedObjectPage = $state.includes('projects.project.datasets.dataset') || $state.includes('projects.project.foreigndatasets.dataset');
+                $scope.selectedObjectPageUrl = StateUtils.href.dataset($scope.datasetSmartName);
             });
 
             $scope.$watch("selection.confirmedItem", (nv) => {
@@ -1552,6 +1591,7 @@ app.directive('datasetRightColumnSummary', function($controller, $stateParams, $
                     });
                 }).error(setErrorInScope.bind($scope));
             };
+            $scope.saveCustomFields = DatasetCustomFieldsService.saveCustomFields;
 
             $scope.anyPipelineTypeEnabled = function() {
                 return $rootScope.projectSummary && ($rootScope.projectSummary.sparkPipelinesEnabled || $rootScope.projectSummary.sqlPipelinesEnabled);
