@@ -96,7 +96,7 @@ app.directive("foreignDatasetExplore", function($timeout, $q, Assert, DataikuAPI
 
             if (!$stateParams.fromFlow) {
                 // Do not change the focus item zoom if coming from flow
-                GraphZoomTrackerService.setFocusItemByFullName("dataset", $stateParams.datasetFullName);
+                GraphZoomTrackerService.setFocusItemByFullId("dataset", $stateParams.datasetFullName);
             }
 
             $scope.table = null;
