@@ -5,7 +5,7 @@ var app = angular.module('dataiku.datasets');
 
 
 // All Row-Oriented DS (including SQL)
-app.controller("BaseRowDatasetController", function($scope, LoggerProvider, DataikuAPI, DatasetUtils, WT1, withConsistency) {
+app.controller("BaseRowDatasetController", function($scope, LoggerProvider, DataikuAPI, DatasetUtils, WT1, withConsistency, ConnectionsService) {
     var Logger = LoggerProvider.getLogger('datasets.row');
 
     // Set error message when future are aborted
@@ -56,8 +56,7 @@ app.controller("BaseRowDatasetController", function($scope, LoggerProvider, Data
         $scope.saveDataset().then(function() {
             DataikuAPI.datasets.pushColumnDescriptionsToTable(
                 $scope.dataset,
-                $scope.consistency?.result?.newSchema?.columns,
-                $scope.consistency?.result?.detectedSchema?.columns,
+                $scope.consistency?.result?.newSchema?.columns
             ).success((resp) => {
                 $scope.warningMessages = resp?.anyMessage ? resp : null;
                 $scope.checkConsistency();
@@ -89,15 +88,7 @@ app.controller("BaseRowDatasetController", function($scope, LoggerProvider, Data
         $scope.checkConsistency();
     };
 
-    $scope.searchConnectionsWithDescriptions = function(term, connection) { // Connection should be as defined in ConnectionTypeAndName in java
-        if (connection.name.includes(term)) {
-            return true;
-        }
-        if (connection.description?.includes(term)) {
-            return true;
-        }
-        return false;
-    };
+    $scope.searchConnectionsWithDescriptions = ConnectionsService.searchConnectionsWithDescriptions;
 });
 
 
@@ -506,6 +497,151 @@ app.controller("ExternalCassandraDatasetController", function($scope, $controlle
     $controller("BaseCassandraDatasetController", {$scope: $scope});
 });
 
+app.controller("BaseIcebergDatasetController", function($scope, $stateParams, $controller, DataikuAPI, LoggerProvider, Dialogs, SqlConnectionNamespaceService) {
+    $controller("BaseRowDatasetController", {$scope: $scope, withConsistency: true});
+
+    var Logger = LoggerProvider.getLogger('datasets.iceberg');
+
+    // Finish dataset initialization if needed
+    if (! $scope.dataset.schema) {
+        $scope.dataset.schema = { columns: [] };
+    }
+
+    $scope.$watch('dataset.type', function (nv, ov) {
+        DataikuAPI.connections.getNames($scope.dataset.type).success(function (data) {
+            $scope.connections = data;
+            if (!$scope.dataset.params.connection && data.length) {
+                $scope.dataset.params.connection = data[0];
+                $scope.test(true, false);
+            }
+        }).error(setErrorInScope.bind($scope));
+    });
+
+    $scope.getAllTables = function(){
+        Dialogs.confirmUnsafeHTML($scope, "Really list all tables?",
+            "<p>This will list <strong>all tables in all schemas</strong> of your Iceberg catalog.</p>"+
+            "<p> On large entreprise databases, this is likely "+
+            "to be extremely long and to cause your browser to become unresponsive.</p>").then($scope.test.bind(this,false,true));
+    };
+
+    $scope.test = function (testTable, listTables) {
+        $scope.testing = true;
+        $scope.testResult = null;
+        $scope.schemaJustModified = false;
+        if (angular.isUndefined($scope.dataset.params.connection)) {
+            Logger.info('Not testable');
+            $scope.testing = false;
+            $scope.testResult = { connectionOK: false, connectionErrorMsg: "no connection defined" };
+            return;
+        }
+        DataikuAPI.datasets.iceberg.test($stateParams.projectKey, $scope.dataset, 15, listTables, testTable)
+            .success(function (data) {
+                Logger.info('Got test result');
+                $scope.testing = false;
+                $scope.testResult = data;
+                if (! $scope.dataset.managed && (!$scope.dataset.schema || !$scope.dataset.schema.columns || $scope.dataset.schema.columns.length == 0) && $scope.testResult.tableSchema) {
+                    // Overwrite schema using detected schema, if we have none
+                    $scope.dataset.schema = {
+                        userModified: false,
+                        columns: $scope.testResult.tableSchema.columns
+                    };
+                    $scope.testResult.schemaMatchesTable = true;
+
+                    $scope.suggestDatasetName($scope.testResult.suggestedName);
+                }
+            })
+            .error(function (data) { $scope.testing = false; });
+    };
+
+    $scope.overwriteSchemaFromTable = function () {
+        $scope.dataset.schema = {
+            userModified: false,
+            columns: $scope.testResult.tableSchema.columns
+        };
+        $scope.test(true, false);
+    };
+
+    $scope.onLoadComplete = function() {
+        if ($scope.$eval('dataset.params.connection')) {
+            $scope.test(true, false);
+        }
+    };
+
+    $scope.suggestDatasetName = function(name) {
+        if (!$scope.dataset.name && !$scope.uiState.new_dataset_name_manually_edited) {
+            $scope.uiState.new_dataset_name = name;
+        }
+    };
+
+    $scope.isPartitioned = function() {
+        return $scope.dataset && $scope.dataset.partitioning && $scope.dataset.partitioning.dimensions && $scope.dataset.partitioning.dimensions.length > 0;
+    };
+
+    $scope.setPartitioned = function(activate) {
+        $scope.dataset.partitioning = $scope.dataset.partitioning || {};
+        if (activate) {
+            DataikuAPI.datasets.detectIcebergPartitioning($scope.dataset).success(function(data) {
+                if (data.didDetectScheme && data.detectedScheme && data.detectedScheme.dimensions) {
+                    $scope.dataset.partitioning = data.detectedScheme;
+                } else {
+                    // activate partitioning with the default
+                    $scope.dataset.partitioning.dimensions = $scope.dataset.partitioning.dimensions || [];
+                    $scope.addDimension();
+                }
+            }).error(function(data, status, headers, config, statusText) {
+                // activate partitioning with the default
+                $scope.dataset.partitioning.dimensions = $scope.dataset.partitioning.dimensions || [];
+                $scope.addDimension();
+                // and show the error
+                setErrorInScope.bind($scope)(data, status, headers, config, statusText);
+            });
+        } else {
+            $scope.dataset.partitioning.dimensions = [];
+        }
+    };
+
+    $scope.removeDimension = function(index) {
+        $scope.dataset.partitioning.dimensions.splice(index, 1);
+    };
+
+    $scope.addDimension = function() {
+        $scope.dataset.partitioning.dimensions.push({
+            name : 'dimension_' + $scope.dataset.partitioning.dimensions.length,
+            type : 'value',
+            params : {'period': $scope.timeDimensionPeriods[0]}
+        });
+    };
+
+    $scope.fetchNamespaces = function(connectionName, origin, connectionType) {
+        SqlConnectionNamespaceService.listIcebergNamespaces(connectionName, $scope, origin, connectionType);
+    };
+
+    $scope.$on('$destroy', destroy);
+
+    function destroy () {
+        SqlConnectionNamespaceService.abortListIcebergNamespaces($scope);
+    }
+});
+
+app.controller("ManagedIcebergDatasetController", function($scope, $controller, DataikuAPI) {
+    $controller("BaseIcebergDatasetController", {$scope: $scope});
+
+    $scope.createTable = function() {
+        DataikuAPI.datasets.iceberg.createTable($scope.dataset).success(function (data) {
+            $scope.test(true, false);
+        }).error(setErrorInScope.bind($scope));
+    };
+
+    $scope.dropTable = function() {
+        DataikuAPI.datasets.iceberg.dropTable($scope.dataset).success(function (data) {
+            $scope.test(true, false);
+        }).error(setErrorInScope.bind($scope));
+    };
+});
+
+app.controller("ExternalIcebergDatasetController", function($scope, $controller) {
+    $controller("BaseIcebergDatasetController", {$scope: $scope});
+});
 
 app.controller("ElasticSearchDatasetController", function($scope, $controller, DataikuAPI, $stateParams, Logger) {
     $controller("BaseNoSQLRowDatasetController", {$scope: $scope, withConsistency: true});
