@@ -262,11 +262,11 @@ app.controller("LambdaServiceBaseController", function($scope, $state, $statePar
             });
     };
 
-    $scope.editCustomFields = function() {
+    $scope.editCustomFields = function(editingTabIndex = 0) {
         if (!$scope.service) {
             return;
         }
-        let modalScope = angular.extend($scope, {objectType: 'LAMBDA_SERVICE', objectName: $scope.service.name, objectCustomFields: $scope.service.customFields});
+        let modalScope = angular.extend($scope, {objectType: 'LAMBDA_SERVICE', objectName: $scope.service.name, objectCustomFields: $scope.service.customFields, editingTabIndex});
         CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(customFields) {
             $scope.saveCustomFields(customFields);
         });
