@@ -1105,7 +1105,7 @@ Renderer.prototype.code = function(code, lang, escaped) {
 
     if (lang === 'math') {
         return '\n<p class="dss-mathjax-block">$math-block\n'
-            + code
+            + escape(code, false)
             + '\n$math-block</p>\n'
     }
 
@@ -1123,7 +1123,7 @@ Renderer.prototype.code = function(code, lang, escaped) {
  * processed by markdown
  */
 Renderer.prototype.mathInline = function(formula) {
-    return '<span class="dss-mathjax-inline">$math-inline ' + formula + ' $math-inline</span>';
+    return '<span class="dss-mathjax-inline">$math-inline ' + escape(formula, false) + ' $math-inline</span>';
 };
 
 Renderer.prototype.blockquote = function(quote) {
@@ -2122,6 +2122,7 @@ app.directive('autocompletableTextarea', function(DataikuAPI, $timeout, $statePa
 
                 $scope.editorOptions = {
                     mode: attrs.noMarkdown ? 'text' : 'text/x-markdown',
+                    placeholder: attrs.customPlaceholder || null,
                     indentUnit: 2,
                     lineNumbers : false,
                     lineWrapping : true,
