@@ -1035,11 +1035,11 @@ app.directive('sqlSearchNotebookRightColumnSummary', function($rootScope, Dataik
                     });
             };
 
-            scope.editCustomFields = function() {
+            scope.editCustomFields = function(editingTabIndex = 0) {
                 if (!scope.notebook) {
                     return;
                 }
-                let modalScope = angular.extend(scope, {objectType: scope.objectType, objectName: scope.notebook.name, objectCustomFields: scope.notebook.customFields});
+                let modalScope = angular.extend(scope, {objectType: scope.objectType, objectName: scope.notebook.name, objectCustomFields: scope.notebook.customFields, editingTabIndex});
                 CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(customFields) {
                     scope.saveCustomFields(customFields);
                 });
