@@ -72,7 +72,7 @@ app.factory("PromptUtils", function(Logger, CreateModalFromTemplate, $filter, $d
         return !angular.equals(oldInputs, prompt.textPromptTemplateInputs);
     };
 
-    svc.createNewPrompt = function(mode, llmId, llmSettings, inputSource, datasetRef, templateId) {
+    svc.createNewPrompt = function(mode, llmId, llmSettings, inputSource, datasetRef, template) {
         const newPromptStudioPrompt = {};
         newPromptStudioPrompt.inlinePromptTemplateQueries = [];
         newPromptStudioPrompt.tags = [];
@@ -105,75 +105,18 @@ app.factory("PromptUtils", function(Logger, CreateModalFromTemplate, $filter, $d
             });
 
         } else if (newPrompt.promptMode === "PROMPT_TEMPLATE_STRUCTURED") {
+            const templateId = template ? template.id : undefined;
             WT1.event("prompt-studio-new-prompt-modal-new-from-template", {
                 templateId,
                 llmId: llmId
             });
 
-            switch(templateId) {
-                case "sample-blank":
-                    newPrompt.promptTemplateInputs = [{ name: "input", type: "TEXT" }];
-                    newPrompt.structuredPromptPrefix = "";
-                    newPrompt.placeholder = "Explain here what the model must do";
-                    break;
-                case "sample-extract-technical-specifications":
-                    newPrompt.promptTemplateInputs = [{ name: "Product description", type: "TEXT" }];
-                    newPrompt.structuredPromptPrefix = "Extract the key information from the below product reviews in JSON format";
-                    break;
-                case "sample-summarize-product-review":
-                    newPrompt.promptTemplateInputs = [
-                        { name: "Review text", type: "TEXT" },
-                        { name: "Review title", type: "TEXT" },
-                    ];
-                    newPrompt.structuredPromptPrefix = "Summarize the below product reviews in two sentences. Use only the information from the review text and title.";
-                    newPrompt.structuredPromptExamples =[
-                        {
-                            inputs: ["When I went to the mailbox, I was super sad to see that the packaging was damaged when it arrived. It was really messy. That's disappointing. However, once I opened it, it was good. Instructions seemed clear, but it still took me long to get running. Results are okay",
-                                    "Package was a mess"],
-                            output: "The packaging was damaged, but the product gives satisfying results. Ease of use could be improved"
-                        }
-                    ];
-                    break;
-                case "sample-support-requests-classification":
-                    newPrompt.promptTemplateInputs = [{ name: "Support request text", type: "TEXT" }];
-                    newPrompt.structuredPromptPrefix = "Given the following support request from a customer, classify it among the following topics:\n\n* Pricing request\n* Payment problem\n* Information request before sale\n* Delivery issue\n* Defective product\n* Complaint against company personnel\n* Insulting/Abusive customer\n* Unknown/Other\n\nOnly reply with the category";
-                    break;
-                case "sample-contract-analysis":
-                    newPrompt.promptTemplateInputs = [{ name: "Contract text", type: "TEXT" }];
-                    newPrompt.structuredPromptPrefix = "Read the provided software master license agreement. Then indicate:\n\n1) What is the general liability cap\n2) What is the governing law\n3) What are the termination for convenience terms";
-                    break;
-                case "sample-align-language-level":
-                    newPrompt.promptTemplateInputs = [{ name: "Text to rewrite", type: "TEXT" }];
-                    newPrompt.structuredPromptPrefix = "Rewrite the following text as professional-level language. Correct improper English. Do not try to summarize or otherwise change the meaning.";
-                    newPrompt.structuredPromptExamples = [
-                        {
-                            inputs: ["U know your in a bad place when u see cockroaches. Urgh. I'll never 4 ever wuld go there again. The food was meh, and the service ... sigh"],
-                            output: "There were cockroaches in the place. Would never return. The food was mediocre. Service was not great."
-                        },
-                        {
-                            inputs: ["We had a lovely time in this restaurant. The waiter was nice and service was fast. Food was tasty. The price was a bit high but worth it"],
-                            output: "We had a lovely time in this restaurant. The waiter was nice and service was fast. Food was tasty. The price was a bit high but worth it"
-                        }
-                    ];
-                    break;
-                case "sample-chain-of-thought":
-                    newPrompt.promptTemplateInputs = [{ name: "Reasoning problem", type: "TEXT" }];
-                    newPrompt.structuredPromptPrefix = "Here are some reasoning problems. Think step by step, before giving your final answer.";
-                    newPrompt.structuredPromptExamples = [
-                        {
-                            inputs: ["A coin is heads up. Ka turns the coin over. Sherrie turns the coin over. Is the coin still heads up?"],
-                            output: "The coin was turned over by both Ka and Sherrie. So the coin was turned over two times, which is an even number. The coin started heads up, and a coin only has two sides, so after an even number of turns, it will be back to heads up. So the answer is yes."
-                        },
-                        {
-                            inputs: ["A person is traveling at 20 km/h and reaches his destination in 2.5 hours, can you find the traveled distance?"],
-                            output: "The distance that the person traveled would be 20 km/hr * 2.5 hrs = 50 km. The answer is 50 km."
-                        },
-                        {
-                            inputs: ["There were nine computers in the server room. Five more computers were installed each day, from Monday to Thursday. How many computers are now in the server room?"],
-                            output: "There were originally 9 computers. For each of four days, five more computers were added. So 5 * 4 = 20 computers were added. 9 + 20 is 29. The answer is 29."
-                        }
-                    ];
-                    break;
+            const normalizedTemplate = template || { inputs: [{ name: "input", type: "TEXT" }], promptPrefix: "", examples: [] };
+            newPrompt.promptTemplateInputs = angular.copy(normalizedTemplate.inputs || []);
+            newPrompt.structuredPromptPrefix = normalizedTemplate.promptPrefix || "";
+            newPrompt.structuredPromptExamples = angular.copy(normalizedTemplate.examples || []);
+            if (templateId === "sample-blank") {
+                newPrompt.placeholder = "Explain here what the model must do";
             }
         } else if (newPrompt.promptMode === "RAW_PROMPT") {
             WT1.event("prompt-studio-new-prompt-modal-new-raw-prompt", {
@@ -623,11 +566,13 @@ app.filter("niceLLMType", function() {
     }
 });
 
-app.controller('NewPromptModalController', function($scope, Logger, TaggingService, PromptUtils, WT1) {
+app.controller('NewPromptModalController', function($scope, Logger, TaggingService, PromptUtils, WT1, DataikuAPI) {
     WT1.event("prompt-studio-new-prompt-modal-open");
 
     $scope.uiState = {
-        selectedTemplate: { id: "sample-blank", name: "Blank template", icon: "dku-icon-edit-24" },
+        selectedTemplate: null,
+        selectedTemplateId: null,
+        selectedTemplateName: "",
     };
 
     $scope.promptTypes = [
@@ -663,23 +608,25 @@ app.controller('NewPromptModalController', function($scope, Logger, TaggingServi
         }
     }
 
-    $scope.selectPromptTemplate = function (sample) {
-        $scope.uiState.selectedTemplate = $scope.templates.find(template => template.name == sample);
+    const setSelectedTemplate = function(template) {
+        $scope.uiState.selectedTemplate = template || null;
+        $scope.uiState.selectedTemplateId = template ? template.id : null;
+        $scope.uiState.selectedTemplateName = template ? template.name : "";
     };
 
-    //TODO - Before merging Chat feature banch remove the icons from this list if we still don't use them
-    $scope.templates = [
-        { id: "sample-blank", name: "Blank template" },
-        { id: "sample-extract-technical-specifications", name: "Extract technical specifications" },
-        { id: "sample-summarize-product-review", name: "Analyze product reviews" },
-        { id: "sample-support-requests-classification", name: "Classify support requests" },
-        { id: "sample-contract-analysis", name: "Analyze contract text" },
-        { id: "sample-align-language-level", name: "Improve text level language" },
-        { id: "sample-chain-of-thought", name: "Chain-of-thought prompt" },
-    ];
+    $scope.selectPromptTemplate = function (templateId) {
+        setSelectedTemplate($scope.templates.find(template => template.id == templateId));
+    };
+
+    $scope.templates = [];
+    DataikuAPI.enterpriseAssetLibrary.getAllPromptTemplates().success(function(data) {
+        $scope.templates = (data || []).sort((a, b) => (a.name || "").localeCompare(b.name || ""));
+        const defaultTemplate = $scope.templates.find(t => t.id === "sample-blank") || $scope.templates[0];
+        setSelectedTemplate(defaultTemplate);
+    }).error(setErrorInScope.bind($scope));
 
     $scope.accept = function() {
-        const newPromptStudioPrompt = PromptUtils.createNewPrompt($scope.uiState.promptMode, $scope.uiState.llmId, {}, $scope.uiState.source, $scope.uiState.datasetRef, $scope.uiState.selectedTemplate.id);
+        const newPromptStudioPrompt = PromptUtils.createNewPrompt($scope.uiState.promptMode, $scope.uiState.llmId, {}, $scope.uiState.source, $scope.uiState.datasetRef, $scope.uiState.selectedTemplate);
         Logger.info("Adding prompt", newPromptStudioPrompt);
 
         $scope.addPrompt(newPromptStudioPrompt);
@@ -816,7 +763,7 @@ app.controller('PromptStudioController', function ($scope, $state, $stateParams,
             $scope.uiState.loadingPrompt = false;
             setErrorInScope.bind($scope)(err);
         });
-    }
+    };
 
     $scope.setPromptDatasetPreview = function(preview) {
         $scope.promptDatasetPreview = angular.copy(preview);
@@ -830,7 +777,7 @@ app.controller('PromptStudioController', function ($scope, $state, $stateParams,
                 mainInputs: response.mainInputs
             }));
         }
-    }
+    };
 
     $scope.fillPromptData = function(prompt) {
         DataikuAPI.promptStudios.getPromptLastResponse($stateParams.projectKey, $stateParams.promptStudioId, prompt.id).success(function(data) {
@@ -999,7 +946,7 @@ app.controller('PromptStudioController', function ($scope, $state, $stateParams,
 
     $scope.hasImageInput = function() {
         return PromptUtils.hasImageInput($scope.activePromptStudioPrompt.prompt);
-    }
+    };
 
     /* *********************** Initialization code **************** */
 
@@ -1037,14 +984,14 @@ app.controller('PromptStudioController', function ($scope, $state, $stateParams,
                 $scope.save(modalScope.dismiss);
             };
         });
-    }
+    };
 
     function retrieveTagMap() {
         const promptStudioTags = $scope.promptStudio.prompts.map(prompt => prompt.tags).reduce(function(acc, cur) {
             return acc.concat(cur);
         }, []);
         return TaggingService.fillTagsMapFromArray(promptStudioTags);
-    }
+    };
 
     $scope.getPromptStudioTags = function() {
         if (!$scope.promptStudio) return;
@@ -1152,7 +1099,7 @@ app.controller('PromptStudioController', function ($scope, $state, $stateParams,
         const { inputNames, inputs } = PromptUtils.getInlinePromptInputMap($scope.activePromptStudioPrompt.prompt, query);
 
         $scope.viewRowRawPrompt(inputs, inputNames, $scope.activePromptStudioPrompt);
-    }
+    };
 
     $scope.runActivePromptIfAbleTo = function() {
         if ($scope.activePromptStudioPrompt.prompt.promptMode !== 'CHAT' && !$scope.runButtonDisabledReason()) {
@@ -1301,18 +1248,18 @@ app.controller('PromptStudioController', function ($scope, $state, $stateParams,
 
             });
         }).error(setErrorInScope.bind($scope));
-    }
+    };
 
     $scope.changeDataset = function(dataset, queriesSource) {
         $scope.activePromptStudioPrompt.dataset = dataset || $scope.activePromptStudioPrompt.dataset;
         $scope.activePromptStudioPrompt.prompt.promptTemplateQueriesSource = queriesSource;
         $scope.forceDatasetPreview();
-    }
+    };
 
     $scope.toggleMenu = (isOpen) => {
         $scope.isMenuExpanded = isOpen;
         localStorageService.set(LOCAL_STORAGE_KEY_MENU, isOpen);
-    }
+    };
 
     $scope.updateSampleSettings = (settings) => {
         $scope.activePromptStudioPrompt.nbRows = settings.nbRows;
@@ -1419,7 +1366,7 @@ app.controller("ExportAsPromptRecipeModalController", function($scope, $statePar
         .then(function() {
             $state.go("projects.project.recipes.recipe", { projectKey: $stateParams.projectKey, recipeName: $scope.recipeSettings.recipeName });
         }).catch(setErrorInScope.bind($scope));
-    }
+    };
 
     function createNewRecipe() {
         DataikuAPI.promptStudios.getRecipePayloadFromPrompt($stateParams.projectKey, $scope.promptStudio.id, $scope.activePromptStudioPrompt.id).then(function({data}) {
@@ -1569,6 +1516,61 @@ app.component('promptResponseSummary', {
     }
 });
 
+app.component('quicktestResponseSummary', {
+    bindings: {
+        totalUsage: '<',
+    },
+    templateUrl: '/templates/promptstudios/quicktest-response-summary.html',
+    controller: function() {
+        const $ctrl = this;
+
+        $ctrl.getEstimatedCostPer1KRecords = function() {
+            return ($ctrl.totalUsage.estimatedCost || 0) * 1000;
+        };
+    }
+});
+
+app.component('totalUsageSummary', {
+    bindings: {
+            totalUsage: '<',
+        },
+        templateUrl: '/templates/promptstudios/total-usage-summary.html',
+        controller: function($scope) {
+            const $ctrl = this;
+
+            $scope.$watch('$ctrl.totalUsage', function() {
+                let total = angular.copy($ctrl.totalUsage);
+                total.category = "TOTAL";
+                delete total['details'];
+                $ctrl.totalUsageList = [];
+                Object.entries($ctrl.totalUsage.details || []).forEach(([category, usage]) => {
+                    usage.category = category;
+                    $ctrl.totalUsageList.push(usage);
+                });
+                $ctrl.totalUsageList.push(total);
+            });
+
+            $ctrl.getQueryCount = function(queryCount) {
+                if (queryCount < 2) {
+                    return queryCount + " query";
+                } else {
+                    return queryCount + " queries"
+                }
+            };
+            const categories = {
+                'TOTAL': 'Total usage',
+                'COMPLETION': 'Completion',
+                'IMAGE_GENERATION': 'Image generation',
+                'EMBEDDING': 'Embedding',
+                'RERANKING': 'Reranking',
+                'GUARDRAIL': 'Guardrails',
+            };
+            $ctrl.getCategoryLabel = function(category) {
+                return categories[category];
+            };
+        }
+});
+
 
 app.component('promptInputDefinition', {
     bindings: {
@@ -1729,9 +1731,7 @@ app.component('promptStudioDocumentSources', {
         };
 
         $ctrl.hasDisplayableSources = function() {
-            // If the KB returns no results or returns unknown source types, we could have a sources section with empty `items`
-            // We only display sources of type SIMPLE_DOCUMENT or FILE_BASED_DOCUMENT
-            return $ctrl.sources?.flatMap(source => source.items).filter(item => item.type === 'SIMPLE_DOCUMENT' || item.type === 'FILE_BASED_DOCUMENT').length;
+            return $ctrl.sources?.some((source) => source?.items.length > 0);
         };
 
         $ctrl.shouldExpandSource = function(source) {
@@ -1761,9 +1761,7 @@ app.component('promptStudioDocumentSource', {
         };
 
         $ctrl.hasDisplayableParts = function() {
-            // If a KB returns no results or returns unknown source types, we could have a source with empty `items`, alongside other sources that do have items
-            // We only display sources of type SIMPLE_DOCUMENT or FILE_BASED_DOCUMENT
-            return $ctrl.source.items.filter(item => item.type === 'SIMPLE_DOCUMENT' || item.type === 'FILE_BASED_DOCUMENT').length;
+            return true;
         };
 
         $ctrl.hasHierarchy = function() {
@@ -1784,6 +1782,8 @@ app.component('promptLlmCompletionSettings', {
     bindings: {
         completionSettings: '<',
         activeLlm: '<',
+        advancedSettingsInFold: '<',
+        hideJsonMode: '<',
     },
     templateUrl: '/templates/promptstudios/prompt-llm-completion-settings.html',
     controller: function(PromptUtils, ReasoningEffortCompletionSetting) {
@@ -1792,6 +1792,14 @@ app.component('promptLlmCompletionSettings', {
         $ctrl.reasoningEffortDescriptions = ReasoningEffortCompletionSetting.map(function(reasoningEffort) {
             return reasoningEffort.description;
         });
+        $ctrl.$onInit = function() {
+            if ($ctrl.advancedSettingsInFold === undefined) {
+                $ctrl.advancedSettingsInFold = false;
+            }
+            if ($ctrl.hideJsonMode === undefined) {
+                $ctrl.hideJsonMode = false;
+            }
+        };
         $ctrl.$onChanges = function(changes) {
             if (changes.activeLlm) {
                 $ctrl.temperatureRange = PromptUtils.getTemperatureRange($ctrl.activeLlm);
@@ -1841,6 +1849,7 @@ app.component('promptReusableTemplate', {
         disablePromptSwitch: '<',
         disableImageInputs: '<',
         onPromptInputChange: '&',
+        from: '@',
     },
     require: {
         apiErrorContext: "^apiErrorContext"
@@ -1985,11 +1994,11 @@ app.directive('promptStudioRightColumnSummary', function($controller, $state, $s
 
 
             /** Custom fields from plugins **/
-            scope.editCustomFields = function() {
+            scope.editCustomFields = function(editingTabIndex = 0) {
                 if (!scope.promptStudio) {
                     return;
                 }
-                let modalScope = angular.extend(scope, {objectType: 'PROMPT_STUDIO', objectName: scope.promptStudio.name, objectCustomFields: scope.promptStudio.customFields});
+                let modalScope = angular.extend(scope, {objectType: 'PROMPT_STUDIO', objectName: scope.promptStudio.name, objectCustomFields: scope.promptStudio.customFields, editingTabIndex});
                 CreateModalFromTemplate("/templates/taggable-objects/custom-fields-edit-modal.html", modalScope).then(function(newCustomFields) {
                     WT1.event('custom-fields-save', {objectType: 'PROMPT_STUDIO'});
                     const oldCustomFields = angular.copy(scope.promptStudio.customFields);
