@@ -413,7 +413,7 @@ app.directive("recipeIoInputAddList", function(Assert, RecipesUtils, RecipeDescS
 });
 
 
-app.controller("_RecipeOutputNewManagedBehavior", function($scope, WT1, Logger, DataikuAPI, $stateParams, RecipeComputablesService, $rootScope, SqlConnectionNamespaceService) {
+app.controller("_RecipeOutputNewManagedBehavior", function($scope, WT1, Logger, DataikuAPI, $stateParams, RecipeComputablesService, $rootScope, SqlConnectionNamespaceService, ConnectionsService) {
     $scope.newOutputDataset = {};
     $scope.newOutputODB = {};
     $scope.newOutputMES = {};
@@ -430,6 +430,8 @@ app.controller("_RecipeOutputNewManagedBehavior", function($scope, WT1, Logger,
             .catch($scope.setErrorInTopScope($scope));
     };
 
+    $scope.searchConnectionsWithDescriptions = ConnectionsService.searchConnectionsWithDescriptions;
+
     $scope.setupManagedDatasetOptions = function(data, forceUpdate){
         $scope.managedDatasetOptions = data;
         if (data.connections.length && (!$scope.newOutputDataset.connectionOption || forceUpdate) ){
@@ -576,6 +578,7 @@ app.controller("_RecipeOutputNewManagedBehavior", function($scope, WT1, Logger,
             specificSettings : {
                 overrideSQLCatalog: $scope.newOutputDataset.overrideSQLCatalog,
                 overrideSQLSchema: $scope.newOutputDataset.overrideSQLSchema,
+                overrideIcebergNamespace: $scope.newOutputDataset.overrideIcebergNamespace,
                 formatOptionId : $scope.newOutputDataset.formatOptionId,
             },
             partitioningOptionId : $scope.newOutputDataset.partitioningOption,
@@ -704,6 +707,10 @@ app.controller("_RecipeOutputNewManagedBehavior", function($scope, WT1, Logger,
         $scope.recipeWT1Event("recipe-create-streaming-endpoint", {});
     };
 
+    $scope.fetchNamespaces = function(origin, connectionType) {
+        SqlConnectionNamespaceService.listIcebergNamespaces($scope.newOutputDataset.connectionOption.connectionName, $scope, origin, connectionType);
+    };
+
     $scope.fetchCatalogs = function(origin, connectionType) {
         SqlConnectionNamespaceService.listSqlCatalogs($scope.newOutputDataset.connectionOption.connectionName, $scope, origin, connectionType);
     };
