@@ -28,7 +28,7 @@
                 }
             }
         };
-                   
+
 
         $scope.EMBED_DOCS_EXTRACTION_MODES = [ // keep in sync with EmbedDocumentsRecipeParams.java - ExtractionMode enum
             {
@@ -69,8 +69,18 @@
             },
         };
 
+        $scope.EMBED_DOCS_ENGINE_MAP = {
+            'STRUCTURED': {title: 'Structured text extraction', description: "When possible, the engine uses document headers to divide the content into extraction units. Image handling can be used to leverage images in documents and scanned PDFs." +
+                    " Supported file formats are PDF, DOCX, PPTX, HTML, TXT, MD (without OCR), JPG, JPEG, and PNG (with OCR enabled)."},
+            'RAW': {title: 'Raw text extraction', description: "Fast but doesn't extract the structure of the document, only the raw text. OCR can be used on images with text." +
+                    " Supported file formats are PDF, DOCX, PPTX, HTML, TXT, MD (without OCR), JPG, JPEG, and PNG (with OCR enabled)."},
+            'VLM': {title: 'VLM extraction', description: "Uses a Vision Language Model to extract information from documents that may include text and visual elements like charts, graphics, and tables." +
+                    " Supported file formats are PDF, DOC, DOCX, ODT, PPT, PPTX, ODP, JPG, JPEG and PNG."},
+            'DONOTEXTRACT': {title: 'Ignore (Do not extract)', description: "Ignore matching files."},
+        };
+
         DataikuAPI.flow.recipes.nlp.getDefaultDocExtractionPrompts($stateParams.projectKey, $scope.recipe.name).success(function(data) {
-            $scope.promptsTemplates = data; 
+            $scope.promptsTemplates = data;
         }).error(setErrorInScope.bind($scope));
 
         $scope.getPrompt = function(charsLimit, promptVersion) {
@@ -154,6 +164,14 @@
             };
         };
 
+        $scope.makeDefaultRawSettings = function() {
+            return {
+                "useOCR": false,
+                "ocrEngine": "AUTO",
+                "ocrLanguages": "en",
+            };
+        }
+
         $scope.addNewRule = function() {
             $scope.recipe.params.rules.push({
                 "filter": {
@@ -171,24 +189,32 @@
                 },
 
                 "actionToPerform": "STRUCTURED",
+                "rawSettings": $scope.makeDefaultRawSettings(),
                 "structuredSettings": $scope.makeDefaultStructuredSettings(),
                 "splittingSettings": $scope.makeDefaultSplittingSettings(),
                 "storeInMultimodalColumn": "FULL_CONTENT"
             });
             $scope.uiState.showAdvancedSettings.push(false);
-        };
+        }
 
         $scope.onRuleActionChange = function(idx) {
             let ruleToBeUpdated = idx == -1 ? $scope.recipe.params.allOtherRule : $scope.recipe.params.rules[idx];
 
-            if (ruleToBeUpdated.actionToPerform == 'VLM') {
-                ruleToBeUpdated.vlmSettings = ruleToBeUpdated.vlmSettings || $scope.makeDefaultVLMSettings(ruleToBeUpdated);
-                ruleToBeUpdated.storeInMultimodalColumn = "IMAGES";
-            } else if (ruleToBeUpdated.actionToPerform == 'STRUCTURED') {
-                ruleToBeUpdated.structuredSettings = ruleToBeUpdated.structuredSettings || $scope.makeDefaultStructuredSettings();
-                ruleToBeUpdated.storeInMultimodalColumn = $scope.shouldStoreDetectedImages(ruleToBeUpdated) ? "IMAGES" : "FULL_CONTENT";
+            switch (ruleToBeUpdated.actionToPerform) {
+                case 'VLM':
+                    ruleToBeUpdated.vlmSettings = ruleToBeUpdated.vlmSettings || $scope.makeDefaultVLMSettings(ruleToBeUpdated);
+                    ruleToBeUpdated.storeInMultimodalColumn = "IMAGES";
+                    break;
+                case 'STRUCTURED':
+                    ruleToBeUpdated.structuredSettings = ruleToBeUpdated.structuredSettings || $scope.makeDefaultStructuredSettings();
+                    ruleToBeUpdated.storeInMultimodalColumn = $scope.shouldStoreDetectedImages(ruleToBeUpdated) ? "IMAGES" : "FULL_CONTENT";
+                    break;
+                case 'RAW':
+                    ruleToBeUpdated.rawSettings = ruleToBeUpdated.rawSettings || $scope.makeDefaultRawSettings();
+                    ruleToBeUpdated.storeInMultimodalColumn = "FULL_CONTENT";
+                    break;
             }
-        };
+        }
 
         $scope.clearAll = function() { // remove all rules except 'all other files' rule
             // eslint-disable-next-line for-direction
@@ -321,7 +347,6 @@
                     }
                 }).error(setErrorInScope.bind($scope));
             }
-
         }
 
         $scope.overrideCustomPromptWith = function (rule, promptVersion) {
@@ -355,8 +380,8 @@
             return false;
         };
 
-        $scope.onStructuredImageHandlingChange = function(rule){
-            if(rule.actionToPerform === 'STRUCTURED' ) {
+        $scope.onImageHandlingChange = function(rule){
+            if(['STRUCTURED', 'RAW'].contains(rule.actionToPerform)) {
                 if ($scope.shouldStoreDetectedImages(rule)) {
                     rule.storeInMultimodalColumn = 'IMAGES';
                 } else {
@@ -367,4 +392,12 @@
 
     });
 
+    app.component("ocrEngine", {
+        bindings: {
+            engine: "=",
+            languages: "=",
+        },
+        templateUrl: "templates/recipes/doc-extraction-common/ocr-engine.component.html",
+    });
+
 })();
\ No newline at end of file
