@@ -49,7 +49,7 @@
                     objectName = node.attributes["llmId"];
                 } else if (nameLower === "dku_llm_mesh_embedding_query") {
                     objectName = node.attributes["llmId"];
-                } else if (nameLower == "dku_managed_tool_call") {
+                } else if (nameLower === "dku_managed_tool_call") {
                     objectName = node.attributes["toolType"] || ""
                 } else if (nameLower === "python_agent_tool_call") {
                     emoji = "🐍️ ";
@@ -57,6 +57,11 @@
                 } else if (nameLower === "python_agent_mcp_subtool_call") {
                     emoji = "📡 ";
                     objectName = node.attributes["subtool_name"];
+                } else if (nameLower === "dku_agent_block_run" || nameLower === "dku_agent_parallel_sub_block" || nameLower === "dku_agent_for_each_sub_block" || nameLower === "dku_agent_reflection_generator_block") {
+                    emoji = "🧱 ";
+                    objectName = node.attributes["block_id"];
+                } else if (nameLower === "dku_agent_for_each_iteration" || nameLower === "dku_agent_react_iteration" || nameLower === "dku_agent_reflection_generation" || nameLower === "dku_agent_reflection_critique") {
+                    objectName = `iteration ${node.attributes["iterationNumber"]}`;
                 }
 
                 const durationInfo = node.duration !== undefined ? ` (${node.duration}ms)` : "";
