@@ -114,11 +114,22 @@ app.controller("RunnableCoreController", function($scope, $controller, $statePar
 
 });
 
-app.service("RunnableUtilsService", function(FutureWatcher, $timeout, $state, ProgressStackMessageBuilder) {
+app.service("RunnableUtilsService", function(FutureWatcher, $timeout, $state, ProgressStackMessageBuilder, ProjectFolderService, WT1) {
     const svc = {}
 
     /* resultScope must contain runState:{} and runOutput:{} */
-    svc.handleResult = function(resultScope, initialResponse, isProjectCreation, manageScroll) {
+    svc.handleResult = function(resultScope, initialResponse, postRunOptions) {
+        const defaultOptions = {
+            isProjectCreation: false, // if the runnable is a project creation macro
+            manageScroll: false, // if true, scrolls the modal to the runnable output
+            shouldRedirectToProject: true, // if after creating the project the modal should redirect to it (if applicable)
+            projectFolderId: null // the folder the project is created in (if applicable)
+        };
+        postRunOptions = {
+            ...defaultOptions,
+            ...postRunOptions
+        };
+
         resultScope.runState.running = true;
         resultScope.runState.jobId = initialResponse.jobId;
         resultScope.runOutput.resultType = null;
@@ -146,10 +157,24 @@ app.service("RunnableUtilsService", function(FutureWatcher, $timeout, $state, Pr
                 resultScope.runOutput.failure.errorType = resultScope.runOutput.failure.clazz;
             }
 
-            if (isProjectCreation && data.result.data) {
-                const dataObj = data.result.data.object;
-                resultScope.dismiss();
-                $state.go("projects.project.home.regular", {projectKey: dataObj.projectKey})
+            if (postRunOptions.isProjectCreation && !data.result.failure && !data.result.error) {
+                // note : even in case of error, the project may have been created but we can't know for sure, in doubt we do not publish a WT1 event
+                const projectKey = data.result.data?.object?.projectKey;
+                ProjectFolderService.getFolder(postRunOptions.projectFolderId).then((folder) => {
+                    WT1.tryEvent("project-create-from-macro", () => {
+                        return {
+                            ...resultScope.wt1Context,
+                            hashedProjectId: projectKey ? md5(projectKey) : undefined,
+                            isInSuggestedFolder: false, // no folder suggestion
+                            isInRoot: ProjectFolderService.isInRoot(folder.id),
+                            isUnderSandbox: ProjectFolderService.isUnderSandbox(folder),
+                        };
+                    });
+                });
+                resultScope.resolveModal(projectKey);
+                if (postRunOptions.shouldRedirectToProject && projectKey) {
+                    $state.go("projects.project.home.regular", {projectKey: projectKey})
+                }
             }
         };
         if (initialResponse.hasResult) {
@@ -169,7 +194,7 @@ app.service("RunnableUtilsService", function(FutureWatcher, $timeout, $state, Pr
                 resultScope.runState.running = false;
                 setErrorInScope.bind(resultScope)(data, status, headers);
             }).finally(function() {
-                if (!isProjectCreation && manageScroll) {
+                if (!postRunOptions.isProjectCreation && postRunOptions.manageScroll) {
                     $timeout(() => $('.runnable-modal .modal-body div.oa').scrollTop($('.runnable-modal .modal-body div.oa').scrollTop() + $('#runnable-output').position().top - 20), 100);
                 }
             });
@@ -306,8 +331,9 @@ app.controller("RunnableController", function ($scope, $rootScope, $controller,
         WT1.event("runnable-run", {type : runnable.runnableType});
         $scope.runState.running = true;
         var runCall;
+        const projectFolderId = ProjectFolderContext.getCurrentProjectFolderId();
         if ($scope.mode == "PROJECT_CREATION") {
-            runCall = DataikuAPI.runnables.projectCreationRun(runnable.runnableType, runnable.$config, ProjectFolderContext.getCurrentProjectFolderId());
+            runCall = DataikuAPI.runnables.projectCreationRun(runnable.runnableType, runnable.$config, projectFolderId);
         } else if ($scope.insight) {
             runCall = DataikuAPI.runnables.insightRun($stateParams.projectKey, $scope.insight.id);
         } else if ($scope.cluster) {
@@ -315,12 +341,18 @@ app.controller("RunnableController", function ($scope, $rootScope, $controller,
         } else {
             runCall = DataikuAPI.runnables.manualRun($stateParams.projectKey, runnable.runnableType, runnable.$config, runnable.$adminConfig);
         }
-        runCall.success(function(initialResponse) {
-            RunnableUtilsService.handleResult($scope, initialResponse, $scope.mode == "PROJECT_CREATION", true);
+        runCall.then(function(initialResponse) {
+            const postRunOptions = {
+                isProjectCreation: $scope.mode == "PROJECT_CREATION",
+                manageScroll: true,
+                shouldRedirectToProject: $scope.shouldRedirectToProject,
+                projectFolderId: $scope.mode == "PROJECT_CREATION" ? projectFolderId : null,
+            };
+            RunnableUtilsService.handleResult($scope, initialResponse.data, postRunOptions);
             $scope.runState.jobId = initialResponse.jobId;
-        }).error(function(a, b, c) {
+        }).catch((resp) => {
             $scope.runState.running = false;
-            $scope.runOutput.error = a;
+            $scope.runOutput.error = resp.data;
         }).finally(function() {
             $timeout(() => $('.runnable-modal .modal-body div.oa').scrollTop($('.runnable-modal .modal-body div.oa').scrollTop() + $('#runnable-output').position().top - 20), 100);
         });
@@ -364,7 +396,7 @@ app.directive("runnableRunButton", function($stateParams, DataikuAPI, FutureWatc
                     runCall = DataikuAPI.runnables.manualRun($stateParams.projectKey, runnable.runnableType, runnable.$config, runnable.$adminConfig);
                 }
                 runCall.success(function(initialResponse) {
-                    RunnableUtilsService.handleResult($scope, initialResponse, false);
+                    RunnableUtilsService.handleResult($scope, initialResponse, {isProjectCreation: false});
                 }).error(function(a, b, c) {
                     $scope.runState.running = false;
                     $scope.runOutput.error = a;
