@@ -6,7 +6,7 @@
     /**
      * (!) This directive previously was in static/dataiku/js/simple_report/chart_dragdrop.js
      */
-    app.directive('chartMultiDragDropZones', function(translate) {
+    app.directive('chartMultiDragDropZones', function(translate, ChartColumnTypeUtils, WT1) {
         return {
             controller: 'ChartDragDropController',
             link: function($scope, element) {
@@ -14,13 +14,19 @@
                 $scope.activeDragDrop = {};
                 $scope.translate = translate;
 
-                $scope.onDragEnd = function() {
+                $scope.onDragEnd = function(data) {
                     // Unhide the moved element, as ng-repeat will reuse it
                     if ($scope.activeDragDrop.draggedElementToHide) {
                         $scope.activeDragDrop.draggedElementToHide.show();
                     }
                     clear($scope.activeDragDrop);
                     $scope.setDragInactive();
+
+                    const currentChartIndex = $scope.currentChart && $scope.currentChart.index;
+                    if (ChartColumnTypeUtils.isHierarchy(data) && !_.isNil(currentChartIndex)) {
+                        const chartType = $scope.charts && $scope.charts[currentChartIndex] && $scope.charts[currentChartIndex].def.type;
+                        WT1.event('hierarchy-added-to-chart', { chartType });
+                    }
                 };
 
                 element[0].addEventListener('dragend', function(e) {
