@@ -4,14 +4,20 @@
     const app = angular.module('dataiku.charts');
 
     // (!) This directive previously was in static/dataiku/js/simple_report/config_ui.js
-    app.directive('geoAdminZone', function($parse) {
+    app.directive('geoAdminZone', function($parse, Ng2MenuOrchestratorService) {
         return {
             templateUrl: '/static/dataiku/js/simple_report/directives/drag-drop/drop-zones/geo-admin-zone/geo-admin-zone.directive.html',
             scope: true,
             link: function($scope, element, attrs) {
                 $scope.$watch(attrs.list, newList => $scope.list = newList);
+                $scope.id = attrs.id;
+                $scope.chartDefKey = attrs.chartDefKey;
                 $scope.acceptCallback = $parse(attrs.acceptCallback)($scope);
+
+                $scope.openMatMenu = function(menuIdx, event) {
+                    Ng2MenuOrchestratorService.triggerMenuOpen($scope.chartDefKey, menuIdx, event);
+                };
             }
-        }
+        };
     });
 })();
