@@ -7,7 +7,7 @@
      * Service responsible for retrieving appropriate icon for a given chart type and DSS location.
      * (!) This service previously was in static/dataiku/js/simple_report/chart_type_picker.js
      */
-    app.factory('ChartIconUtils', function(WebAppsService) {
+    app.factory('ChartIconUtils', function(WebAppsService, AssetsUtils) {
         const ret = {
             computeChartIcon: function(type, variant, isInAnalysis, webAppType) {
                 if (!ret.typeAndVariantToImageMap) {
@@ -33,12 +33,12 @@
                     } else {
                         uri += 'Chart_Icon_Dataset_';
                     }
-                    return uri + imageName + '.svg';
+                    return AssetsUtils.appendAssetsHash(uri + imageName + '.svg');
                 }
             },
 
             computeScatterLegendIcon(type) {
-                return `/static/dataiku/images/charts/icons/scatter-legend/symbol_${type}.svg`;
+                return AssetsUtils.appendAssetsHash(`/static/dataiku/images/charts/icons/scatter-legend/symbol_${type}.svg`);
             },
 
             typeAndVariantToImageMap: {
