@@ -13,7 +13,7 @@
     /**
      * A set of helpers to create and enhance d3 svg axes
      */
-    function D3ChartAxes(d3Utils, CHART_AXIS_TYPES, CHART_TYPES, CHART_MODES, ChartDimension, ChartUADimension, ChartAxesUtils, AxisTicksConfigMode, ChartFeatures, ChartFormatting, ChartsStaticData, AxisTicksConfiguration, ChartYAxisPosition, ChartFormattingPaneSections, GridlinesAxisType, ChartDataUtils, ChartLabels) {
+    function D3ChartAxes(d3Utils, CHART_AXIS_TYPES, CHART_TYPES, CHART_MODES, ChartDimension, ChartUADimension, ChartAxesUtils, AxisTicksConfigMode, ChartFeatures, ChartFormatting, ChartsStaticData, AxisTicksConfiguration, ChartYAxisPosition, ChartFormattingPaneSections, GridlinesAxisType, ChartDataUtils, ChartLabels, ChartMeasure, CHART_VARIANTS, ValuesInChartPlacementMode, ChartPropertiesService) {
 
         const addFormatterToBinnedAxis = (axis, tickExtents, formattingOptions) => {
             axis.tickFormat(ChartFormatting.getForBinnedAxis(tickExtents, formattingOptions));
@@ -23,10 +23,10 @@
             axis.tickFormat(ChartFormatting.getForCustomBinnedAxis(tickExtents, formattingOptions));
         };
 
-        const addFormatterToOrdinalAxis = (axis, tickExtents) => {
+        const addFormatterToOrdinalAxis = (axis, tickExtents, formattingOptions) => {
             axis.tickFormat((_d, i) => {
                 const value = tickExtents[i];
-                return ChartFormatting.getForOrdinalAxis(value);
+                return ChartFormatting.getForOrdinalAxis(value, formattingOptions);
             });
         };
 
@@ -81,10 +81,10 @@
                 .attr('opacity', 0)
                 .attr('font-size', `${fontSize}px`)
                 .text('0');
-            if (textElement){
+            if (textElement) {
                 const textHeight = textElement.node()?.getBBox().height;
                 textElement.remove();
-                if (textHeight){
+                if (textHeight) {
                     result = textHeight;
                 }
             }
@@ -146,6 +146,7 @@
              */
             createDimensionAxis: function(chartData, axisSpec, isLogScale, includeZero, formattingOptions, chartDef, ignoreLabels) {
                 const isNumerical = ChartAxesUtils.isNumerical(axisSpec);
+                const isDualAxis = !!chartData.hasDualDimensionAxis?.(axisSpec.name);
                 let extent = ChartAxesUtils.getDimensionExtent(chartData, axisSpec, ignoreLabels);
 
                 if (!isLogScale && !ChartAxesUtils.isManualMode(axisSpec.customExtent)) {
@@ -190,7 +191,7 @@
                     } else if (isGroupedNumerical) {
                         addFormatterToBinnedAxis(axis, extent.values, formattingOptions);
                     } else {
-                        addFormatterToOrdinalAxis(axis, extent.values);
+                        addFormatterToOrdinalAxis(axis, extent.values, formattingOptions);
                     }
                     axis.scaleType = SCALE_TYPES.ORDINAL;
                     return axis;
@@ -214,7 +215,7 @@
                         axis = createNumericAxis();
                     } else if (ChartDimension.isGroupedNumerical(axisSpec.dimension) || (axisSpec.type === CHART_AXIS_TYPES.UNAGGREGATED && ChartUADimension.isTrueNumerical(axisSpec.dimension))) {
                         if (ChartDimension.hasOneTickPerBin(axisSpec.dimension) && ChartFeatures.chartSupportOneTickPerBin(chartDef)) {
-                            axis = createOrdinalAxis(true);
+                            axis = createOrdinalAxis(!isDualAxis); // for now dual axis is used only in waterfall, and values are already merged at this point, so treat them as alphanum values
                         } else {
                             axis = createNumericAxis();
                         }
@@ -467,9 +468,10 @@
              * @param {jQuery selection} $svg
              * @param {ChartDef.java} chartDef
              * @param {array of d3 axis} yAxes
+             * @param {ChartTileProperties} chartTileProperties
              * @returns {{top: number, bottom: number, right: number, left: number}} the margins object
              */
-            getHorizontalMarginsAndAxesWidth: function(margins, $svg, chartDef, yAxes) {
+            getHorizontalMarginsAndAxesWidth: function(margins, $svg, chartDef, yAxes, chartTileProperties) {
                 const axesWidth = [];
                 margins[ChartYAxisPosition.LEFT] = ChartsStaticData.CHART_BASE_MARGIN;
                 margins[ChartYAxisPosition.RIGHT] = ChartsStaticData.CHART_BASE_MARGIN;
@@ -480,7 +482,7 @@
                     };
                     const side = axis.position;
                     const axisFormatting = ChartAxesUtils.getFormattingForYAxis(chartDef.yAxesFormatting, axis.id);
-                    if (axis && axisFormatting.displayAxis) {
+                    if (axis && ChartPropertiesService.showYAxis(axisFormatting, chartTileProperties)) {
                         let labels;
                         if (axis.type === CHART_AXIS_TYPES.MEASURE || axis.scaleType === SCALE_TYPES.LINEAR || axis.scaleType === SCALE_TYPES.TIME) {
                             labels = axis.scale().ticks();
@@ -516,7 +518,7 @@
                     || (axis && (axis.dimension !== undefined || axis.measure !== undefined))
                     || ChartAxesUtils.getMeasuresDisplayedOnAxis(axis.position, chartDef.genericMeasures).length >= 1);
 
-                    if (canHaveAxisTitle && axisFormatting.showAxisTitle) {
+                    if (canHaveAxisTitle && ChartPropertiesService.showYAxisTitle(axisFormatting, chartTileProperties)) {
                         tempMargins[side] += ChartsStaticData.AXIS_MARGIN + axisFormatting.axisTitleFormatting.fontSize;
                     }
 
@@ -536,29 +538,23 @@
 
             getMarginsAndAxesWidth: function(chartHandler, chartDef, $svg, xAxis, yAxes) {
                 let margins = { top: ChartsStaticData.CHART_BASE_MARGIN, bottom: ChartsStaticData.CHART_BASE_MARGIN };
-                let yAxesWidth;
-                if (!chartHandler.noXAxis && ChartFeatures.canDisplayAxes(chartDef.type)) {
-                    if (chartDef.xAxisFormatting.displayAxis) {
+                if (ChartFeatures.canDisplayAxes(chartDef.type)) {
+                    if (ChartPropertiesService.showXAxis(chartDef.xAxisFormatting, chartHandler.chartTileProperties)) {
                         margins.bottom += ChartsStaticData.AXIS_WIDTH;
                     }
 
                     const canHaveAxisTitle = ChartFeatures.canShowXAxisTitle(chartDef) && ((!_.isNil(chartDef.xAxisFormatting.axisTitle) && chartDef.xAxisFormatting.axisTitle.length > 0)
-                    || (xAxis && (xAxis.dimension !== undefined || xAxis.measure !== undefined))
-                    || chartDef.genericDimension0.length === 1);
+                        || (xAxis && (xAxis.dimension !== undefined || xAxis.measure !== undefined))
+                        || ChartDimension.getGenericDimensions(chartDef).length === 1);
 
-                    if (canHaveAxisTitle && chartDef.xAxisFormatting.showAxisTitle) {
+                    if (canHaveAxisTitle && ChartPropertiesService.showXAxisTitle(chartDef.xAxisFormatting, chartHandler.chartTileProperties)) {
                         margins.bottom += ChartsStaticData.AXIS_MARGIN + chartDef.xAxisFormatting.axisTitleFormatting.fontSize;
                     }
                 }
 
-                if (chartHandler.noYAxis) {
-                    margins.left = ChartsStaticData.CHART_BASE_MARGIN;
-                    margins.right = ChartsStaticData.CHART_BASE_MARGIN;
-                } else {
-                    const { updatedMargins, axesWidth } = svc.getHorizontalMarginsAndAxesWidth(margins, $svg, chartDef, yAxes);
-                    margins = updatedMargins;
-                    yAxesWidth = axesWidth;
-                }
+                const { updatedMargins, axesWidth } = svc.getHorizontalMarginsAndAxesWidth(margins, $svg, chartDef, yAxes, chartHandler.chartTileProperties);
+                margins = updatedMargins;
+                const yAxesWidth = axesWidth;
 
                 return { margins, yAxesWidth };
             },
@@ -803,7 +799,7 @@
                 }
 
                 // Adjust bottom margin for x axis
-                if (xAxis && !chartHandler.noXAxis && chartDef.xAxisFormatting.displayAxis) {
+                if (xAxis && ChartPropertiesService.showXAxis(chartDef.xAxisFormatting, chartHandler.chartTileProperties)) {
                     margins = svc.adjustBottomMargin(chartDef.xAxisFormatting.axisValuesFormatting.axisTicksFormatting, margins, $svg, xAxis, chartHandler.forceRotation);
                 }
 
@@ -863,10 +859,10 @@
                     }
 
                     if (chartDef.valuesInChartDisplayOptions.displayValues && chartDef.type === CHART_TYPES.GROUPED_COLUMNS) {
-                        svc.adjustVerticalBarsYAxisPadding(axis, vizHeight, ChartLabels.getMeasureValueInChartMaxHeight(chartDef, true, false, 2, computeTextHeightFromFontSize($svgs)), true);
+                        svc.adjustVerticalBarsYAxisPadding(axis, vizHeight, ChartLabels.getMeasureValueInChartMaxHeight(chartDef, true, false, 2, computeTextHeightFromFontSize($svgs)), true, chartDef);
                     }
 
-                    if (chartDef.valuesInChartDisplayOptions.displayValues && ChartFeatures.canDisplayTotalValues(chartDef)) {
+                    if (chartDef.valuesInChartDisplayOptions.displayValues && ChartFeatures.canDisplayTotalValues(chartDef) && !chartDef.genericMeasures.some(m => ChartMeasure.isRealUnaggregatedMeasure(m))) {
                         svc.adjustVerticalBarsYAxisPadding(axis, vizHeight, ChartLabels.getMeasureValueInChartMaxHeight(chartDef, false, true, 5, computeTextHeightFromFontSize($svgs)), true);
                     }
 
@@ -905,7 +901,7 @@
                     }
                 });
 
-                if (!chartHandler.noXAxis && xAxis) {
+                if (xAxis) {
                     xAxis.orient('bottom');
 
                     $xAxisSvgs.each(function() {
@@ -926,7 +922,7 @@
                             }
                         }
 
-                        if (chartDef.xAxisFormatting.displayAxis) {
+                        if (ChartPropertiesService.showXAxis(chartDef.xAxisFormatting, chartHandler.chartTileProperties)) {
                             xAxisG.call(xAxis);
 
                             const axisScale = yAxes[0].scale()(0);
@@ -968,15 +964,17 @@
                                 // The last tick might be at the very end of the axis and overflow the SVG
                                 const lastTick = xAxisG.select('.tick:last-of-type');
                                 const domainWidth = xAxisG.select('.domain').node()?.getBBox()?.width || 0;
-                                const lastTickTransform = lastTick.attr('transform');
-                                const lastTickText = lastTick.select('text');
+                                if (lastTick) {
+                                    const lastTickTransform = lastTick.attr('transform');
+                                    const lastTickText = lastTick.select('text');
 
-                                if (lastTickTransform) {
-                                    const translateMatch = lastTickTransform.match(/translate\(([^,]+),([^)]+)\)/);
-                                    const lastTickX = translateMatch ? parseFloat(translateMatch[1]) : 0;
-                                    const lastTextWidth = lastTickText.node()?.getBBox()?.width || 0;
-                                    if (lastTickX + lastTextWidth / 2 > domainWidth + updatedMargins.right) {
-                                        lastTickText.attr('x', -(lastTickX + (lastTextWidth / 2) - domainWidth));
+                                    if (lastTickTransform) {
+                                        const translateMatch = lastTickTransform.match(/translate\(([^,]+),([^)]+)\)/);
+                                        const lastTickX = translateMatch ? parseFloat(translateMatch[1]) : 0;
+                                        const lastTextWidth = lastTickText.node()?.getBBox()?.width || 0;
+                                        if (lastTickX + lastTextWidth / 2 > domainWidth + updatedMargins.right) {
+                                            lastTickText.attr('x', -(lastTickX + (lastTextWidth / 2) - domainWidth));
+                                        }
                                     }
                                 }
                             }
@@ -991,78 +989,76 @@
 
                     g.attr('transform', 'translate(' + updatedMargins.left + ',' + updatedMargins.top + ')');
 
-                    if (xAxis && chartDef.gridlinesOptions.vertical.show && ChartFeatures.canHaveVerticalGridlines(chartDef) && !chartHandler.noXAxis) {
+                    if (xAxis && chartDef.gridlinesOptions.vertical.show && ChartFeatures.canHaveVerticalGridlines(chartDef)) {
                         const gridlinesPosition = { x1: 0, x2: 0, y1: 0, y2: allNegative ? vizHeight : -vizHeight };
                         svc.drawGridlines(g.select('g.x.axis'), 'x', chartDef.gridlinesOptions.vertical.lineFormatting, gridlinesPosition, g);
                     }
 
-                    if (!chartHandler.noYAxis) {
-                        yAxes.forEach((axis, index) => {
-                            const axisColor = yAxesColors[axis.id] || '#000';
-                            const axisFormatting = ChartAxesUtils.getFormattingForYAxis(chartDef.yAxesFormatting, axis.id);
+                    yAxes.forEach((axis, index) => {
+                        const axisColor = yAxesColors[axis.id] || '#000';
+                        const axisFormatting = ChartAxesUtils.getFormattingForYAxis(chartDef.yAxesFormatting, axis.id);
 
-                            axis.orient(axis.position);
+                        axis.orient(axis.position);
 
-                            if (vizHeight < 300) {
-                                axis.ticks(svc.optimizeTicksNumber(vizHeight));
+                        if (vizHeight < 300) {
+                            axis.ticks(svc.optimizeTicksNumber(vizHeight));
+                        }
+
+                        const yAxisG = g.append('g').attr('class', `y y${index + 1} axis`);
+                        let remainingAxesWidth = 0;
+                        if (ChartAxesUtils.isRightYAxis(axis)) {
+                            yAxisG.attr('transform', 'translate(' + vizWidth + ',0)');
+                        } else {
+                            remainingAxesWidth = yAxesWidth.slice(index + 1).reduce((acc, val) => {
+                                const isLeftAxis = ChartAxesUtils.isLeftYAxis(yAxes.find(axis => axis.id === val.id));
+                                if (isLeftAxis && val.width > 0) {
+                                    acc += val.width + ChartsStaticData.AXIS_Y_SPACING;
+                                }
+                                return acc;
+                            }, 0);
+                            yAxisG.attr('transform', `translate(${-remainingAxesWidth},0)`);
+                        }
+                        if (ChartPropertiesService.showYAxis(axisFormatting, chartHandler.chartTileProperties)) {
+                            yAxisG.call(axis);
+
+                            if (chartDef.gridlinesOptions.horizontal.show && svc.shouldDrawGridlinesForAxis(chartDef.type, axis, chartDef.gridlinesOptions.horizontal.displayAxis)) {
+                                const gridlinesPosition = { x1: remainingAxesWidth, x2: ChartAxesUtils.isRightYAxis(axis) ? -vizWidth : vizWidth, y1: 0, y2: 0 };
+                                svc.drawGridlines(yAxisG, 'y', chartDef.gridlinesOptions.horizontal.lineFormatting, gridlinesPosition, g);
                             }
 
-                            const yAxisG = g.append('g').attr('class', `y y${index + 1} axis`);
-                            let remainingAxesWidth = 0;
-                            if (ChartAxesUtils.isRightYAxis(axis)) {
-                                yAxisG.attr('transform', 'translate(' + vizWidth + ',0)');
-                            } else {
-                                remainingAxesWidth = yAxesWidth.slice(index + 1).reduce((acc, val) => {
-                                    const isLeftAxis = ChartAxesUtils.isLeftYAxis(yAxes.find(axis => axis.id === val.id));
-                                    if (isLeftAxis && val.width > 0) {
-                                        acc += val.width + ChartsStaticData.AXIS_Y_SPACING;
-                                    }
-                                    return acc;
-                                }, 0);
-                                yAxisG.attr('transform', `translate(${-remainingAxesWidth},0)`);
-                            }
-                            if (axisFormatting.displayAxis) {
-                                yAxisG.call(axis);
 
-                                if (chartDef.gridlinesOptions.horizontal.show && svc.shouldDrawGridlinesForAxis(chartDef.type, axis, chartDef.gridlinesOptions.horizontal.displayAxis)) {
-                                    const gridlinesPosition = { x1: remainingAxesWidth, x2: ChartAxesUtils.isRightYAxis(axis) ? -vizWidth : vizWidth, y1: 0, y2: 0 };
-                                    svc.drawGridlines(yAxisG, 'y', chartDef.gridlinesOptions.horizontal.lineFormatting, gridlinesPosition, g);
+                            if (xAxis && chartDef.singleXAxis && chartDef.facetDimension.length && !index) {
+                                yAxisG.select('.domain').attr('d', 'M0,-100V1000'); // TODO @charts dirty, use vizHeight+margins.top+margins.bottom instead of 1000?
+                                if (allPositive && (axis.type === CHART_AXIS_TYPES.MEASURE || axis.scaleType === SCALE_TYPES.LINEAR)) {
+                                    yAxisG.select('.tick').remove(); // remove tick for '0'
                                 }
-
-
-                                if (xAxis && chartDef.singleXAxis && chartDef.facetDimension.length && !index) {
-                                    yAxisG.select('.domain').attr('d', 'M0,-100V1000'); // TODO @charts dirty, use vizHeight+margins.top+margins.bottom instead of 1000?
-                                    if (allPositive && (axis.type === CHART_AXIS_TYPES.MEASURE || axis.scaleType === SCALE_TYPES.LINEAR)) {
-                                        yAxisG.select('.tick').remove(); // remove tick for '0'
-                                    }
-                                }
-
-                                const axisG = g.select(`.y${index + 1}`);
-                                const ticksFormatting = axisFormatting.axisValuesFormatting.axisTicksFormatting;
-
-                                axisG.selectAll('.tick text')
-                                    .attr('fill', ChartFeatures.canSetAxisTextColor(chartDef.type) ? ticksFormatting.fontColor : axisColor)
-                                    .attr('font-size', `${ticksFormatting.fontSize}px`);
                             }
 
                             const axisG = g.select(`.y${index + 1}`);
-                            svc.addTitleToYAxis(axisG, axis, chartDef, chartHandler, margins, vizHeight, yAxesWidth[index].width, axisColor);
+                            const ticksFormatting = axisFormatting.axisValuesFormatting.axisTicksFormatting;
+
+                            axisG.selectAll('.tick text')
+                                .attr('fill', ChartFeatures.canSetAxisTextColor(chartDef.type) ? ticksFormatting.fontColor : axisColor)
+                                .attr('font-size', `${ticksFormatting.fontSize}px`);
+                        }
+
+                        const axisG = g.select(`.y${index + 1}`);
+                        svc.addTitleToYAxis(axisG, axis, chartDef, chartHandler, margins, vizHeight, yAxesWidth[index].width, axisColor);
 
 
-                            // sanitize ticks if a specific configuration is set
-                            if (ChartFeatures.shouldRemoveOverlappingTicks(axisFormatting, chartDef, axisFormatting.id)) {
-                                g.selectAll(`g.y${index + 1}.axis`).selectAll('g.tick').forEach(ticks => {
-                                    ticks.sort((a, b) => a.__data__ - b.__data__);
-                                    const overlappingTicks = svc.sanitizeTicksDisplay(ticks, true, true);
-                                    AxisTicksConfiguration.setYTicksAreOverlapping(overlappingTicks.length > 0);
-                                });
-                            } else {
-                                AxisTicksConfiguration.setYTicksAreOverlapping(false);
-                            }
-                            const domain = yAxisG.selectAll('.domain, .tick');
-                            domain.style('stroke', axisColor);
-                        });
-                    }
+                        // sanitize ticks if a specific configuration is set
+                        if (ChartFeatures.shouldRemoveOverlappingTicks(axisFormatting, chartDef, axisFormatting.id)) {
+                            g.selectAll(`g.y${index + 1}.axis`).selectAll('g.tick').forEach(ticks => {
+                                ticks.sort((a, b) => a.__data__ - b.__data__);
+                                const overlappingTicks = svc.sanitizeTicksDisplay(ticks, true, true);
+                                AxisTicksConfiguration.setYTicksAreOverlapping(overlappingTicks.length > 0);
+                            });
+                        } else {
+                            AxisTicksConfiguration.setYTicksAreOverlapping(false);
+                        }
+                        const domain = yAxisG.selectAll('.domain, .tick');
+                        domain.style('stroke', axisColor);
+                    });
                 });
 
                 return { margins, updatedMargins, vizWidth, vizHeight };
@@ -1075,7 +1071,7 @@
              * @param {string} title: title to display
              * @param {number} maxTextWidth: maximum width for the graphical text element
              */
-            formatAxisTitle: function(labelElement, title, maxTextWidth){
+            formatAxisTitle: function(labelElement, title, maxTextWidth) {
                 if (maxTextWidth > 0) {
                     let textLength = labelElement.node().getComputedTextLength();
                     let displayedText = title;
@@ -1093,7 +1089,7 @@
              * @param {string} title: title to display
              * @param {d3 axis}axis : d3 axis for which we want to display the title
              */
-            addDateToTitle: function(title, axis){
+            addDateToTitle: function(title, axis) {
                 let finalTitle = title;
                 if (title && axis.dimension && ChartUADimension.isDate(axis.dimension) && axis.scaleType === SCALE_TYPES.TIME) {
                 // specific case for a date dimension, if the current domain is contained within a single day, we add this date at the end of the title
@@ -1124,7 +1120,7 @@
                 const axisTitleMaxWidth = chartWidth - margins.right;
 
 
-                if (titleText && chartDef.xAxisFormatting.showAxisTitle) {
+                if (titleText && ChartPropertiesService.showXAxisTitle(chartDef.xAxisFormatting, chartHandler.chartTileProperties)) {
                     const rect = axisG.append('rect');
 
                     const labelElement = axisG.append('text')
@@ -1144,6 +1140,9 @@
                             .on('click', function() {
                                 chartHandler.openSection(ChartFormattingPaneSections.X_AXIS);
                             });
+                        chartHandler.$on('$destroy', () => {
+                            labelElement.on('click', null);
+                        });
                     }
 
                     const bbox = labelElement.node().getBoundingClientRect();
@@ -1187,7 +1186,7 @@
                 let titleText = ChartAxesUtils.getYAxisTitle(yAxis, chartDef, axisFormatting);
                 titleText = svc.addDateToTitle(titleText, yAxis);
 
-                if (titleText && axisFormatting.showAxisTitle) {
+                if (titleText && ChartPropertiesService.showYAxisTitle(axisFormatting, chartHandler.chartTileProperties)) {
                     const labelElement = axisG.append('text')
                         .attr('x', xPosition)
                         .attr('y', (chartHeight - margins.top) / 2)
@@ -1206,6 +1205,9 @@
                             .on('click', function() {
                                 chartHandler.openSection(ChartFormattingPaneSections.Y_AXIS);
                             });
+                        chartHandler.$on('$destroy', () => {
+                            labelElement.on('click', null);
+                        });
                     }
                 }
             },
@@ -1246,9 +1248,28 @@
              * @param {number} valuesFontSize - the font size of the values displayed in chart
              * @returns {Record<string, unknown>} the updated d3 axis object.
              */
-            adjustVerticalBarsYAxisPadding: (axis, axisHeight, valuesFontSize, addNegativeExtent = true) => {
+            adjustVerticalBarsYAxisPadding: (axis, axisHeight, valuesFontSize, addNegativeExtent, chartDef) => {
                 const extent = svc.getCurrentAxisExtent(axis);
-                adjustAxisPadding(axis, extent, axisHeight, valuesFontSize, extent[0] < 0 && addNegativeExtent, extent[1] > 0);
+                if (chartDef?.variant === CHART_VARIANTS.waterfall && chartDef.genericMeasures.length > 0) {
+                    const valuePlacement = chartDef.genericMeasures[0].valuesInChartDisplayOptions?.placementMode;
+                    switch (valuePlacement) {
+                        case ValuesInChartPlacementMode.BELOW:
+                            adjustAxisPadding(axis, extent, axisHeight, valuesFontSize, true, false);
+                            break;
+                        case ValuesInChartPlacementMode.ABOVE:
+                            adjustAxisPadding(axis, extent, axisHeight, valuesFontSize, false, true);
+                            break;
+                        case ValuesInChartPlacementMode.AUTO:
+                            adjustAxisPadding(axis, extent, axisHeight, valuesFontSize, extent[0] < 0, extent[1] > 0);
+                            break;
+
+                        default:
+                            break;
+                    }
+
+                } else {
+                    adjustAxisPadding(axis, extent, axisHeight, valuesFontSize, extent[0] < 0 && addNegativeExtent, extent[1] > 0);
+                }
                 return axis;
             },
 
@@ -1272,7 +1293,7 @@
              * @param {number} axisSize (in pixel)
              * @returns {number} the optimum ticks number
              */
-            optimizeTicksNumber: function(axisSize){
+            optimizeTicksNumber: function(axisSize) {
                 return Math.floor(Math.max(axisSize / 30, 2));
             },
 
