@@ -13,7 +13,7 @@
         return function(g, chartDef, chartHandler, chartData, chartBase, groupsData, f, labelCollisionDetectionHandler, drawReferenceLines = true) {
 
             const xDimension = ChartDimension.getGenericDimension(chartDef),
-                xLabels = chartData.getAxisLabels('x'),
+                xLabels = chartData.getCustomAxisLabels('x') ?? chartData.getAxisLabels('x'),
                 xAxis = chartBase.xAxis,
                 rightAxis = ChartAxesUtils.getRightYAxis(chartBase.yAxes),
                 leftAxis = ChartAxesUtils.getLeftYAxis(chartBase.yAxes),
@@ -21,32 +21,9 @@
                     return chartDef.genericMeasures[d.measure].displayAxis == 'axis1' ? leftAxis.scale() : rightAxis.scale();
                 },
                 getRectValue = function(d) {
-                    return chartData.aggr(d.measure).get(d);
+                    return chartData.aggr(d.measure).get(chartData.getFinalCoords(d));
                 };
 
-            const nonEmptyBinsCounts = {};
-            // do a first pass to compute nonEmptyBinsIdx, we have to do it here, and not in the "prepareData" method, because it would not have the current animation frame or subchart
-            groupsData.forEach(group => {
-                group.columns.forEach(c => {
-                    const columnIndex = c.x;
-                    if (_.isNil(nonEmptyBinsCounts[columnIndex])) {
-                        nonEmptyBinsCounts[columnIndex] = 0;
-                    }
-                    const value = getRectValue(c);
-
-                    let nonEmptyIdx = undefined;
-                    if (value !== 0) {
-                        nonEmptyIdx = nonEmptyBinsCounts[columnIndex];
-                        nonEmptyBinsCounts[columnIndex] += 1;
-                    }
-                    c.nonEmptyIdx = nonEmptyIdx;
-                });
-            });
-            // second pass to set nbNonEmptyBins
-            groupsData.forEach(function(group) {
-                group.columns.forEach(c => c.nbNonEmptyBins = nonEmptyBinsCounts[c.x]);
-            });
-
             const nbMaxColumns = Math.max(...groupsData.map(group => group.columns.filter(c => !_.isNil(c.nonEmptyIdx)).length));
 
             let groupWidth = ChartDimension.isUngroupedNumerical(xDimension) ? 10 : Math.max(1, xAxis.ordinalScale.rangeBand());
@@ -76,6 +53,10 @@
 
             const positionBarWrappers = function(barWrappers) {
                 return barWrappers.attr('transform', function(d, i) {
+                    if (chartDef.variant === CHART_VARIANTS.waterfall) {
+                        return undefined;
+                    }
+
                     let xTranslate = barWidth * i;
                     if (HierarchicalChartsUtils.shouldIgnoreEmptyBinsForColorDimension(chartDef)) {
                         xTranslate = (_.isNil(d.nonEmptyIdx) || _.isNil(d.nbNonEmptyBins)) ? 0 : (barWidth * d.nonEmptyIdx + groupWidth / 2 - (barWidth * d.nbNonEmptyBins) / 2);
@@ -126,7 +107,9 @@
                     return chartHandler.legendsWrapper.getLegend(0).items[ChartColorUtils.getColorIndex(d, hasColorDim)].desaturatedColor;
                 })
                 .attr('x', 0)
-                .interrupt('updateColumns').transition('updateColumns').ease('easeOutQuad')
+                .interrupt('updateColumns')
+                .transition('updateColumns')
+                .ease('easeOutQuad')
                 .call(positionRects);
 
             // mix chart uses the same drawer, hence the condition on the chartType
@@ -166,6 +149,10 @@
                 };
 
                 const getLabelXPosition = (d, i) => {
+                    if (chartDef.variant === CHART_VARIANTS.waterfall) {
+                        return barWidth * 0.5;
+                    }
+
                     if (HierarchicalChartsUtils.shouldIgnoreEmptyBinsForColorDimension(chartDef)) {
                         // nonEmptyIdx undefined means that the bin is empty
                         const xPos = (_.isNil(d.nonEmptyIdx) || _.isNil(d.nbNonEmptyBins)) ? 0 : (barWidth * (d.nonEmptyIdx + 0.5) + groupWidth / 2 - (barWidth * d.nbNonEmptyBins) / 2);
@@ -175,6 +162,9 @@
                 };
 
                 const getBackgroundXPosition = (d, i) => {
+                    if (chartDef.variant === CHART_VARIANTS.waterfall) {
+                        return barWidth * 0.5 - d.width / 2 - backgroundXMargin;
+                    }
                     if (HierarchicalChartsUtils.shouldIgnoreEmptyBinsForColorDimension(chartDef)) {
                         // nonEmptyIdx undefined means that the bin is empty
                         const xPos = (_.isNil(d.nonEmptyIdx) || _.isNil(d.nbNonEmptyBins)) ? 0 : (barWidth * (d.nonEmptyIdx + 0.5) + groupWidth / 2 - (barWidth * d.nbNonEmptyBins) / 2) - d.width / 2 - backgroundXMargin;
@@ -189,8 +179,9 @@
                 };
 
                 const getLabelText = (d) => {
-                    const value = chartData.aggr(d.aggregationIndex).get(d);
-                    return BarChartUtils.shouldDisplayBarLabel(chartData.getCount(d), getRectValue(d)) ? chartBase.measureFormatters[d.aggregationIndex](value) : '';
+                    const finalCoords = chartData.getFinalCoords(d);
+                    const value = chartData.aggr(finalCoords.aggregationIndex).get(finalCoords);
+                    return BarChartUtils.shouldDisplayBarLabel(chartData.getCount(finalCoords), getRectValue(finalCoords)) ? chartBase.measureFormatters[finalCoords.aggregationIndex](value) : '';
                 };
 
                 const labelsDrawContext = {
