@@ -8,7 +8,7 @@
 
     // (!) This service previously was in static/dataiku/js/simple_report/curves/lines.js
     function LinesZoomHelper(ChartDataUtils, D3ChartAxes, ChartAxesUtils, LinesUtils, ReferenceLines, ChartYAxisPosition, ChartUsableColumns, ChartCustomMeasures, ChartZoomLoader,
-        ChartSetErrorInScope, Logger, ChartDimension, ChartActivityIndicator, ChartsStaticData) {
+        ChartSetErrorInScope, Logger, ChartDimension, ChartActivityIndicator, ChartsStaticData, ChartPropertiesService) {
 
         const svc = {
 
@@ -120,8 +120,8 @@
                 const xMax = interval[1];
                 const chartData = chartBase.chartData;
                 const results = {};
-                const includeEmptyBins = LinesUtils.hasEmptyBinsToIncludeAsZero(chartDef, chartData);
-                const yExtents = ChartDataUtils.getMeasureExtents(chartDef, chartData.data, [xMin, xMax], includeEmptyBins);
+                const includeEmptyBins = LinesUtils.hasEmptyBinsToIncludeAsZero(ChartDimension.getGenericDimension(chartDef), chartData);
+                const yExtents = ChartDataUtils.getMeasureExtents(chartDef, chartData, 'x', [xMin, xMax], includeEmptyBins);
                 results.recordsCount = yExtents.recordsCount;
                 results.pointsCount = yExtents.pointsCount;
                 const leftAxis = chartBase.yAxes.filter(axis => axis.position === ChartYAxisPosition.LEFT),
@@ -187,10 +187,10 @@
                 return zoomUtils;
             },
 
-            redrawChart(chartBase, chartDef, zoomUtils, containerSelection, xAxis, drawFrame) {
+            redrawChart(chartBase, chartDef, zoomUtils, containerSelection, xAxis, drawFrame, chartTileProperties) {
                 const leftYAxis = ChartAxesUtils.getLeftYAxis(chartBase.yAxes);
                 const rightYAxis = ChartAxesUtils.getRightYAxis(chartBase.yAxes);
-                svc.updateAxes(containerSelection, chartDef, xAxis, leftYAxis, rightYAxis, zoomUtils, chartBase.vizHeight, chartBase.vizWidth);
+                svc.updateAxes(containerSelection, chartDef, xAxis, leftYAxis, rightYAxis, zoomUtils, chartBase.vizHeight, chartBase.vizWidth, chartTileProperties);
 
                 drawFrame(zoomUtils.frameIndex, chartBase, true);
                 svc.updateMissingDataAreas(chartBase, zoomUtils);
@@ -365,13 +365,13 @@
                 };
             },
 
-            updateAxes(containerSelection, chartDef, xAxis, leftYAxis, rightYAxis, zoomUtils, vizHeight, vizWidth) {
-                svc.updateXAxis(containerSelection, chartDef, xAxis, vizHeight, [leftYAxis, rightYAxis]);
-                svc.updateYAxes(containerSelection, chartDef, leftYAxis, rightYAxis, zoomUtils, vizWidth);
+            updateAxes(containerSelection, chartDef, xAxis, leftYAxis, rightYAxis, zoomUtils, vizHeight, vizWidth, chartTileProperties) {
+                svc.updateXAxis(containerSelection, chartDef, xAxis, vizHeight, [leftYAxis, rightYAxis], chartTileProperties);
+                svc.updateYAxes(containerSelection, chartDef, leftYAxis, rightYAxis, zoomUtils, vizWidth, chartTileProperties);
             },
 
-            updateXAxis(containerSelection, chartDef, xAxis, vizHeight, yAxes) {
-                if (!chartDef.xAxisFormatting.displayAxis) {
+            updateXAxis(containerSelection, chartDef, xAxis, vizHeight, yAxes, chartTileProperties) {
+                if (!ChartPropertiesService.showXAxis(chartDef.xAxisFormatting, chartTileProperties)) {
                     return;
                 }
 
@@ -399,18 +399,18 @@
                 });
             },
 
-            updateYAxes(containerSelection, chartDef, leftAxis, rightAxis, zoomUtils, vizWidth) {
+            updateYAxes(containerSelection, chartDef, leftAxis, rightAxis, zoomUtils, vizWidth, chartTileProperties) {
                 if (leftAxis) {
-                    svc.updateYAxis(containerSelection, chartDef, leftAxis, zoomUtils, '.y1.axis', vizWidth);
+                    svc.updateYAxis(containerSelection, chartDef, leftAxis, zoomUtils, '.y1.axis', vizWidth, chartTileProperties);
                 }
                 if (rightAxis) {
-                    svc.updateYAxis(containerSelection, chartDef, rightAxis, zoomUtils, '.y2.axis', vizWidth);
+                    svc.updateYAxis(containerSelection, chartDef, rightAxis, zoomUtils, '.y2.axis', vizWidth, chartTileProperties);
                 }
             },
 
-            updateYAxis(containerSelection, chartDef, yAxis, zoomUtils, selector, vizWidth) {
+            updateYAxis(containerSelection, chartDef, yAxis, zoomUtils, selector, vizWidth, chartTileProperties) {
                 const axisFormatting = ChartAxesUtils.getFormattingForYAxis(chartDef.yAxesFormatting, yAxis);
-                if (axisFormatting && !axisFormatting.displayAxis) {
+                if (!axisFormatting || !ChartPropertiesService.showYAxis(axisFormatting, chartTileProperties)) {
                     return;
                 }
 
