@@ -35,6 +35,7 @@
             $ctrl.iconSize = 16;
             $ctrl.editedMessage = '';
             $ctrl.editedMessageId = '';
+            $ctrl.toolValidations = null;
 
             $ctrl.$onChanges = (changes) => {
                 // don't reload the messages if the active session is still streaming
@@ -64,6 +65,8 @@
                     ...($ctrl.chatSessions[activeSessionId] || {}),
                     streamedMessage: '',
                     rawMessage: '',
+                    // mostly used for debug mode (text / debug messages separated into parts)
+                    streamedParts: [],
                     rawReasoning: '',
                     reasoning: '',
                     currentlyStreaming: true,
@@ -132,16 +135,17 @@
                                     }
                                 })
                             }
+
                             if (data.text) {
-                                const text = data.text;
-                                activeSession.rawMessage += text;
+                                activeSession.rawMessage += data.text;
                                 let currentLength = activeSession.rawMessage.length;
-                                const convertToMarkdown = currentLength < THROTTLE_MIN_LENGTH || (currentLength > THROTTLE_MIN_LENGTH && currentLength > previousLength + CHAR_LIMIT_FOR_MARKDOWN);
                                 // throttle text streaming if the string is too long
+                                const convertToMarkdown = currentLength < THROTTLE_MIN_LENGTH || (currentLength > THROTTLE_MIN_LENGTH && currentLength > previousLength + CHAR_LIMIT_FOR_MARKDOWN);
+                                const textPart = getOrCreateTextPart();
+                                textPart.raw += data.text;
                                 if (activeSession.useMarkdown && convertToMarkdown) {
-                                    // if there is an error parsing the HTML (e.g., LLM is spitting out garbage text), stop using markdown
                                     try {
-                                        activeSession.streamedMessage = $dkuSanitize(marked(activeSession.rawMessage, {
+                                        textPart.html = $dkuSanitize(marked(textPart.raw, {
                                             breaks: true
                                         }));
                                         previousLength = currentLength;
@@ -150,22 +154,31 @@
                                         activeSession.useMarkdown = false;
                                     }
                                 }
-
                                 if (!activeSession.useMarkdown) {
-                                    activeSession.streamedMessage = activeSession.rawMessage;
+                                    textPart.html = textPart.raw;
                                 }
+                                combineStreamedParts();
+                                $scope.$apply();
+                                scrollChat(activeSessionId, false);
+                            }
+                            if (data.type === "event" && activeSession.lastCustomAssistantMessageSettings?.toolsUsingAgentSettings?.debugMode) {
+                                const text = "<code class=\"prompt-chat__output-text--event\">EVENT: " + data.eventKind + ": " + JSON.stringify(data.eventData).replace('_', '&lowbar;') + "</code>\n\n";
+                                const debugHtml = $dkuSanitize(text);
+                                activeSession.streamedParts.push({ type: 'debug', html: debugHtml });
+                                combineStreamedParts();
                                 $scope.$apply();
                                 scrollChat(activeSessionId, false);
                             }
                             break;
                         } case 'completion-response': {
+                            const streamedMessage = activeSession.streamedMessage;
                             activeSession.streamedMessage = '';
                             activeSession.currentlyStreaming = false;
                             activeSession.isRerun = false;
 
                             // only add the message if we are actually still on the same session
                             if ($ctrl.sessionId === activeSessionId) {
-                                onChatCompletion($ctrl.processResponse ? $ctrl.processResponse({ response: data }) : data, activeSessionId);
+                                onChatCompletion($ctrl.processResponse ? $ctrl.processResponse({ response: data }) : data, activeSessionId, streamedMessage);
                                 $timeout(() => {
                                     scrollChat(activeSessionId, true);
                                 });
@@ -189,6 +202,23 @@
                     scrollChat(activeSessionId, true);
                 });
 
+
+                function combineStreamedParts() {
+                    activeSession.streamedMessage = activeSession.streamedParts.map(part => part.html || '').join('');
+                }
+
+                function getOrCreateTextPart() {
+                    const parts = activeSession.streamedParts;
+                    const lastPart = parts.length ? parts[parts.length - 1] : null;
+                    // if we are streaming text, reuse previous part
+                    if (lastPart && lastPart.type === 'text') {
+                        return lastPart;
+                    }
+                    const newPart = { type: 'text', raw: '', html: '' };
+                    parts.push(newPart);
+                    return newPart;
+                }
+
                 return {
                     callback,
                     activeSession
@@ -211,9 +241,9 @@
             }
 
             // used for auto textarea resizing
-            function setMessageField(el) {
-                el.parentNode.dataset.replicatedValue = el.value;
-            }
+            function setMessageField(el, message) {
+                el.parentNode.dataset.replicatedValue = message;
+            };
 
             $ctrl.sendMessage = () => {
                 if ($ctrl.onBeforeSendMessage) {
@@ -247,6 +277,24 @@
                 clearMessage();
             };
 
+            $ctrl.sendToolValidationResponses = () => {
+                const newMessage = {
+                    parentId: $ctrl.lastMessageId,
+                    id: generateRandomId(7),
+                    runBy: $rootScope.appConfig.login,
+                    message: {
+                        role: 'toolValidationResponses',
+                        toolValidationResponses: $ctrl.toolValidations.map(tv => ({validationRequestId: tv.id, validated: tv.validated, arguments: tv.arguments}))
+                    },
+                    version: 0
+                };
+                $ctrl.messages[newMessage.id] = newMessage;
+                $ctrl.messageBranch.push(newMessage);
+                $ctrl.streamParentId = $ctrl.lastMessageId;
+                onSendMessage(newMessage, { version: 0, parentId: newMessage.id })
+                clearMessage();
+            };
+
             $ctrl.sendEditedMessage = (parentId) => {
                 const newMessage = {
                     parentId,
@@ -279,7 +327,11 @@
             };
 
             $ctrl.rerunResponse = (message) => {
-                const parentId = message.parentId;
+                let parentId = message.parentId;
+                while ($ctrl.messages[parentId] && !["user", "toolValidationResponses"].includes($ctrl.messages[parentId].message.role)) {
+                    const hiddenMessage = $ctrl.messages[parentId];
+                    parentId = hiddenMessage.parentId;
+                }
                 const newMessage = $ctrl.messages[parentId];
                 $ctrl.messageBranch = buildBranch(parentId);
                 onSendMessage(newMessage, { version: message.version + 1, parentId }, true);
@@ -291,7 +343,7 @@
             };
 
             $ctrl.cannotSendMessage = () => {
-                return $ctrl.cannotRunChat() || $ctrl.message.trim() === '' || $ctrl.hasError() || $ctrl.editedMessageId;
+                return $ctrl.cannotRunChat() || $ctrl.message.trim() === '' || $ctrl.hasError() || $ctrl.editedMessageId || $ctrl.pendingToolValidations();
             };
 
             $ctrl.hasError = () => {
@@ -310,6 +362,18 @@
                 return $ctrl.chatSessions[$ctrl.sessionId] && $ctrl.chatSessions[$ctrl.sessionId].currentlyStreaming;
             };
 
+            $ctrl.pendingToolValidations = () => {
+                return $ctrl.messages && $ctrl.messages[$ctrl.lastMessageId] && $ctrl.messages[$ctrl.lastMessageId].message && $ctrl.messages[$ctrl.lastMessageId].message["role"] === "toolValidationRequests";
+            }
+
+            $ctrl.setToolValidations = () => {
+                if ($ctrl.pendingToolValidations()) {
+                    $ctrl.toolValidations = $ctrl.messages[$ctrl.lastMessageId].message.toolValidationRequests
+                } else {
+                    $ctrl.toolValidations = null;
+                }
+            }
+
             $ctrl.cannotRunChat = () => {
                 return !$ctrl.hasActiveLlm || $ctrl.isStreaming();
             };
@@ -344,7 +408,7 @@
                 $timeout(() => {
                     const editEl = document.getElementById('prompt-chat-edit-entry');
                     editEl.focus();
-                    setMessageField(editEl);
+                    setMessageField(editEl, editEl.value);
                 });
             };
 
@@ -385,8 +449,10 @@
 
                     modalScope.uiState = modalScope.uiState || {};
                     modalScope.uiState.showContextSelector = $ctrl.showContextSelector;
+
+                    const currentContext = PromptChatService.getChatContext($ctrl.sessionId);
                     modalScope.uiState.contextWrapper = {
-                        context: $ctrl.context ? angular.copy($ctrl.context) : {}
+                        context: currentContext ? angular.copy(currentContext) : {}
                     };
                     modalScope.setTemplate = (template) => {
                         modalScope.uiState.contextWrapper = {
@@ -395,9 +461,9 @@
                     };
                     modalScope.confirm = () => {
                         // add context to messages
-                        $ctrl.context = modalScope.uiState.contextWrapper?.context;
+                        const newContext = modalScope.uiState.contextWrapper?.context;
                         if ($ctrl.onSetContext) {
-                            $ctrl.onSetContext({ context: $ctrl.context });
+                            $ctrl.onSetContext({ context: newContext });
                         }
                         modalScope.dismiss();
                     };
@@ -411,7 +477,7 @@
                     const promise = $ctrl.onStopStreaming({ sessionId, activeSession: $ctrl.chatSessions[sessionId], messages: $ctrl.messages }) || Promise.resolve();
                     promise.then((response) => {
                         if (response) {
-                            onChatCompletion(response);
+                            onChatCompletion(response, $ctrl.sessionId, $ctrl.sessionId in $ctrl.chatSessions ? $ctrl.chatSessions[$ctrl.sessionId].streamedMessage : "");
                             $timeout(() => {
                                 scrollChat(sessionId, false);
                             });
@@ -433,14 +499,26 @@
             });
             $scope.$on('$destroy', llmStopDevKernelUnsubscribe);
 
-            function onChatCompletion(response) {
+            function onChatCompletion(response, sessionId, lastMessageUIRepresentation) {
                 $ctrl.lastMessageId = response.lastMessageId;
                 const customAssistantMessageSettings = $ctrl.chatSessions[$ctrl.sessionId]?.lastCustomAssistantMessageSettings;
+
+                if ($ctrl.lastMessageId in response.chatMessages) {
+                    response.chatMessages[$ctrl.lastMessageId].message.uiRepresentation = lastMessageUIRepresentation;
+                }
+
                 prepareMessages(response.chatMessages, response.lastMessageId, customAssistantMessageSettings);
+
                 if (response.log) {
                     PromptChatService.setLog($ctrl.sessionId, response.log);
                 }
 
+                if (response.contextUpsert) {
+                    Logger.info("Upserting in context", response.contextUpsert)
+                    PromptChatService.upsertChatContext($ctrl.sessionId, response.contextUpsert);
+                }
+
+
                 $ctrl.onChatCompletion({ 
                     lastMessageId: response.lastMessageId,
                     messages: response.chatMessages,
@@ -450,13 +528,14 @@
 
             function clearMessage() {
                 $ctrl.message = $ctrl.chatSessions[$ctrl.sessionId]?.defaultMessage || '';
-                setMessageField(document.getElementById(entryElId));
+                setMessageField(document.getElementById(entryElId), '');
             }
 
             function resetChat() {
                 $ctrl.messages = {};
                 $ctrl.messageBranch = [];
                 $ctrl.lastMessageId = null;
+                $ctrl.toolValidations = null;
                 PromptChatService.setLog($ctrl.sessionId);
             }
 
@@ -480,11 +559,22 @@
 
             function prepareMessages(messages, lastMessageId, customAssistantMessageSettings) {
                 if (customAssistantMessageSettings) {
-                    $ctrl.messages[lastMessageId] = { ...($ctrl.messages[lastMessageId] || {}), $customSettings: customAssistantMessageSettings };
+                    let _lastAssistantMessageId = lastMessageId;
+                    let _lastAssistantMessage = messages[_lastAssistantMessageId];
+                    if (_lastAssistantMessage && _lastAssistantMessage.message?.role === "toolValidationRequests") {
+                        const memoryFragmentMessage = messages[_lastAssistantMessage.parentId];
+                        const beforeMemoryFragmentMessage = messages[memoryFragmentMessage.parentId];
+                        if (beforeMemoryFragmentMessage.message?.role === "assistant") {
+                            _lastAssistantMessage = beforeMemoryFragmentMessage;
+                            _lastAssistantMessageId = beforeMemoryFragmentMessage.id;
+                        }
+                    }
+                    $ctrl.messages[_lastAssistantMessageId] = { ...($ctrl.messages[_lastAssistantMessageId] || {}), $customSettings: customAssistantMessageSettings };
                 }
 
                 $ctrl.messages = PromptChatService.enrichChatMessages(messages, $ctrl.messages);
                 $ctrl.messageBranch = buildBranch(lastMessageId);
+                $ctrl.setToolValidations();
                 document.getElementById(entryElId).focus();
                 $timeout(() => {
                     const containerEl = document.getElementById('prompt-chat');
