@@ -32,22 +32,4 @@ describe('chart features scatter', function () {
         expectIdToBeHidden('qa_charts_subcharts-dropzone');
     })
 
-
-    it('has axis options', function () {
-        ChartFeaturesTestUtils.setXYUaDimensionFromNumericalColumns();
-        renderTemplate(`/templates/simple_report/types/definition-${chartType}.html`);
-
-        $('.measure-wrapper')[0].click(); // in X
-        expectIdToBeHidden('qa_charts_one-tick-per-bin-select');
-        expectIdToBeHidden('qa_charts_handling-empty-bins-select');
-
-        $('.measure-wrapper')[1].click() // in Y
-        expectIdToBeHidden('qa_charts_one-tick-per-bin-select');
-        expectIdToBeHidden('qa_charts_handling-empty-bins-select');
-    })
-
-    it('doesn\'t have along dimension option', function () {
-        ChartFeaturesTestUtils.computeAlongDimensionSelectTests(chartType, 'NORMAL', false);
-    })
-
 });
