@@ -39,6 +39,12 @@ describe('typesToIconAndLabel filters test', function () {
         module('dataiku.mock');
     });
 
+    let rootScopeForAppConfig;
+    beforeEach(inject(function (_$rootScope_) {
+        rootScopeForAppConfig = _$rootScope_;
+        rootScopeForAppConfig.appConfig = {};
+    }));
+
     let datasetTypeToIcon;
     let datasetTypeToName;
     let connectionTypeToNameForList;
@@ -98,12 +104,6 @@ describe('typesToIconAndLabel filters test', function () {
     const CUSTOM_RECIPES = buildCustomDefinition('customCodeRecipes', 'recipeType');
     const CUSTOM_SAMPLE_DATASET = buildCustomDefinition('customSampleDatasets', 'datasetType');
 
-    let rootScopeForAppConfig;
-    beforeEach(inject(function ($rootScope) {
-        rootScopeForAppConfig = $rootScope;
-        rootScopeForAppConfig.appConfig = {};
-    }));
-
     function addMockedItemInCustoms(type, customToMock, icon, label, definedDesc, withOwnerPluginDesc) {
         let newMock = {
             [customToMock[TYPE_KEY]]: type
