@@ -682,7 +682,11 @@ if [ "$NODETYPE" != "govern" ]
 then
 	"$DIP_HOME"/bin/dssadmin -noLog regenerate-config
 else
-	"$DIP_HOME"/bin/govern-admin -noLog regenerate-config
+  # Copying all DSS log4j properties
+  cp -p "$MYDIR/dist/log4j.properties" "$DIP_HOME"/bin/log4j.properties
+  # Newline to make sure we're not concatenating first line to log4j.properties last line
+  { echo ""; cat "$MYDIR/dist/govern-additional-log4j.properties"; } >> "$DIP_HOME"/bin/log4j.properties
+  "$DIP_HOME"/bin/govern-admin -noLog regenerate-config
 fi
 
 # Final steps that we always do
