@@ -53,6 +53,23 @@ class RegularEvaluateRecipe(EvaluateRecipe):
                  recipe_desc, script, preparation_output_schema, cond_outputs=None, preprocessing_params=None,
                  evaluation_store_folder=None, evaluation_dataset_type=None, api_node_logs_config=None,
                  diagnostics_folder=None, fmi=None):
+        """
+        :param str model_folder: Path to the folder of the saved model.
+        :param str input_dataset_smartname: The smart name for the input dataset to evaluate.
+        :param str managed_folder_smart_id: The smart ID for the managed folder storing images.
+        :param str output_dataset_smartname: The smart name for the output dataset.
+        :param str metrics_dataset_smartname: The smart name for the metrics dataset.
+        :param dict recipe_desc: The recipe's parameters (EvaluationRecipePayloadParams).
+        :param dict script: The script (SerializedShakerScript).
+        :param dict preparation_output_schema: The output schema of the dataset (Schema).
+        :param dict cond_outputs: Optional. The conditional outputs (List<ConditionalOutput>).
+        :param dict preprocessing_params: The preprocessing parameters (ResolvedPreprocessingParams).
+        :param str evaluation_store_folder: Optional path to the Model Evaluation Store folder.
+        :param str evaluation_dataset_type: The type of dataset being evaluated (e.g., 'CLASSIC').
+        :param dict api_node_logs_config: Configuration for API node logging.
+        :param str diagnostics_folder: Optional path to a folder for storing diagnostic files.
+        :param str fmi: Optional Full Model ID (FMI).
+        """
         super(RegularEvaluateRecipe, self).__init__(model_folder, input_dataset_smartname, managed_folder_smart_id, output_dataset_smartname,
                                                     metrics_dataset_smartname, recipe_desc, script,
                                                     preparation_output_schema,
