@@ -8,6 +8,8 @@ import logging
 import sys
 
 from dataiku.base.folder_context import build_folder_context
+from dataiku.doctor.evaluation.evaluation_errors import ERR_MSG_NO_EVAL_FOLDER, ERR_MSG_NO_REF_FOLDER
+from dataiku.modelevaluation.drift.embedding_drift_settings import TextDriftSettings, ImageDriftSettings
 from dataiku.doctor.prediction.custom_standalone_evaluation_scoring import calculate_custom_standalone_evaluation_metrics, ModelParametersForCustomMetric
 from dataiku.doctor.utils.gpu_execution import log_nvidia_smi_if_use_gpu
 from dataikuapi.dss.analysis import RemoveRowsStepBuilder, FilterOnBadTypeStepBuilder
@@ -18,14 +20,16 @@ import pandas as pd
 from dataiku import Dataset
 from dataiku.base.remoterun import read_dku_env_and_set
 from dataiku.base.utils import ErrorMonitoringWrapper
-from dataiku.core import debugging
+from dataiku.core import debugging, schema_handling
 from dataiku.core import dkujson as dkujson
 from dataiku.core import doctor_constants
 from dataiku.doctor import step_constants
 from dataiku.doctor.diagnostics import default_diagnostics
 from dataiku.doctor.diagnostics import diagnostics
-from dataiku.doctor.evaluation.base import add_statistics_to_evaluation, recreate_preds_from_probas, recreate_preds_from_probas_and_threshold, \
-    add_custom_metrics_to_perf, is_classification, is_regression, is_binary_classification, proba_definitions_from_probas
+from dataiku.doctor.evaluation.base import add_statistics_to_evaluation, recreate_preds_from_probas, \
+    recreate_preds_from_probas_and_threshold, \
+    add_custom_metrics_to_perf, is_classification, is_regression, is_binary_classification, \
+    proba_definitions_from_probas, handle_drift_failure
 from dataiku.doctor.evaluation.base import compute_drift
 from dataiku.doctor.evaluation.base import format_data_drift_column_handling
 from dataiku.doctor.evaluation.base import load_input_dataframe
@@ -75,16 +79,27 @@ class StandaloneEvaluateRecipe(object):
 
     should_replace_empty_target_with_default_class = False
 
-    def __init__(self, input_dataset_smartname, recipe_desc, preparation_output_schema, evaluation_store_folder,
-                 reference_dataset_smartname, reference_dataset_schema, diagnostics_folder):
+    def __init__(self,
+                 input_dataset_smartname, managed_folder_smart_id, managed_folder_smart_id_ref,
+                 recipe_desc,
+                 preparation_output_schema,
+                 evaluation_store_folder,
+                 reference_dataset_smartname,
+                 reference_dataset_schema,
+                 diagnostics_folder):
         """
-        This initialization is made solely to read and format the input of the recipes and to create objects that will be used the compute method for better readibility
-        :param input_dataset_smartname: string
-        :param recipe_desc: dict
-        :param preparation_output_schema: dict
-        :param evaluation_store_folder: folder
-        :param reference_dataset_smartname: string
-        :param diagnostics_folder: folder
+        This initialization is made solely to read and format the input of the recipes and to create objects that will
+        be used the compute method for better readability
+
+        :param str input_dataset_smartname: The smart name of the primary dataset to evaluate.
+        :param str managed_folder_smart_id: The smart ID of the managed folder for evaluation data.
+        :param str managed_folder_smart_id_ref: The smart ID of the managed folder for reference data.
+        :param dict recipe_desc: The recipe's parameters (StandaloneEvaluationRecipePayloadParams).
+        :param dict preparation_output_schema: The schema of the prepared dataset (Schema).
+        :param str evaluation_store_folder: The path to the Model Evaluation Store folder.
+        :param str reference_dataset_smartname: The smart name of the reference dataset.
+        :param dict reference_dataset_schema: The schema of the reference dataset (Schema).
+        :param str diagnostics_folder: The path to the folder storing diagnostic files.
         """
         self.evaluation_store_folder_context = build_folder_context(evaluation_store_folder)
         diagnostics_folder_context = build_folder_context(diagnostics_folder)
@@ -180,6 +195,10 @@ class StandaloneEvaluateRecipe(object):
         self.recipe_desc = recipe_desc
         self.reference_dataset_schema = reference_dataset_schema
 
+        self.text_drift_settings, self.image_drift_settings = (
+            self._prepare_embedding_drift_settings(managed_folder_smart_id, managed_folder_smart_id_ref))
+
+
     def compute(self):
         # --- Fetch input dataset schema and fix target/prediction dtypes
         names, dtypes, parse_date_columns = Dataset.get_dataframe_schema_st(
@@ -360,7 +379,7 @@ class StandaloneEvaluateRecipe(object):
 
         # --- Compute the collector_data on the sample (not the full evaluated data)
         sample_df = sample_and_store_dataframe(self.evaluation_store_folder_context, input_df,
-                                               self.preparation_output_schema,
+                                               {'columns': schema_handling.get_schema_from_df(input_df)},
                                                filename='sample_scored.csv.gz',
                                                schema_filename='sample_scored_schema.json',
                                                limit_sampling=self.recipe_desc.get('limitSampling', True))
@@ -416,10 +435,13 @@ class StandaloneEvaluateRecipe(object):
                     self.recipe_desc.get('dataDriftColumnHandling'))
             compute_drift(sample_df, sample_df, self.resolved_preprocessing_params,
                           self.evaluation_store_folder_context,
-                          self.recipe_desc.get('treatDriftFailureAsError', False), self.prediction_type,
+                          self.recipe_desc.get('treatDriftFailureAsError', False),
+                          self.prediction_type,
                           drift_column_settings,
-                          self.recipe_desc.get('driftConfidenceLevel', 0.95), prediction_column_name=self.prediction_column_name,
-                          should_text_drift=self.recipe_desc.get('hasTextDrift'), text_drift_params=self.recipe_desc.get('textDriftParams'))
+                          self.recipe_desc.get('driftConfidenceLevel', 0.95),
+                          prediction_column_name=self.prediction_column_name,
+                          text_drift_settings=self.text_drift_settings,
+                          image_drift_settings=self.image_drift_settings)
 
         if self.has_custom_evaluation_metrics:
             model_parameters = ModelParametersForCustomMetric(self.prediction_type, self.recipe_desc, self.modeling_params)
@@ -480,6 +502,26 @@ class StandaloneEvaluateRecipe(object):
                 dtypes[self.prediction_column_name] = np.float64
         return dtypes
 
+    def _prepare_embedding_drift_settings(self, managed_folder_smart_id, managed_folder_smart_id_ref):
+        """Prepares and validates the settings for text and image embedding drift."""
+        treat_drift_failure_as_error = self.recipe_desc.get('treatDriftFailureAsError', False)
+
+        text_drift_settings = TextDriftSettings(self.recipe_desc.get('hasTextDrift', False))
+        if text_drift_settings.should_be_computed:
+            text_drift_settings = text_drift_settings.with_params(self.recipe_desc.get('textDriftParams', None))
+
+        image_drift_settings = ImageDriftSettings(self.recipe_desc.get('hasImageDrift', False))
+        if image_drift_settings.should_be_computed:
+            if not managed_folder_smart_id:
+                handle_drift_failure(ERR_MSG_NO_EVAL_FOLDER, treat_drift_failure_as_error)
+
+            if not managed_folder_smart_id_ref:
+                handle_drift_failure(ERR_MSG_NO_REF_FOLDER, treat_drift_failure_as_error)
+
+            image_drift_settings = image_drift_settings.with_params(
+                self.recipe_desc.get('imageDriftParams', None), managed_folder_smart_id, managed_folder_smart_id_ref)
+
+        return text_drift_settings, image_drift_settings
 
 if __name__ == "__main__":
     debugging.install_handler()
@@ -487,9 +529,10 @@ if __name__ == "__main__":
     read_dku_env_and_set()
 
     with ErrorMonitoringWrapper():
-        reference_dataset_schema = dkujson.load_from_filepath(sys.argv[6]) if sys.argv[6] != "" else None
-        ser_runner = StandaloneEvaluateRecipe(sys.argv[1], dkujson.load_from_filepath(sys.argv[2]),
-                                              dkujson.load_from_filepath(sys.argv[3]), sys.argv[4], sys.argv[5],
-                                              reference_dataset_schema, sys.argv[7])
+        reference_dataset_schema = dkujson.load_from_filepath(sys.argv[8]) if sys.argv[8] != "" else None
+        ser_runner = StandaloneEvaluateRecipe(sys.argv[1], sys.argv[2],sys.argv[3],
+                                              dkujson.load_from_filepath(sys.argv[4]),
+                                              dkujson.load_from_filepath(sys.argv[5]), sys.argv[6], sys.argv[7],
+                                              reference_dataset_schema, sys.argv[9])
         log_nvidia_smi_if_use_gpu(recipe_desc=ser_runner.recipe_desc)
         ser_runner.compute()
