@@ -334,7 +334,7 @@ class RegressionModelScorer(ClassicalPredictionModelScorer):
                 )
 
         # Global metrics
-        global_metrics = {}
+        global_metrics = {"testSize": self.test_y.shape[0]}
         if self.test_sample_weight is not None:
             test_weight = self.test_sample_weight.sum()
             target_avg = np.dot(self.test_y, self.test_sample_weight) / test_weight
