@@ -42,7 +42,12 @@ class GeneratedFeaturesMapping:
         if features is None:
             return
         for feature in features:
-            self.feature_to_block[feature] = block_name
+            if feature in self.feature_to_block and self.feature_to_block[feature] != block_name:
+                message = ("Preprocessed feature names collision detected: columns `{}` and `{}` have preprocessed feature "
+                           "names that overlap. Try renaming the columns.").format(self.feature_to_block[feature], block_name)
+                raise ValueError(message)
+            else:
+                self.feature_to_block[feature] = block_name
 
     def get_block_from_feature(self, feature_name):
         """
@@ -117,3 +122,9 @@ class GeneratedFeaturesMapping:
                 if current_block_name == block_name:
                     features.append(feature)
         return features
+
+    def get_preprocessed_feature_role(self, feature_name, per_feature):
+        """
+        Returns the feature role 'TARGET', 'INPUT_PAST_ONLY' or 'INPUT' from the preprocessed feature name.
+        """
+        return per_feature[self.get_origin_columns_from_feature(feature_name, per_feature)[0]]['role']
