@@ -1055,7 +1055,7 @@ class PredictionPreprocessingHandler(PreprocessingHandler):
             yield ExtractMLAssertionMasksNbInitialRows(self.assertions)
 
         roles_filter = {"INPUT"}
-        if hasattr(self, 'modeling_params') and self.modeling_params.get("isShiftWindowsCompatible", False):
+        if hasattr(self, 'algorithm') and self.algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_past_only_external_features():
             roles_filter.add("INPUT_PAST_ONLY")
 
         # Numericals
