@@ -62,14 +62,14 @@ class TimeseriesScoringHandler(object):
                                                                            self.training_prediction_length)
 
         self.external_features = (
-            get_external_features(self.preprocessing_params, self.modeling_params.get("isShiftWindowsCompatible", False)) if self.algorithm.SUPPORTS_EXTERNAL_FEATURES else None
+            get_external_features(self.preprocessing_params, self.algorithm) if self.algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_external_features() else None
         )
 
         context = DiagOnlyContext(diagnostics_folder_context) if diagnostics_folder_context else None
         self.listener = ProgressListener(context=context)
 
         self.preprocessing_folder_context = preprocessing_folder_context
-        self.timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, self.listener, self.algorithm.SUPPORTS_EXTERNAL_FEATURES)
+        self.timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, self.listener, self.algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_external_features())
         if self.external_features:
             self.timeseries_preprocessing.load_resources()
 
@@ -156,7 +156,7 @@ class TimeseriesScoringHandler(object):
                 self.core_params,
                 self.preprocessing_params,
                 self.external_features,
-                self.modeling_params.get("isShiftWindowsCompatible", False),
+                self.algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_past_only_external_features(),
                 separate_external_features=True,
             )
 
@@ -166,16 +166,15 @@ class TimeseriesScoringHandler(object):
 
         has_external_features = self.external_features is not None and len(self.external_features) > 0
         has_future_features = has_external_features and len(get_filtered_features(self.preprocessing_params, include_roles=["INPUT"])) > 0
-        if self.modeling_params.get("isShiftWindowsCompatible", False):
-            # ML-based models
-            # TODO: extend to algorithms supporting past-only features (role=INPUT_PAST_ONLY)
+        if self.algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_past_only_external_features():
+            # ML-based models and models supporting past-only features
             has_preprocessed_features = has_external_features and len(get_filtered_features(self.preprocessing_params, include_roles=["INPUT", "INPUT_PAST_ONLY"])) > 0
         else:
             has_preprocessed_features = has_future_features
         # split past and future df and check that there are enough future external features values if actually required
         past_resampled_df, future_resampled_df = self._split_past_and_future_df(resampled_df, check_enough_future_values=has_future_features)
 
-        preprocess_on_full_df = self.algorithm.USE_GLUON_TS
+        preprocess_on_full_df = self.algorithm.ONE_MODEL_FOR_MULTIPLE_TS
 
         if has_preprocessed_features:
             # we could either pass past_resampled_df or future_resampled_df because it will only look at which timeseries identifiers are in the df
@@ -206,7 +205,7 @@ class TimeseriesScoringHandler(object):
         for timeseries_identifier, past_preprocessed_df_of_timeseries_identifier in timeseries_iterator(
             past_preprocessed_df, self.timeseries_identifier_columns
         ):
-            if not self.algorithm.USE_GLUON_TS and timeseries_identifier not in self.clf.trained_models:
+            if not self.algorithm.ONE_MODEL_FOR_MULTIPLE_TS and timeseries_identifier not in self.clf.trained_models:
                 unseen_timeseries_identifiers.append(timeseries_identifier)
             elif len(past_preprocessed_df_of_timeseries_identifier.index) < self.min_timeseries_size:
                 too_short_timeseries_identifiers.append(timeseries_identifier)
@@ -326,7 +325,7 @@ def _remove_end_missing_target(df, time_variable, target_variable, timeseries_id
     return pd.concat(target_dfs, ignore_index=True)
 
 
-def resample_for_scoring(df, schema, resampling_params, core_params, preprocessing_params, external_features, supports_shifts, separate_external_features=False):
+def resample_for_scoring(df, schema, resampling_params, core_params, preprocessing_params, external_features, supports_past_only_features, separate_external_features=False):
     """Resampling for the scoring/evaluation recipes.
     First it resamples either the target and the external features together (evaluation) or separately (scoring) based on separate_external_features.
     Then it resamples the extra columns of the input dataset.
@@ -370,7 +369,7 @@ def resample_for_scoring(df, schema, resampling_params, core_params, preprocessi
     external_features_columns = (external_features or [])
     extra_columns = [col for col in df.columns if col not in base_columns + [target_variable] + external_features_columns]
 
-    include_roles = ["INPUT", "INPUT_PAST_ONLY"] if supports_shifts else ["INPUT"]
+    include_roles = ["INPUT", "INPUT_PAST_ONLY"] if supports_past_only_features else ["INPUT"]
     numerical_external_features = get_filtered_features(preprocessing_params, include_types=["NUMERIC"], include_roles=include_roles)
     categorical_external_features = get_filtered_features(preprocessing_params, exclude_types=["NUMERIC"], include_roles=include_roles)
 
@@ -398,7 +397,7 @@ def resample_for_scoring(df, schema, resampling_params, core_params, preprocessi
             resampled_external_features_df = resample_timeseries(external_features_df, schema, resampling_params, core_params, kia_numerical_external_features, kia_categorical_external_features)
             resampled_df = pd.merge(resampled_df, resampled_external_features_df, on=base_columns, how="right")
 
-            if supports_shifts and len(past_only_columns) > 0:
+            if supports_past_only_features and len(past_only_columns) > 0:
                 past_numerical_external_features = [x for x in numerical_external_features if x in past_only_columns]
                 past_categorical_external_features = [x for x in categorical_external_features if x in past_only_columns]
                 external_features_df = df[base_columns + past_only_columns]
