@@ -2,8 +2,9 @@ import logging
 
 import numpy as np
 
-from dataiku.core import doctor_constants
-from dataiku.core.doctor_constants import TIMESERIES_IDENTIFIER_COLUMNS, TARGET_VARIABLE, PREDICTION_LENGTH, TIME_VARIABLE
+from dataiku.core import doctor_constants, intercom
+from dataiku.core.doctor_constants import TIMESERIES_IDENTIFIER_COLUMNS, TARGET_VARIABLE, PREDICTION_LENGTH, TIME_VARIABLE, \
+    DEFAULT_PERMUTATION_IMPORTANCE_ITERATIONS
 from dataiku.doctor import step_constants
 from dataiku.doctor.crossval.search_context import TimeseriesForecastingSearchContext
 from dataiku.doctor.diagnostics import default_diagnostics
@@ -13,7 +14,8 @@ from dataiku.doctor.prediction.common import needs_hyperparameter_search
 from dataiku.doctor.prediction.common import regridify_optimized_params
 from dataiku.doctor.prediction.metric import MAPE
 from dataiku.doctor.timeseries.preparation.auto_shifts_generation import TimeseriesAutoShiftsGenerator
-from dataiku.doctor.utils import unix_time_millis
+from dataiku.doctor.timeseries.utils.permutation_importance_computer import PermutationImportanceComputer
+from dataiku.doctor.utils import unix_time_millis, get_filtered_features
 from dataiku.doctor.utils import write_done_traininfo
 from dataiku.doctor.utils import get_hyperparams_search_time_traininfo
 from dataiku.doctor.utils import write_hyperparam_search_time_traininfo
@@ -37,7 +39,6 @@ logger = logging.getLogger(__name__)
 
 def launch_training(core_params, modeling_sets, preprocessing_params, resampling_params,
                     run_folder_context, split_folder_context, split_desc):
-
     log_nvidia_smi_if_use_gpu(core_params=core_params)
 
     split_params = split_desc["params"]
@@ -53,11 +54,11 @@ def launch_training(core_params, modeling_sets, preprocessing_params, resampling
     assert len(modeling_sets) == 1, "There cannot be more than one modeling set for time series forecasting training"
     modeling_set = modeling_sets[0]
     modeling_params = modeling_set["modelingParams"]
-    has_external_features = has_external_features_or_windows(preprocessing_params, modeling_params.get("isShiftWindowsCompatible", False))
+    algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
+    has_external_features = has_external_features_or_windows(preprocessing_params, modeling_params, algorithm)
     has_auto_shifts_feature_generation = should_compute_auto_shifts(preprocessing_params, modeling_params)
     metrics_params = modeling_params["metrics"]
     model_folder_context = modeling_set["model_folder_context"]
-    algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
     grid_search_params = modeling_params["grid_search_params"]
     n_search_splits = grid_search_params["nFolds"] if grid_search_params["mode"] == "TIME_SERIES_KFOLD" else 1
 
@@ -71,7 +72,7 @@ def launch_training(core_params, modeling_sets, preprocessing_params, resampling
     if has_auto_shifts_feature_generation:
         preprocessing_listener.add_future_step(step_constants.ProcessingStep.STEP_TIMESERIES_FEATURE_GENERATION)
     preprocessing_listener.add_future_step(step_constants.ProcessingStep.STEP_PREPARE_SPLITS)
-    if algorithm.SUPPORTS_EXTERNAL_FEATURES and has_external_features:
+    if algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_external_features() and has_external_features:
         preprocessing_listener.add_future_steps(step_constants.TIMESERIES_PREPROCESSING_STEPS)
 
     listener = preprocessing_listener.new_child(ModelStatusContext(model_folder_context, start))
@@ -82,6 +83,12 @@ def launch_training(core_params, modeling_sets, preprocessing_params, resampling
     else:
         listener.add_future_steps(step_constants.TIMESERIES_REGULAR_TRAIN_STEPS)
 
+    include_roles = ["INPUT", "INPUT_PAST_ONLY"] if algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_past_only_external_features() else ["INPUT"]
+    columns = get_filtered_features(preprocessing_params, include_roles=include_roles)
+    will_do_permutation_importance = not modeling_params.get("skipPermutationImportance") and columns and PermutationImportanceComputer.supports_permutation_importance(algorithm, preprocessing_params)
+    if will_do_permutation_importance:
+        listener.add_future_step(step_constants.ProcessingStep.STEP_TIMESERIES_PERMUTATION_IMPORTANCE)
+
     if not modeling_params.get("skipExpensiveReports"):
         listener.add_future_step(step_constants.ProcessingStep.STEP_TIMESERIES_RESIDUALS)
 
@@ -100,7 +107,7 @@ def launch_training(core_params, modeling_sets, preprocessing_params, resampling
             resampling_params,
             core_params,
             preprocessing_params,
-            modeling_params.get("isShiftWindowsCompatible", False),
+            algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_past_only_external_features(),
             compute_zero_target_ratio_diagnostic,
         )
 
@@ -162,13 +169,13 @@ def launch_training(core_params, modeling_sets, preprocessing_params, resampling
             )
 
     # We preprocess the full dataframe after potentially skipping time series that are too short for splitting
-    full_timeseries_preprocessing = TimeseriesPreprocessing(run_folder_context, core_params, preprocessing_params, modeling_params, preprocessing_listener, algorithm.SUPPORTS_EXTERNAL_FEATURES)
+    full_timeseries_preprocessing = TimeseriesPreprocessing(run_folder_context, core_params, preprocessing_params, modeling_params, preprocessing_listener, algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_external_features())
 
-    # If model is gluon based, we run the preprocessing on the whole dataframe for the external features,
-    # because the model is trained on the full dataframe.
+    # If the model can fit several timeseries at once, we run the preprocessing on the whole dataframe
+    # for the external features, because the model is trained on the full dataframe.
     # In the statistical models case, we perform the preprocessing on a per time series basis, because
     # we train one model per time series.
-    preprocess_on_full_df = algorithm.USE_GLUON_TS
+    preprocess_on_full_df = algorithm.ONE_MODEL_FOR_MULTIPLE_TS
 
     # No preprocessing is done when there are no external features
     transformed_full_df = full_timeseries_preprocessing.fit_and_process(
@@ -179,13 +186,14 @@ def launch_training(core_params, modeling_sets, preprocessing_params, resampling
     )
     preprocessing_end = unix_time_millis()
 
-    if algorithm.SUPPORTS_EXTERNAL_FEATURES and has_external_features and not full_timeseries_preprocessing.external_features:
+    if algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_external_features() and has_external_features and not full_timeseries_preprocessing.external_features:
         raise ValueError("Missing preprocessed external features.")
 
     # The external features are used only if the algorithm supports them
-    full_preprocessed_external_features = full_timeseries_preprocessing.external_features if algorithm.SUPPORTS_EXTERNAL_FEATURES else None
+    full_preprocessed_external_features = full_timeseries_preprocessing.external_features if algorithm.EXTERNAL_FEATURES_COMPATIBILITY.supports_external_features() else None
     use_external_features = bool(full_preprocessed_external_features)
     full_generated_features_mappings = {ts_id: pipeline.generated_features_mapping for ts_id, pipeline in full_timeseries_preprocessing.pipeline_by_timeseries.items()}
+    full_preprocessed_external_features = split_external_features(full_preprocessed_external_features, preprocessing_params['per_feature'], full_generated_features_mappings)
     full_shift_map = get_shift_map(preprocessing_params, full_generated_features_mappings)
 
     # All shifts and windows algos require at least one generated feature
@@ -286,6 +294,14 @@ def launch_training(core_params, modeling_sets, preprocessing_params, resampling
                            preprocessed_external_features=full_preprocessed_external_features, shift_map=full_shift_map,
                            save_model=True, step_name=step_constants.ProcessingStep.STEP_TIMESERIES_FITTING_GLOBAL)
 
+    if will_do_permutation_importance:
+        with listener.push_step(step_constants.ProcessingStep.STEP_TIMESERIES_PERMUTATION_IMPORTANCE):
+            use_only_generated_features = modeling_params.get("isShiftWindowsCompatible", False)
+            computer = PermutationImportanceComputer(model_scorer, model_folder_context, algorithm, core_params,
+                                                     full_timeseries_preprocessing, timeseries_identifier_columns, estimator, columns, full_shift_map, use_only_generated_features)
+            per_identifier = len(timeseries_identifier_columns) > 0 and modeling_params.get("perIdentifierPermutationImportance", False)
+            computer.compute_permutation_importance(full_df, per_identifier, DEFAULT_PERMUTATION_IMPORTANCE_ITERATIONS)
+
     if not modeling_params.get("skipExpensiveReports"):
         with listener.push_step(step_constants.ProcessingStep.STEP_TIMESERIES_RESIDUALS):
             min_size_for_scoring = algorithm.get_min_size_for_scoring(
@@ -375,6 +391,7 @@ def preprocess_train_test_external_features(
 
     preprocessed_external_features = timeseries_preprocessing_for_split.external_features
     train_features_mappings = {ts_id: pipeline.generated_features_mapping for ts_id, pipeline in timeseries_preprocessing_for_split.pipeline_by_timeseries.items()}
+    preprocessed_external_features = split_external_features(preprocessed_external_features, preprocessing_params['per_feature'], train_features_mappings)
     if test_df is not None:
         test_df = timeseries_preprocessing_for_split.process(
             test_df,
@@ -445,3 +462,19 @@ def populate_auto_shifts(preprocessing_params, run_folder_context):
         message = "Auto-shifts feature generation did not detect any correlated values."
         diagnostics.add_or_update(DiagnosticType.ML_DIAGNOSTICS_MODELING_PARAMETERS, message)
         logger.warning(message)
+
+
+def split_external_features(preprocessed_external_features, per_feature, feature_mappings):
+    """
+    Creates the per timeseries mapping of each preprocessed feature to TARGET, INPUT or INPUT_PAST_ONLY.
+    """
+    if preprocessed_external_features is None:
+        return None
+    res = {}
+    for identifier in preprocessed_external_features.keys():
+        res[identifier] = {"INPUT": [], "INPUT_PAST_ONLY": [], "TARGET": []}
+        for feature in preprocessed_external_features[identifier]:
+            role = feature_mappings[identifier].get_preprocessed_feature_role(feature, per_feature)
+            res[identifier][role].append(feature)
+    return res
+
