@@ -21,6 +21,7 @@ from dataiku.huggingface.types import ProcessSingleRerankingCommand
 from dataiku.huggingface.types import ProcessSingleRerankingResponse
 from dataiku.huggingface.types import SingleCommand
 from dataiku.huggingface.types import SingleResponse
+from dataiku.generated_sources.com.dataiku.dip.llm.online.llm_client.reranking_document import RerankingDocument
 
 # Should not import huggingface or transformers here, otherwise would break hf_transfer and transformers_offline
 # see https://app.shortcut.com/dataiku/story/190851/make-sure-transformers-offline-is-set-early-enough
@@ -207,11 +208,19 @@ class MockModelPipelineReranking(ModelPipeline[ProcessSingleRerankingCommand, Pr
         await asyncio.sleep(random.uniform(0, 2))
         logger.info("Test prompt for mocked reranking pipeline ran successfully")
 
+    @staticmethod
+    def extract_content(requestDocument: RerankingDocument) -> str:
+        content = ""
+        for part in requestDocument.get("parts", []):
+            if part.get("type") == 'TEXT':
+                content += part.get("text", "")
+        return content
+
     async def run_single_async(self, request: ProcessSingleRerankingCommand) -> AsyncIterator[ProcessSingleRerankingResponse]:
         await asyncio.sleep(random.uniform(0, 2))
-        unordered_reranked_documents = [{"index": idx, "relevanceScore": len(doc.get("content", ""))} for idx, doc in enumerate(request["documents"])]
-        reranked_documents = sorted(unordered_reranked_documents, key=lambda x: x["relevanceScore"])
-        yield {"documents": reranked_documents}
+        unordered_reranked_documents = [{"index": idx, "relevanceScore": float(len(self.extract_content(requestDocument)))} for idx, requestDocument in enumerate(request["documents"])]
+        reranked_documents = sorted(unordered_reranked_documents, key=lambda x: x["relevanceScore"], reverse=True)
+        yield {"ok": True, "documents": reranked_documents}
 
 
 
