@@ -196,25 +196,30 @@ class ModelPipelineImageGenerationDiffusion(ModelPipelineBatching[ProcessSingleI
     def _get_inputs(self, requests: List[ProcessSingleImageGenerationCommand]) -> List:
         inputs = []
         for request in requests:
-            inputs.append({ "prompt_texts": request.get("promptTexts"), "negative_prompt_texts": request.get("negativePromptTexts") })
+            inputs.append({ "prompt_texts": request["query"].get("prompts"), "negative_prompt_texts": request["query"].get("negativePrompts") })
         return inputs
 
     def _get_params(self, request: ProcessSingleImageGenerationCommand) -> Dict:
-        fidelity: Optional[float] = request.get("fidelity", None)
+        fidelity: Optional[float] = request["query"].get("fidelity", None)
         if fidelity is None:
             guidance_scale = self._default_guidance_scale
         else:
             guidance_scale = fidelity * 35.0
+        quality = request["query"].get("quality")
+        try:
+            num_inference_steps = int(str(quality))
+        except Exception:
+            num_inference_steps = self._default_num_inference_steps
         return {
             # if prompts are weighted they will be handled differently in the inference function
-            "prompt_weighted": self._are_prompts_weighted(request.get("promptTexts")),
-            "negative_prompt_weighted": self._are_prompts_weighted(request.get("negativePromptTexts")),
-            "height": request.get("height", self._default_height),
-            "width": request.get("width", self._default_width),
-            "num_inference_steps": request.get("numInferenceSteps", self._default_num_inference_steps),
-            "seed": request.get("seed", None),
+            "prompt_weighted": self._are_prompts_weighted(request["query"].get("prompts")),
+            "negative_prompt_weighted": self._are_prompts_weighted(request["query"].get("negativePrompts")),
+            "height": request["query"].get("height", self._default_height),
+            "width": request["query"].get("width", self._default_width),
+            "num_inference_steps": num_inference_steps,
+            "seed": request["query"].get("seed", None),
             "guidance_scale": guidance_scale,
-            "num_images_per_prompt": request.get("numImagesPerPrompt", 1),
+            "num_images_per_prompt": request["query"].get("nbImagesToGenerate", 1),
         }
 
     def _parse_response(self, response, request: ProcessSingleImageGenerationCommand) -> ProcessSingleImageGenerationResponse:
@@ -315,7 +320,7 @@ class ModelPipelineImageGenerationStableDiffusionXL(ModelPipelineImageGeneration
         return {
             **super()._get_params(request),
             **{
-                "refiner_strength": request.get("refinerStrength", self._default_refiner_strength) if self._refiner is not None else 1,
+                "refiner_strength": self._default_refiner_strength if self._refiner is not None else 1,
             }
         }
 
@@ -434,7 +439,7 @@ class ModelPipelineImageGenerationFlux(ModelPipelineImageGenerationDiffusion):
         return {
             **super()._get_params(request),
             **{
-                "max_sequence_length": request.get("max_sequence_length", self._default_max_sequence_length),
+                "max_sequence_length": self._default_max_sequence_length,
             }
         }
 
