@@ -157,6 +157,15 @@ class ModelPipelineTextGenerationVLLM(ModelPipelineVLLM[ProcessSinglePromptComma
                 **extra_args,
             )
 
+        # [sc-282651]
+        self.inline_tools_json_schema = False
+        if self.openai_server.use_harmony:
+            self.inline_tools_json_schema = self.model_settings.get("inlineToolsJsonSchemaRefs", True)
+            logger.info("Server uses OpenAI Harmony. " + (
+                "Will try to inline references in tools JSON schema to enhance compatibility." if self.inline_tools_json_schema
+                else "JSON schema reference inlining is disabled in the model settings."
+            ))
+
     async def run_test_query(self):
         from dataiku.huggingface.vllm_backend.oai_mappers import generate_dummy_dss_completion_request
 
@@ -190,6 +199,9 @@ class ModelPipelineTextGenerationVLLM(ModelPipelineVLLM[ProcessSinglePromptComma
         logger.info("Start prompt {request_id}".format(request_id=request_id))
         assert self.openai_server
 
+        if self.inline_tools_json_schema:
+            request = self._resolve_tools_schema_references(request)
+
         oai_request = dss_to_oai_completion_request(
             request,
             self.chat_template_renderer,
@@ -200,4 +212,18 @@ class ModelPipelineTextGenerationVLLM(ModelPipelineVLLM[ProcessSinglePromptComma
         response = await self.openai_server.create_chat_completion(oai_request)
         async for resp_or_chunk in oai_to_dss_completion_response(response):
             yield resp_or_chunk
-        logger.info("Done prompt {request_id}".format(request_id=request_id))
\ No newline at end of file
+        logger.info("Done prompt {request_id}".format(request_id=request_id))
+
+    def _resolve_tools_schema_references(self, request: ProcessSinglePromptCommand) -> ProcessSinglePromptCommand:
+        from dataiku.huggingface.json_schema import inline_schema_references
+
+        tools = request["settings"].get("tools") or []
+        for tool in tools:
+            params = tool["function"].get("parameters")
+            if not params:
+                continue
+
+            inlined_params = inline_schema_references(params)
+            tool["function"]["parameters"] = inlined_params
+
+        return request
