@@ -143,6 +143,10 @@ class ModelParamsLoader:
                 params["distributed_executor_backend"] = "mp"
         if self.enable_expert_parallelism is not None:
             params["enable_expert_parallel"] = self.enable_expert_parallelism
+        if IS_MAC:
+            # When running on mac, we need to force multiprocessing instead of ray
+            # More details on https://github.com/vllm-project/vllm/issues/18362
+            params["distributed_executor_backend"] = "mp"
 
         return params
 
@@ -330,7 +334,15 @@ class CompletionModelParamsLoader(ModelParamsLoader):
         if self.max_num_seqs is not None:
             params["max_num_seqs"] = self.max_num_seqs
         if self.guided_decoding_backend and self.guided_decoding_backend.strip():
-            params["guided_decoding_backend"] = self.guided_decoding_backend
+            import vllm
+            if package_is_at_least(vllm, "0.12.0"):
+                # `guided_decoding_backend` was removed in https://github.com/vllm-project/vllm/pull/29326
+                from vllm.config.structured_outputs import StructuredOutputsConfig
+                structured_output_config = StructuredOutputsConfig()
+                structured_output_config.backend = self.guided_decoding_backend
+                params["structured_outputs_config"] = structured_output_config
+            else:
+                params["guided_decoding_backend"] = self.guided_decoding_backend
         if self.config_format is not None:
             params["config_format"] = self.config_format
         if self.load_format is not None:
@@ -411,6 +423,9 @@ class Mistral7BModelParamsLoader(CompletionModelParamsLoader):
             )
             return reduced_context_len
 
+    def _load_format(self) -> Optional[str]:
+        return "safetensors"
+
 
 class Llama318BModelParamsLoader(CompletionModelParamsLoader):
     model_display_name = "Llama 3.1 8B"
@@ -518,6 +533,9 @@ class MistralNemo12BModelParamsLoader(CompletionModelParamsLoader):
             )
             return reduced_context_len
 
+    def _load_format(self) -> Optional[str]:
+        return "safetensors"
+
 
 class MistralFormatParamsLoader(CompletionModelParamsLoader):
     def _load_format(self) -> Optional[str]:
