@@ -4,19 +4,19 @@ import os
 import traceback
 from concurrent.futures import ThreadPoolExecutor
 
-
 from dataiku.base.async_link import AsyncJavaLink
 from dataiku.base.socket_block_link import parse_javalink_args
 from dataiku.base.utils import watch_stdin
 from dataiku.core import debugging
 
-logger = logging.getLogger("docextraction_server")
+logger = logging.getLogger(__name__)
 
 class DocExtractionServer:
     def __init__(self):
         self.started = False
         self.executor = ThreadPoolExecutor(1)
-        self.pipeline = None
+        self._docling_pipeline = None
+        self._raw_pipeline = None
         self.settings = None
 
     async def handler(self, command):
@@ -25,12 +25,16 @@ class DocExtractionServer:
             yield await asyncio.get_running_loop().run_in_executor(
                 self.executor, self.start, command
             )
-        elif command["type"] == "process-document":
-            logger.info("received process-document")
+        elif command["type"] == "process-document-structured":
+            logger.info("received process-document-structured")
             logger.debug("Received command: %s", command)
-            yield await self.process_document(command)
+            yield await self.docling_process_document(command)
+        elif command["type"] == "process-document-raw":
+            logger.info("received process-document-raw")
+            logger.debug("Received command: %s", command)
+            yield await self.raw_process_document(command)
         else:
-            raise Exception("Unknown command type: %s" % command["type"])
+            raise ValueError("Unknown command type: %s" % command["type"])
 
     def start(self, start_command):
         """
@@ -42,9 +46,9 @@ class DocExtractionServer:
         self.settings = start_command.get("settings", {})
         self.started = True
 
-    async def process_document(self, process_document_command):
+    async def docling_process_document(self, process_document_command):
         # Safe because this runs on the main asyncio event loop. Since there are no `await` calls during pipeline initialization, the event loop cannot switch tasks, making this block atomic.
-        if self.pipeline is None:
+        if self._docling_pipeline is None:
             logger.info("First document processing - initializing DoclingExtractorPipeline")
             try:
                 from dataiku.llm.docextraction.docling_extraction import DoclingExtractorPipeline
@@ -53,10 +57,26 @@ class DocExtractionServer:
                     f"Unable to initialize pipeline. Check the code environment: {e}"
                 ) from e
 
-            self.pipeline = DoclingExtractorPipeline(self.settings)
+            self._docling_pipeline = DoclingExtractorPipeline(self.settings)
             logger.info("DoclingExtractorPipeline initialized successfully")
 
-        return await self.pipeline.process_document(process_document_command)
+        return await self._docling_pipeline.process_document(process_document_command)
+
+    async def raw_process_document(self, process_document_command):
+        if self._raw_pipeline is None:
+            logger.info("First document processing - initializing RawExtractorPipeline")
+            try:
+                from dataiku.llm.docextraction.raw_extraction import RawExtractorPipeline
+            except ModuleNotFoundError as e:
+                raise ModuleNotFoundError(
+                    f"Unable to initialize pipeline. Check the code environment: {e}"
+                ) from e
+
+            self._raw_pipeline = RawExtractorPipeline(self.settings)
+            logger.info("RawExtractorPipeline initialized successfully")
+
+        return await self._raw_pipeline.process_document(process_document_command)
+
 
 def log_exception(loop, context):
     exc = context.get("exception")
