@@ -3,6 +3,7 @@ import json
 import logging
 import math
 import os
+import copy
 import threading
 import traceback
 from concurrent.futures import ThreadPoolExecutor
@@ -14,8 +15,8 @@ from dataiku.base.socket_block_link import parse_javalink_args
 from dataiku.base.utils import watch_stdin
 from dataiku.core.knowledge_bank import MultipartContext, KnowledgeBank
 from dataiku.core.vector_stores.dku_vector_store import VectorStoreFactory, DkuVectorStore
-from dataiku.huggingface.types import CompletionSettings, ChatMessage
-from dataiku.langchain.base_rag_handler import RetrievalSource
+from dataiku.huggingface.types import CompletionSettings, ChatMessage, Artifact
+from dataiku.langchain.base_rag_handler import RetrievalSource, AugmentationFallbackStrategy
 from dataiku.langchain.content_part_types import TextPart, ImageRefPart, ImageRetrieval, CaptionedImageRefPart, MultipartContent
 from dataiku.langchain.dku_embeddings import DKUEmbeddings
 from dataiku.langchain.document_handler import DocumentHandler
@@ -23,8 +24,9 @@ from dataiku.langchain.sources_handler import SourcesHandler
 from dataiku.llm.evaluation.genai_metrics_input import GenAIMetricInput
 from dataiku.llm.rag.guardrails import AnswerRelevancy, Faithfulness, Guardrail, MultimodalAnswerRelevancy, MultimodalFaithfulness
 from dataiku.llm.tracing import SpanBuilder, new_trace
+from dataiku.llm.rag.reranking import Reranking
 from dataiku.llm.types import LLMErrorType, ProcessSinglePromptCommand, RAGLLMSettings, SimpleCompletionResponseOrError, Source, FilterDesc, \
-    SearchInputStrategy, TrustedObject
+    SearchInputStrategy, TrustedObject, RAGRerankingSettings
 from dataikuapi.dss.llm import DSSLLM, DSSLLMCompletionQuery, DSSLLMStreamedCompletionChunk, DSSLLMStreamedCompletionFooter
 
 if TYPE_CHECKING:
@@ -39,6 +41,7 @@ class RAGServer:
     embeddings: DKUEmbeddings
     guardrails_embedding_model_id: str
     rag_settings: RAGLLMSettings
+    reranking_settings: RAGRerankingSettings
     search_input_strategy: SearchInputStrategy
     no_retrieval_key: str
     retrieval_source: RetrievalSource
@@ -86,18 +89,22 @@ class RAGServer:
 
         self.rag_settings = start_command["ragSettings"]
         self.completion_settings = start_command["defaultCompletionSettings"]
+        self.reranking_settings = self.rag_settings.get("reranking", {})
         self.search_input_strategy = self.rag_settings["searchInputStrategySettings"]["strategy"]
         self.no_retrieval_key = start_command["noRetrievalKey"]
 
         self.embeddings = DKUEmbeddings(llm_id=kb["embeddingLLMId"])
         self.retrieval_source = RetrievalSource(self.rag_settings.get("retrievalSource", RetrievalSource.EMBEDDING))
         retrieval_columns = self.rag_settings.get("retrievalColumns") if self.retrieval_source != RetrievalSource.MULTIMODAL else None
-        self.document_handler = DocumentHandler(kb, self.rag_settings, self.retrieval_source, retrieval_columns)
+        augmentation_fallback_strategy = AugmentationFallbackStrategy(self.rag_settings.get("augmentationFallbackStrategy", AugmentationFallbackStrategy.USE_EMBEDDING))
+        self.document_handler = DocumentHandler(kb, self.rag_settings, self.retrieval_source, retrieval_columns, augmentation_fallback_strategy, trusted_object)
         self.sources_handler = SourcesHandler(
             self.rag_settings.get("sourcesSettings", {}),
             kb.get("managedFolderId"),
             self.retrieval_source,
-            retrieval_columns
+            retrieval_columns,
+            augmentation_fallback_strategy,
+            trusted_object
         )
         # Guardrails settings initialization
         if self.rag_settings["ragSpecificGuardrails"]["faithfulnessSettings"]["enabled"]:
@@ -135,10 +142,13 @@ class RAGServer:
         trace.__enter__()
 
         (text_messages, relevant_messages, question) = self._extract_messages_and_question(process_prompt_command)
-        question = self._query_rewriter(relevant_messages, question, trace)
+        (question, intermediate_artifacts) = self._query_rewriter(relevant_messages, question, trace)
         docs = []
         if self._should_query_kb(question):
             docs = self._query_retriever(process_prompt_command, question, trace)
+            if self.reranking_settings.get("enabled", False):
+                reranker = Reranking(self.reranking_settings)
+                docs = reranker.rerank(question, docs, trace, logger)
 
         completion = self._get_completion(docs, text_messages, process_prompt_command)
 
@@ -167,7 +177,12 @@ class RAGServer:
             rag_response["logProbs"] = raw_resp["logProbs"]
         if "additionalInformation" in raw_resp:
             rag_response["additionalInformation"] = raw_resp["additionalInformation"]
-
+        if "memoryFragment" in raw_resp:
+            rag_response["memoryFragment"] = raw_resp["memoryFragment"]
+        if intermediate_artifacts:
+            rag_response["artifacts"] = intermediate_artifacts
+        if "artifacts" in raw_resp:
+            rag_response.setdefault("artifacts", []).extend(raw_resp["artifacts"])  # artifacts from rewrite query and main answer are concatenated 
         # but for usage metadata, it's not incurred here, but only reported, so put them in the reported field
         rag_response["reportedUsageMetadata"] = {
             "promptTokens": raw_resp.get("promptTokens", None),
@@ -184,6 +199,9 @@ class RAGServer:
         # set sources field if we have them
         if self.output_format == "SEPARATED" and sources_separated is not None:
             rag_response["sources"] = sources_separated
+            for s in rag_response["sources"]:
+                # This is required as metadata can now contain lists but historically sources metadata were map of string
+                s["metadata"] = { k: str(v) for k, v in s["metadata"].items() }
 
         if len(self.guardrails) != 0:
             if not sources_separated:
@@ -202,7 +220,8 @@ class RAGServer:
                                                   trace=trace)
 
         rag_response["trace"] = trace.to_dict()
-        rag_response.setdefault("additionalInformation", {})["sources"] = [{"items": [self.sources_handler.build_role_based_source_from(doc) for doc in docs]}]
+        # sources will always contain a single "items" entry, kept for backward compatibility
+        rag_response.setdefault("additionalInformation", {})["sources"] = [{"items": [source_item for doc in docs if (source_item := self.sources_handler.build_role_based_source_from(doc)) is not None]}]
 
         return rag_response
 
@@ -214,10 +233,14 @@ class RAGServer:
         trace.__enter__()
 
         (text_messages, relevant_messages, question) = self._extract_messages_and_question(process_prompt_command)
-        question = await asyncio.get_running_loop().run_in_executor(None, self._query_rewriter, text_messages, question, trace)
+        (question, intermediate_artifacts) = await asyncio.get_running_loop().run_in_executor(None, self._query_rewriter, relevant_messages, question, trace)
         docs = []
         if self._should_query_kb(question):
             docs = await asyncio.get_running_loop().run_in_executor(None, self._query_retriever, process_prompt_command, question, trace)
+            if self.reranking_settings.get("enabled", False):
+                reranker = Reranking(self.reranking_settings)
+                docs = await asyncio.get_running_loop().run_in_executor(None, reranker.rerank, question, docs, trace, logger)
+
         completion = self._get_completion(docs, text_messages, process_prompt_command)
 
         original_footer = None
@@ -235,6 +258,8 @@ class RAGServer:
                     if item is done:
                         break
                     yield item
+            if intermediate_artifacts:
+                yield DSSLLMStreamedCompletionChunk({"artifacts": intermediate_artifacts})
 
             async for chunk in _aexecute_streamed_completion(completion):
                 if isinstance(chunk, DSSLLMStreamedCompletionChunk):
@@ -290,7 +315,8 @@ class RAGServer:
             if field in original_footer.data:
                 footer_data[field] = original_footer.data[field]
         footer_data.setdefault("additionalInformation", {})
-        footer_data["additionalInformation"]["sources"] = [{"items": [self.sources_handler.build_role_based_source_from(doc) for doc in docs]}]
+        # sources will always contain a single "items" entry, kept for backward compatibility
+        footer_data["additionalInformation"]["sources"] = [{"items": [sourceItem for doc in docs if (sourceItem := self.sources_handler.build_role_based_source_from(doc)) is not None]}]
 
         footer_data["trace"] = trace.to_dict()
         return DSSLLMStreamedCompletionFooter(footer_data)
@@ -329,9 +355,9 @@ class RAGServer:
 
         return raw_tokens
 
-    def _query_rewriter(self, relevant_messages: List[ChatMessage], question: str, trace: SpanBuilder) -> str:
+    def _query_rewriter(self, relevant_messages: List[ChatMessage], question: str, trace: SpanBuilder) -> Tuple[str, List[Artifact]]:
         if self.search_input_strategy == "RAW_QUERY":
-            return question
+            return question, []
 
         if self.search_input_strategy == "REWRITE_QUERY":
             logger.info("Asking the LLM to rewrite this question: %s" % question)
@@ -344,6 +370,7 @@ class RAGServer:
                     completion = self.llm.new_completion()
                     completion.with_message(retrieval_prompt, role="system")
                     completion.with_message(rewrite_prompt, role="system")
+                    completion.settings.update(self.completion_settings)
                     for message in relevant_messages:
                         completion.with_message(message['content'], role=message.get("role", "user"))
                     resp = completion.execute()
@@ -352,8 +379,7 @@ class RAGServer:
                         raise RuntimeError("LLM call failed: %s" % resp._raw.get("errorMessage", "Unknown error"))
                     if "trace" in resp._raw:
                         rewrite_span.append_trace(resp._raw["trace"])
-
-                    return resp.text
+                    return resp.text, resp._raw.get("artifacts", [])
 
         raise ValueError("Unsupported strategy in searchInputStrategySettings: %s" % self.search_input_strategy)
 
@@ -379,6 +405,7 @@ class RAGServer:
 
                 retriever = self.dku_vector_store.as_retriever(self.embeddings, self.rag_settings, additional_search_kwargs)
                 docs = retriever.invoke(question)
+                docs = self.sources_handler.load_docs_metadata(docs, self.dku_vector_store)
 
                 retrieve_span.attributes["nbRetrievedDocuments"] = len(docs)
 
@@ -402,6 +429,9 @@ class RAGServer:
         completion = self.llm.new_completion()
         _set_chat_messages(completion, final_messages)
 
+        if "context" in process_prompt_command["query"]:
+            completion.cq["context"] = copy.deepcopy(process_prompt_command["query"]["context"])
+
         completion.settings.update(self.completion_settings)
         # re-use the completion query settings (from the command)
         settings = process_prompt_command["settings"]
@@ -500,7 +530,7 @@ class RAGServer:
             multipart_content = MultipartContext()
             for index, d in enumerate(docs):
                 # Build multipart content
-                parts = self.document_handler.get_multipart_content(d, image_retrieval=ImageRetrieval.IMAGE_INLINE)
+                parts = self.document_handler.get_multipart_content(d, index=index, image_retrieval=ImageRetrieval.IMAGE_INLINE)
                 multipart_content.parts.extend(parts)
             logger.info("Context: %s" % multipart_content.to_text())
             rag_context_message: ChatMessage = {"role": "user", "multipart_content": multipart_content}
@@ -636,13 +666,14 @@ def _is_relevant_for_vector_store_query(message: ChatMessage) -> bool:
     if tool_outputs and len(tool_outputs) > 0:
         return False
 
-    return message["role"] not in ["system", "tool"] \
+    return message["role"] not in ["system", "tool", "memoryFragment"] \
         and not message.get("partOfExample", False)
 
 def _set_chat_messages(query: DSSLLMCompletionQuery, chat_messages: List[ChatMessage]) -> None:
     for message in chat_messages:
         role = message["role"]
         content = message.get("content")
+        memory_fragment = message.get("memoryFragment")
         multipart_content: Optional[MultipartContext] = message.get("multipart_content")
         tool_calls = message.get("toolCalls")
         tool_outputs = message.get("toolOutputs")
@@ -672,6 +703,9 @@ def _set_chat_messages(query: DSSLLMCompletionQuery, chat_messages: List[ChatMes
         elif content:
             query.with_message(content, role=role)
 
+        elif memory_fragment:
+            query.with_memory_fragment(memory_fragment)
+
         else:
             logger.warning("Chat message seems empty, excluding it from the RAG query" % message)
 
