@@ -36,12 +36,22 @@ class DriftEmbedding(object):
         :rtype: dict
         """
         column_results = {}
+        classifier_sample_size = 0
 
         for column in self.embedding_cur:
             logger.info("Embedding drift: computing embedding drift for column {col}".format(col=column))
-            y_test, y_prob_of_1, id_test = self._compute_classifier(self.embedding_ref, self.embedding_cur, column)
+            y_test, y_prob_of_1, id_test, classifier_sample_size = self._compute_classifier(
+                self.embedding_ref, self.embedding_cur, column
+            )
             column_results[column] = self._compute_core_metrics(column, y_test, y_prob_of_1)
-        return {"columns": column_results}
+
+        return {
+            "columns": column_results,
+            "sampleSize": {
+                "referenceClassifierSampleSize": classifier_sample_size,
+                "currentClassifierSampleSize": classifier_sample_size,
+            },
+        }
 
     def compute_drift_for_image(self, ref_df, cur_df, ref_folder_name, cur_folder_name):
         """
@@ -56,10 +66,13 @@ class DriftEmbedding(object):
         :rtype: dict
         """
         column_results = {}
+        classifier_sample_size = 0
 
         for column in self.embedding_cur:
             logger.info("Embedding drift: computing embedding drift for column {col}".format(col=column))
-            y_test, y_prob_of_1, id_test = self._compute_classifier(self.embedding_ref, self.embedding_cur, column)
+            y_test, y_prob_of_1, id_test, classifier_sample_size = self._compute_classifier(
+                self.embedding_ref, self.embedding_cur, column
+            )
             metrics = self._compute_core_metrics(column, y_test, y_prob_of_1)
             metrics["refPredictionInfos"] = self._get_class_prediction_infos(
                 y_test, y_prob_of_1, id_test, ref_df, ref_folder_name, for_class=0
@@ -68,7 +81,14 @@ class DriftEmbedding(object):
                 y_test, y_prob_of_1, id_test, cur_df, cur_folder_name, for_class=1
             )
             column_results[column] = metrics
-        return {"columns": column_results}
+
+        return {
+            "columns": column_results,
+            "sampleSize": {
+                "referenceClassifierSampleSize": classifier_sample_size,
+                "currentClassifierSampleSize": classifier_sample_size,
+            },
+        }
 
     def _compute_core_metrics(self, column, y_test, y_prob_of_1):
         """Computes the set of metrics common to all drift computations.
@@ -149,19 +169,22 @@ class DriftEmbedding(object):
         :param dict ref: Dictionary of reference embeddings.
         :param dict cur: Dictionary of current embeddings.
         :param str column: Name of the embedding column to process.
-        :return: A tuple containing test set actual labels, test set predicted labels for class 1, and the test sample IDs.
-        :rtype: tuple(pd.Series, np.ndarray, pd.Series) or tuple(None, None, None)
+        :return: A tuple containing test set actual labels, test set predicted labels for class 1,
+                and the test sample IDs.
+        :rtype: tuple(pd.Series, np.ndarray, pd.Series, int) or None
         """
         logger.info("Computing classifier model metric on column %s" % column)
         ref_list = ref[column]
         cur_list = cur[column]
+        ref_sampled, cur_sampled, ref_ids, cur_ids, size = self._subsample_data(ref_list, cur_list)
+
         try:
-            concatenated_df = np.concatenate([ref_list, cur_list])
-            labels = pd.Series([0] * len(ref_list) + [1] * len(cur_list))
-            ids = pd.Series([i for i in range(len(ref_list))] + [i for i in range(len(cur_list))])
+            concatenated_df = np.concatenate([ref_sampled, cur_sampled])
+            labels = pd.Series([0] * len(ref_sampled) + [1] * len(cur_sampled))
+            ids = np.concatenate([ref_ids, cur_ids])
 
             # No need to perform reduction if the embedding vector is already small
-            use_reduction = len(ref_list[0]) > 30
+            use_reduction = len(ref_sampled[0]) > 30
             if use_reduction:
                 logger.info("Performing PCA to reduce the embeddings dimension")
                 reducer = PCA(n_components=10, random_state=1337)
@@ -177,7 +200,7 @@ class DriftEmbedding(object):
 
             clf = train_drift_model(x_train, y_train)
             y_prob_of_1 = clf.predict_proba(x_test)[:, 1]
-            return y_test, y_prob_of_1, id_test
+            return y_test, y_prob_of_1, id_test, size
 
         except Exception as err:
             return _handle_test_error("classifier gini", column, err, self.handle_drift_failure_as_error, None)
@@ -209,7 +232,7 @@ class DriftEmbedding(object):
 
         :param pd.Series y_test: Actual labels (0 or 1) from the test set.
         :param np.ndarray y_prob_of_1: Predicted probabilities for class 1 from the test set.
-        :param pd.Series id_test: The iloc-based IDs corresponding to the test samples.
+        :param pd.Series id_test: The IDs corresponding to the test samples.
         :param pd.DataFrame df: Original Dataset.
         :param str folder_name: Name of the Managed Folder.
         :param int for_class: Target origin label (0 for ref, 1 for cur).
@@ -220,7 +243,7 @@ class DriftEmbedding(object):
         y_prob_of_1_for_class = y_prob_of_1[mask]
         ids = id_test[mask]
 
-        top_5_values = self._extract_top_5_values(df.iloc[ids], y_prob_of_1_for_class, for_class == 0)
+        top_5_values = self._extract_top_5_values(df.loc[ids], y_prob_of_1_for_class, for_class == 0)
         prediction_infos = RegressionModelScorer.compute_preds_pdf(y_prob_of_1_for_class, xmin=0, xmax=1)
 
         return {
@@ -254,3 +277,15 @@ class DriftEmbedding(object):
         top_5_df = df.loc[top_5_series.index]
         top_5_df = top_5_df.assign(**{predict_column_name: top_5_series})
         return top_5_df.reset_index(drop=True)
+
+    def _subsample_data(self, ref, cur):
+        size = min(len(ref), len(cur))
+        rng_ref = np.random.RandomState(42)
+        rng_cur = np.random.RandomState(43)
+
+        ref_ids = rng_ref.choice(len(ref), size, replace=False)
+        cur_ids = rng_cur.choice(len(cur), size, replace=False)
+
+        ref_sampled = ref[ref_ids]
+        cur_sampled = cur[cur_ids]
+        return ref_sampled, cur_sampled, ref_ids, cur_ids, size
