@@ -1,17 +1,18 @@
-from govern.models import EnrichedArtifact
-from govern.models import ScriptOutput
 import copy
 
+from govern.models import EnrichedArtifact
+from govern.models import ScriptOutput
+
 class AutogovernanceHandler:
-    def __init__(self, dkuEnrichedArtifact, client):
+    def __init__(self, enriched_artifact, client):
         """
         Instantiate a new autogovern hook handler.
 
-        :param dict dkuEnrichedArtifact: a Python dict of the dku enriched artifact to auto-govern
+        :param dict enriched_artifact: a Python dict of the dku enriched artifact to auto-govern
         :param :class:`~dataikuapi.govern_client.GovernClient` client: An instance of :class:`~dataikuapi.govern_client.GovernClient` to access the Govern API
         """
 
-        self.enrichedArtifact = EnrichedArtifact(copy.deepcopy(dkuEnrichedArtifact))
+        self.enrichedArtifact = EnrichedArtifact(copy.deepcopy(enriched_artifact))
         self.client = client
         self.message = ''
         self.status = 'SUCCESS'
