@@ -77,7 +77,10 @@ public class CleanDbs implements CustomRunnable {
         this.deleteScenarios = config.get("scenarios").getAsBoolean();
         this.deleteTimelines = config.get("timelines").getAsBoolean();
         this.maxAge = config.get("age").getAsInt();
-        this.force = config.get("force").getAsBoolean();
+        this.force = false;
+        if (config.has("force")) {
+            this.force = config.get("force").getAsBoolean();
+        }
 
         SpringUtils.getInstance().autowire(this);
     }
