@@ -37,7 +37,7 @@ def format_size(size):
     else:
         return '%iGB' % int(size/(1024*1024*1024))
         
-def delete_and_report(to_delete, base_folder, progress_callback, perform_deletion, object_type_name, headers_base):
+def delete_and_report(to_delete, base_folder, progress_callback, perform_deletion, object_type_name, headers_base, formats=None):
     headers = headers_base + ['Size',  ('Status' if perform_deletion else '')]
     report_rows = ['<tr>%s</tr>' % ''.join(['<th>%s</th>' % header for header in headers])]
     deleted_total = 0
@@ -48,6 +48,10 @@ def delete_and_report(to_delete, base_folder, progress_callback, perform_deletio
         deleted_total += deleted
         deletion_status = ('Success' if perform_deletion else '') if len(errors) == 0 else '/'.join(errors)
         cells = deletion + [format_size(deleted), deletion_status]
+        if formats is not None:
+            for i in range(0, len(cells)):
+                if i < len(formats):
+                    cells[i] = formats[i](cells[i])
         report_rows.append('<tr>%s</tr>' % ''.join(['<td>%s</td>' % cell for cell in cells]))
         
         done += 1
